/*******************************************************************************
* File Name: PLC_UART_PM.c
* Version 1.20
*
* Description:
*  This file provides the source code to the Power Management support for
*  the SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PLC_UART.h"
#include "PLC_UART_PVT.h"

#if(PLC_UART_SCB_MODE_I2C_INC)
    #include "PLC_UART_I2C_PVT.h"
#endif /* (PLC_UART_SCB_MODE_I2C_INC) */

#if(PLC_UART_SCB_MODE_EZI2C_INC)
    #include "PLC_UART_EZI2C_PVT.h"
#endif /* (PLC_UART_SCB_MODE_EZI2C_INC) */

#if(PLC_UART_SCB_MODE_SPI_INC || PLC_UART_SCB_MODE_UART_INC)
    #include "PLC_UART_SPI_UART_PVT.h"
#endif /* (PLC_UART_SCB_MODE_SPI_INC || PLC_UART_SCB_MODE_UART_INC) */


/***************************************
*   Backup Structure declaration
***************************************/

#if(PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG || \
   (PLC_UART_SCB_MODE_I2C_CONST_CFG   && (!PLC_UART_I2C_WAKE_ENABLE_CONST))   || \
   (PLC_UART_SCB_MODE_EZI2C_CONST_CFG && (!PLC_UART_EZI2C_WAKE_ENABLE_CONST)) || \
   (PLC_UART_SCB_MODE_SPI_CONST_CFG   && (!PLC_UART_SPI_WAKE_ENABLE_CONST))   || \
   (PLC_UART_SCB_MODE_UART_CONST_CFG  && (!PLC_UART_UART_WAKE_ENABLE_CONST)))

    PLC_UART_BACKUP_STRUCT PLC_UART_backup =
    {
        0u, /* enableState */
    };
#endif


/*******************************************************************************
* Function Name: PLC_UART_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component to enter Deep Sleep.
*  The Enable wakeup from Sleep Mode selection has an influence on
*  this function implementation.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLC_UART_Sleep(void)
{
#if(PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG)

    if(PLC_UART_SCB_WAKE_ENABLE_CHECK)
    {
        if(PLC_UART_SCB_MODE_I2C_RUNTM_CFG)
        {
            PLC_UART_I2CSaveConfig();
        }
        else if(PLC_UART_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            PLC_UART_EzI2CSaveConfig();
        }
    #if(!PLC_UART_CY_SCBIP_V1_I2C_ONLY)
        else if(PLC_UART_SCB_MODE_SPI_RUNTM_CFG)
        {
            PLC_UART_SpiSaveConfig();
        }
        else if(PLC_UART_SCB_MODE_UART_RUNTM_CFG)
        {
            PLC_UART_UartSaveConfig();
        }
    #endif /* (!PLC_UART_CY_SCBIP_V1_I2C_ONLY) */
        else
        {
            /* Unknown mode: do nothing */
        }
    }
    else
    {
        PLC_UART_backup.enableState = (uint8) PLC_UART_GET_CTRL_ENABLED;

        if(0u != PLC_UART_backup.enableState)
        {
            PLC_UART_Stop();
        }
    }

#else

    #if (PLC_UART_SCB_MODE_I2C_CONST_CFG && PLC_UART_I2C_WAKE_ENABLE_CONST)
        PLC_UART_I2CSaveConfig();

    #elif (PLC_UART_SCB_MODE_EZI2C_CONST_CFG && PLC_UART_EZI2C_WAKE_ENABLE_CONST)
        PLC_UART_EzI2CSaveConfig();

    #elif (PLC_UART_SCB_MODE_SPI_CONST_CFG && PLC_UART_SPI_WAKE_ENABLE_CONST)
        PLC_UART_SpiSaveConfig();

    #elif (PLC_UART_SCB_MODE_UART_CONST_CFG && PLC_UART_UART_WAKE_ENABLE_CONST)
        PLC_UART_UartSaveConfig();

    #else

        PLC_UART_backup.enableState = (uint8) PLC_UART_GET_CTRL_ENABLED;

        if(0u != PLC_UART_backup.enableState)
        {
            PLC_UART_Stop();
        }

    #endif /* defined (PLC_UART_SCB_MODE_I2C_CONST_CFG) && (PLC_UART_I2C_WAKE_ENABLE_CONST) */

#endif /* (PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: PLC_UART_Wakeup
********************************************************************************
*
* Summary:
*  Prepares the component for the Active mode operation after exiting Deep Sleep.
*  The Enable wakeup from Sleep Mode option has an influence on this function
*  implementation.
*  This function should not be called after exiting Sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLC_UART_Wakeup(void)
{
#if(PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG)

    if(PLC_UART_SCB_WAKE_ENABLE_CHECK)
    {
        if(PLC_UART_SCB_MODE_I2C_RUNTM_CFG)
        {
            PLC_UART_I2CRestoreConfig();
        }
        else if(PLC_UART_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            PLC_UART_EzI2CRestoreConfig();
        }
    #if(!PLC_UART_CY_SCBIP_V1_I2C_ONLY)
        else if(PLC_UART_SCB_MODE_SPI_RUNTM_CFG)
        {
            PLC_UART_SpiRestoreConfig();
        }
        else if(PLC_UART_SCB_MODE_UART_RUNTM_CFG)
        {
            PLC_UART_UartRestoreConfig();
        }
    #endif /* (!PLC_UART_CY_SCBIP_V1_I2C_ONLY) */
        else
        {
            /* Unknown mode: do nothing */
        }
    }
    else
    {
        if(0u != PLC_UART_backup.enableState)
        {
            PLC_UART_Enable();
        }
    }

#else

    #if (PLC_UART_SCB_MODE_I2C_CONST_CFG  && PLC_UART_I2C_WAKE_ENABLE_CONST)
        PLC_UART_I2CRestoreConfig();

    #elif (PLC_UART_SCB_MODE_EZI2C_CONST_CFG && PLC_UART_EZI2C_WAKE_ENABLE_CONST)
        PLC_UART_EzI2CRestoreConfig();

    #elif (PLC_UART_SCB_MODE_SPI_CONST_CFG && PLC_UART_SPI_WAKE_ENABLE_CONST)
        PLC_UART_SpiRestoreConfig();

    #elif (PLC_UART_SCB_MODE_UART_CONST_CFG && PLC_UART_UART_WAKE_ENABLE_CONST)
        PLC_UART_UartRestoreConfig();

    #else

        if(0u != PLC_UART_backup.enableState)
        {
            PLC_UART_Enable();
        }

    #endif /* (PLC_UART_I2C_WAKE_ENABLE_CONST) */

#endif /* (PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/* [] END OF FILE */
