/*******************************************************************************
* File Name: .h
* Version 1.20
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_PLC_UART_H)
#define CY_SCB_PVT_PLC_UART_H

#include "PLC_UART.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define PLC_UART_SetI2CExtClkInterruptMode(interruptMask) PLC_UART_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define PLC_UART_ClearI2CExtClkInterruptSource(interruptMask) PLC_UART_CLEAR_INTR_I2C_EC(interruptMask)
#define PLC_UART_GetI2CExtClkInterruptSource()                (PLC_UART_INTR_I2C_EC_REG)
#define PLC_UART_GetI2CExtClkInterruptMode()                  (PLC_UART_INTR_I2C_EC_MASK_REG)
#define PLC_UART_GetI2CExtClkInterruptSourceMasked()          (PLC_UART_INTR_I2C_EC_MASKED_REG)

#if(!PLC_UART_CY_SCBIP_V1_I2C_ONLY)
/* APIs to service INTR_SPI_EC register */
#define PLC_UART_SetSpiExtClkInterruptMode(interruptMask) PLC_UART_WRITE_INTR_SPI_EC_MASK(interruptMask)
#define PLC_UART_ClearSpiExtClkInterruptSource(interruptMask) PLC_UART_CLEAR_INTR_SPI_EC(interruptMask)
#define PLC_UART_GetExtSpiClkInterruptSource()                 (PLC_UART_INTR_SPI_EC_REG)
#define PLC_UART_GetExtSpiClkInterruptMode()                   (PLC_UART_INTR_SPI_EC_MASK_REG)
#define PLC_UART_GetExtSpiClkInterruptSourceMasked()           (PLC_UART_INTR_SPI_EC_MASKED_REG)
#endif /* (!PLC_UART_CY_SCBIP_V1_I2C_ONLY) */

#if(PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void PLC_UART_SetPins(uint32 mode, uint32 subMode, uint32 uartTxRx);
#endif /* (PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if !defined (CY_REMOVE_PLC_UART_CUSTOM_INTR_HANDLER)
    extern cyisraddress PLC_UART_customIntrHandler;
#endif /* !defined (CY_REMOVE_PLC_UART_CUSTOM_INTR_HANDLER) */

extern PLC_UART_BACKUP_STRUCT PLC_UART_backup;

#if(PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common config vars */
    extern uint8 PLC_UART_scbMode;
    extern uint8 PLC_UART_scbEnableWake;
    extern uint8 PLC_UART_scbEnableIntr;

    /* I2C config vars */
    extern uint8 PLC_UART_mode;
    extern uint8 PLC_UART_acceptAddr;

    /* SPI/UART config vars */
    extern volatile uint8 * PLC_UART_rxBuffer;
    extern uint8   PLC_UART_rxDataBits;
    extern uint32  PLC_UART_rxBufferSize;

    extern volatile uint8 * PLC_UART_txBuffer;
    extern uint8   PLC_UART_txDataBits;
    extern uint32  PLC_UART_txBufferSize;

    /* EZI2C config vars */
    extern uint8 PLC_UART_numberOfAddr;
    extern uint8 PLC_UART_subAddrSize;
#endif /* (PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*  Conditional Macro
****************************************/

#if(PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Define run time operation mode */
    #define PLC_UART_SCB_MODE_I2C_RUNTM_CFG     (PLC_UART_SCB_MODE_I2C      == PLC_UART_scbMode)
    #define PLC_UART_SCB_MODE_SPI_RUNTM_CFG     (PLC_UART_SCB_MODE_SPI      == PLC_UART_scbMode)
    #define PLC_UART_SCB_MODE_UART_RUNTM_CFG    (PLC_UART_SCB_MODE_UART     == PLC_UART_scbMode)
    #define PLC_UART_SCB_MODE_EZI2C_RUNTM_CFG   (PLC_UART_SCB_MODE_EZI2C    == PLC_UART_scbMode)
    #define PLC_UART_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (PLC_UART_SCB_MODE_UNCONFIG == PLC_UART_scbMode)

    /* Define wakeup enable */
    #define PLC_UART_SCB_WAKE_ENABLE_CHECK        (0u != PLC_UART_scbEnableWake)
#endif /* (PLC_UART_SCB_MODE_UNCONFIG_CONST_CFG) */

#endif /* (CY_SCB_PVT_PLC_UART_H) */


/* [] END OF FILE */
