/*******************************************************************************
* File Name: XBEE_UART.c
* Version 1.20
*
* Description:
*  This file provides the source code to the API for the SCB Component.
*
* Note:
*
*******************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "XBEE_UART_PVT.h"

#if(XBEE_UART_SCB_MODE_I2C_INC)
    #include "XBEE_UART_I2C_PVT.h"
#endif /* (XBEE_UART_SCB_MODE_I2C_INC) */

#if(XBEE_UART_SCB_MODE_EZI2C_INC)
    #include "XBEE_UART_EZI2C_PVT.h"
#endif /* (XBEE_UART_SCB_MODE_EZI2C_INC) */

#if(XBEE_UART_SCB_MODE_SPI_INC || XBEE_UART_SCB_MODE_UART_INC)
    #include "XBEE_UART_SPI_UART_PVT.h"
#endif /* (XBEE_UART_SCB_MODE_SPI_INC || XBEE_UART_SCB_MODE_UART_INC) */


/***************************************
*    Run Time Configuration Vars
***************************************/

/* Stores internal component configuration for unconfigured mode */
#if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common config vars */
    uint8 XBEE_UART_scbMode = XBEE_UART_SCB_MODE_UNCONFIG;
    uint8 XBEE_UART_scbEnableWake;
    uint8 XBEE_UART_scbEnableIntr;

    /* I2C config vars */
    uint8 XBEE_UART_mode;
    uint8 XBEE_UART_acceptAddr;

    /* SPI/UART config vars */
    volatile uint8 * XBEE_UART_rxBuffer;
    uint8  XBEE_UART_rxDataBits;
    uint32 XBEE_UART_rxBufferSize;

    volatile uint8 * XBEE_UART_txBuffer;
    uint8  XBEE_UART_txDataBits;
    uint32 XBEE_UART_txBufferSize;

    /* EZI2C config vars */
    uint8 XBEE_UART_numberOfAddr;
    uint8 XBEE_UART_subAddrSize;
#endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Common SCB Vars
***************************************/

uint8 XBEE_UART_initVar = 0u;

#if !defined (CY_REMOVE_XBEE_UART_CUSTOM_INTR_HANDLER)
    cyisraddress XBEE_UART_customIntrHandler = NULL;
#endif /* !defined (CY_REMOVE_XBEE_UART_CUSTOM_INTR_HANDLER) */


/***************************************
*    Private Function Prototypes
***************************************/

static void XBEE_UART_ScbEnableIntr(void);
static void XBEE_UART_ScbModeStop(void);


/*******************************************************************************
* Function Name: XBEE_UART_Init
********************************************************************************
*
* Summary:
*  Initializes the SCB component to operate in one of the selected configurations:
*  I2C, SPI, UART or EZ I2C.
*  When the configuration is set to Unconfigured SCB, this function does
*  not do any initialization. Use mode-specific initialization APIs instead:
*  SCB_I2CInit, SCB_SpiInit, SCB_UartInit or SCB_EzI2CInit.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void XBEE_UART_Init(void)
{
#if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    if(XBEE_UART_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        XBEE_UART_initVar = 0u; /* Clear init var */
    }
    else
    {
        /* Initialization was done before call */
    }

#elif(XBEE_UART_SCB_MODE_I2C_CONST_CFG)
    XBEE_UART_I2CInit();

#elif(XBEE_UART_SCB_MODE_SPI_CONST_CFG)
    XBEE_UART_SpiInit();

#elif(XBEE_UART_SCB_MODE_UART_CONST_CFG)
    XBEE_UART_UartInit();

#elif(XBEE_UART_SCB_MODE_EZI2C_CONST_CFG)
    XBEE_UART_EzI2CInit();

#endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: XBEE_UART_Enable
********************************************************************************
*
* Summary:
*  Enables the SCB component operation.
*  The SCB configuration should be not changed when the component is enabled.
*  Any configuration changes should be made after disabling the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void XBEE_UART_Enable(void)
{
#if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Enable SCB block, only if it is already configured */
    if(!XBEE_UART_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        XBEE_UART_CTRL_REG |= XBEE_UART_CTRL_ENABLED;

        XBEE_UART_ScbEnableIntr();
    }
#else
    XBEE_UART_CTRL_REG |= XBEE_UART_CTRL_ENABLED;

    XBEE_UART_ScbEnableIntr();
#endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: XBEE_UART_Start
********************************************************************************
*
* Summary:
*  Invokes SCB_Init() and SCB_Enable().
*  After this function call, the component is enabled and ready for operation.
*  When configuration is set to Unconfigured SCB, the component must first be
*  initialized to operate in one of the following configurations: I2C, SPI, UART
*  or EZ I2C. Otherwise this function does not enable the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  XBEE_UART_initVar - used to check initial configuration, modified
*  on first function call.
*
*******************************************************************************/
void XBEE_UART_Start(void)
{
    if(0u == XBEE_UART_initVar)
    {
        XBEE_UART_Init();
        XBEE_UART_initVar = 1u; /* Component was initialized */
    }

    XBEE_UART_Enable();
}


/*******************************************************************************
* Function Name: XBEE_UART_Stop
********************************************************************************
*
* Summary:
*  Disables the SCB component and its interrupt.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void XBEE_UART_Stop(void)
{
#if(XBEE_UART_SCB_IRQ_INTERNAL)
    XBEE_UART_DisableInt();
#endif /* (XBEE_UART_SCB_IRQ_INTERNAL) */

    XBEE_UART_CTRL_REG &= (uint32) ~XBEE_UART_CTRL_ENABLED;  /* Disable SCB block */

#if(XBEE_UART_SCB_IRQ_INTERNAL)
    XBEE_UART_ClearPendingInt();
#endif /* (XBEE_UART_SCB_IRQ_INTERNAL) */

    XBEE_UART_ScbModeStop(); /* Calls scbMode specific Stop function */
}


/*******************************************************************************
* Function Name: XBEE_UART_SetCustomInterruptHandler
********************************************************************************
*
* Summary:
*  Registers a function to be called by the internal interrupt handler.
*  First the function that is registered is called, then the internal interrupt
*  handler performs any operations such as software buffer management functions
*  before the interrupt returns.  It is the user's responsibility not to break the
*  software buffer operations. Only one custom handler is supported, which is
*  the function provided by the most recent call.
*  At initialization time no custom handler is registered.
*
* Parameters:
*  func: Pointer to the function to register.
*        The value NULL indicates to remove the current custom interrupt
*        handler.
*
* Return:
*  None
*
*******************************************************************************/
void XBEE_UART_SetCustomInterruptHandler(cyisraddress func)
{
#if !defined (CY_REMOVE_XBEE_UART_CUSTOM_INTR_HANDLER)
    XBEE_UART_customIntrHandler = func; /* Register interrupt handler */
#else
    if(NULL != func)
    {
        /* Suppress compiler warning */
    }
#endif /* !defined (CY_REMOVE_XBEE_UART_CUSTOM_INTR_HANDLER) */
}


/*******************************************************************************
* Function Name: XBEE_UART_ScbModeEnableIntr
********************************************************************************
*
* Summary:
*  Enables an interrupt for a specific mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
static void XBEE_UART_ScbEnableIntr(void)
{
#if(XBEE_UART_SCB_IRQ_INTERNAL)
    #if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Enable interrupt in the NVIC */
        if(0u != XBEE_UART_scbEnableIntr)
        {
            XBEE_UART_EnableInt();
        }
    #else
        XBEE_UART_EnableInt();

    #endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */
#endif /* (XBEE_UART_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: XBEE_UART_ScbModeStop
********************************************************************************
*
* Summary:
*  Calls the Stop function for a specific operation mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
static void XBEE_UART_ScbModeStop(void)
{
#if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    if(XBEE_UART_SCB_MODE_I2C_RUNTM_CFG)
    {
        XBEE_UART_I2CStop();
    }
    else if(XBEE_UART_SCB_MODE_EZI2C_RUNTM_CFG)
    {
        XBEE_UART_EzI2CStop();
    }
    else
    {
        /* Do nohing for other modes */
    }
#elif(XBEE_UART_SCB_MODE_I2C_CONST_CFG)
    XBEE_UART_I2CStop();

#elif(XBEE_UART_SCB_MODE_EZI2C_CONST_CFG)
    XBEE_UART_EzI2CStop();

#endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


#if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    /*******************************************************************************
    * Function Name: XBEE_UART_SetPins
    ********************************************************************************
    *
    * Summary:
    *  Sets the pins settings accordingly to the selected operation mode.
    *  Only available in the Unconfigured operation mode. The mode specific
    *  initialization function calls it.
    *  Pins configuration is set by PSoC Creator when a specific mode of operation
    *  is selected in design time.
    *
    * Parameters:
    *  mode:      Mode of SCB operation.
    *  subMode:   Sub-mode of SCB operation. It is only required for SPI and UART
    *             modes.
    *  uartTxRx:  Direction for UART.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void XBEE_UART_SetPins(uint32 mode, uint32 subMode, uint32 uartTxRx)
    {
        uint32 hsiomSel [XBEE_UART_SCB_PINS_NUMBER];
        uint32 pinsDm   [XBEE_UART_SCB_PINS_NUMBER];
        uint32 pinsInBuf = 0u;

        uint32 i;

        /* Set default HSIOM to GPIO and Drive Mode to Analog Hi-Z */
        for(i = 0u; i < XBEE_UART_SCB_PINS_NUMBER; i++)
        {
            hsiomSel[i]  = XBEE_UART_HSIOM_DEF_SEL;
            pinsDm[i]    = XBEE_UART_PIN_DM_ALG_HIZ;
        }

        if((XBEE_UART_SCB_MODE_I2C   == mode) ||
           (XBEE_UART_SCB_MODE_EZI2C == mode))
        {
            hsiomSel[XBEE_UART_MOSI_SCL_RX_PIN_INDEX] = XBEE_UART_HSIOM_I2C_SEL;
            hsiomSel[XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_HSIOM_I2C_SEL;

            pinsDm[XBEE_UART_MOSI_SCL_RX_PIN_INDEX] = XBEE_UART_PIN_DM_OD_LO;
            pinsDm[XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_PIN_DM_OD_LO;
        }
    #if(!XBEE_UART_CY_SCBIP_V1_I2C_ONLY)
        else if(XBEE_UART_SCB_MODE_SPI == mode)
        {
            hsiomSel[XBEE_UART_MOSI_SCL_RX_PIN_INDEX] = XBEE_UART_HSIOM_SPI_SEL;
            hsiomSel[XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_HSIOM_SPI_SEL;
            hsiomSel[XBEE_UART_SCLK_PIN_INDEX]        = XBEE_UART_HSIOM_SPI_SEL;

            if(XBEE_UART_SPI_SLAVE == subMode)
            {
                /* Slave */
                pinsDm[XBEE_UART_MOSI_SCL_RX_PIN_INDEX] = XBEE_UART_PIN_DM_DIG_HIZ;
                pinsDm[XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_PIN_DM_STRONG;
                pinsDm[XBEE_UART_SCLK_PIN_INDEX]        = XBEE_UART_PIN_DM_DIG_HIZ;

            #if(XBEE_UART_SS0_PIN)
                /* Only SS0 is valid choice for Slave */
                hsiomSel[XBEE_UART_SS0_PIN_INDEX] = XBEE_UART_HSIOM_SPI_SEL;
                pinsDm  [XBEE_UART_SS0_PIN_INDEX] = XBEE_UART_PIN_DM_DIG_HIZ;
            #endif /* (XBEE_UART_SS1_PIN) */

            #if(XBEE_UART_MISO_SDA_TX_PIN)
                /* Disable input buffer */
                 pinsInBuf |= XBEE_UART_MISO_SDA_TX_PIN_MASK;
            #endif /* (XBEE_UART_MISO_SDA_TX_PIN_PIN) */
            }
            else /* (Master) */
            {
                pinsDm[XBEE_UART_MOSI_SCL_RX_PIN_INDEX] = XBEE_UART_PIN_DM_STRONG;
                pinsDm[XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_PIN_DM_DIG_HIZ;
                pinsDm[XBEE_UART_SCLK_PIN_INDEX]        = XBEE_UART_PIN_DM_STRONG;

            #if(XBEE_UART_SS0_PIN)
                hsiomSel [XBEE_UART_SS0_PIN_INDEX] = XBEE_UART_HSIOM_SPI_SEL;
                pinsDm   [XBEE_UART_SS0_PIN_INDEX] = XBEE_UART_PIN_DM_STRONG;
                pinsInBuf                                |= XBEE_UART_SS0_PIN_MASK;
            #endif /* (XBEE_UART_SS0_PIN) */

            #if(XBEE_UART_SS1_PIN)
                hsiomSel [XBEE_UART_SS1_PIN_INDEX] = XBEE_UART_HSIOM_SPI_SEL;
                pinsDm   [XBEE_UART_SS1_PIN_INDEX] = XBEE_UART_PIN_DM_STRONG;
                pinsInBuf                                |= XBEE_UART_SS1_PIN_MASK;
            #endif /* (XBEE_UART_SS1_PIN) */

            #if(XBEE_UART_SS2_PIN)
                hsiomSel [XBEE_UART_SS2_PIN_INDEX] = XBEE_UART_HSIOM_SPI_SEL;
                pinsDm   [XBEE_UART_SS2_PIN_INDEX] = XBEE_UART_PIN_DM_STRONG;
                pinsInBuf                                |= XBEE_UART_SS2_PIN_MASK;
            #endif /* (XBEE_UART_SS2_PIN) */

            #if(XBEE_UART_SS3_PIN)
                hsiomSel [XBEE_UART_SS3_PIN_INDEX] = XBEE_UART_HSIOM_SPI_SEL;
                pinsDm   [XBEE_UART_SS3_PIN_INDEX] = XBEE_UART_PIN_DM_STRONG;
                pinsInBuf                                |= XBEE_UART_SS3_PIN_MASK;
            #endif /* (XBEE_UART_SS2_PIN) */

                /* Disable input buffers */
            #if(XBEE_UART_MOSI_SCL_RX_PIN)
                pinsInBuf |= XBEE_UART_MOSI_SCL_RX_PIN_MASK;
            #endif /* (XBEE_UART_MOSI_SCL_RX_PIN) */

             #if(XBEE_UART_MOSI_SCL_RX_WAKE_PIN)
                pinsInBuf |= XBEE_UART_MOSI_SCL_RX_WAKE_PIN_MASK;
            #endif /* (XBEE_UART_MOSI_SCL_RX_WAKE_PIN) */

            #if(XBEE_UART_SCLK_PIN)
                pinsInBuf |= XBEE_UART_SCLK_PIN_MASK;
            #endif /* (XBEE_UART_SCLK_PIN) */
            }
        }
        else /* UART */
        {
            if(XBEE_UART_UART_MODE_SMARTCARD == subMode)
            {
                /* SmartCard */
                hsiomSel[XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_HSIOM_UART_SEL;
                pinsDm  [XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_PIN_DM_OD_LO;
            }
            else /* Standard or IrDA */
            {
                if(0u != (XBEE_UART_UART_RX & uartTxRx))
                {
                    hsiomSel[XBEE_UART_MOSI_SCL_RX_PIN_INDEX] = XBEE_UART_HSIOM_UART_SEL;
                    pinsDm  [XBEE_UART_MOSI_SCL_RX_PIN_INDEX] = XBEE_UART_PIN_DM_DIG_HIZ;
                }

                if(0u != (XBEE_UART_UART_TX & uartTxRx))
                {
                    hsiomSel[XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_HSIOM_UART_SEL;
                    pinsDm  [XBEE_UART_MISO_SDA_TX_PIN_INDEX] = XBEE_UART_PIN_DM_STRONG;

                #if(XBEE_UART_MISO_SDA_TX_PIN)
                     pinsInBuf |= XBEE_UART_MISO_SDA_TX_PIN_MASK;
                #endif /* (XBEE_UART_MISO_SDA_TX_PIN_PIN) */
                }
            }
        }
    #endif /* (!XBEE_UART_CY_SCBIP_V1_I2C_ONLY) */

    /* Configure pins: set HSIOM, DM and InputBufEnable */
    /* Note: the DR register settigns do not effect the pin output if HSIOM is other than GPIO */

    #if(XBEE_UART_MOSI_SCL_RX_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_MOSI_SCL_RX_HSIOM_REG,
                                       XBEE_UART_MOSI_SCL_RX_HSIOM_MASK,
                                       XBEE_UART_MOSI_SCL_RX_HSIOM_POS,
                                       hsiomSel[XBEE_UART_MOSI_SCL_RX_PIN_INDEX]);

        XBEE_UART_spi_mosi_i2c_scl_uart_rx_SetDriveMode((uint8) pinsDm[XBEE_UART_MOSI_SCL_RX_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_mosi_i2c_scl_uart_rx_INP_DIS,
                                     XBEE_UART_spi_mosi_i2c_scl_uart_rx_MASK,
                                     (0u != (pinsInBuf & XBEE_UART_MOSI_SCL_RX_PIN_MASK)));
    #endif /* (XBEE_UART_MOSI_SCL_RX_PIN) */

    #if(XBEE_UART_MOSI_SCL_RX_WAKE_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_MOSI_SCL_RX_WAKE_HSIOM_REG,
                                       XBEE_UART_MOSI_SCL_RX_WAKE_HSIOM_MASK,
                                       XBEE_UART_MOSI_SCL_RX_WAKE_HSIOM_POS,
                                       hsiomSel[XBEE_UART_MOSI_SCL_RX_WAKE_PIN_INDEX]);

        XBEE_UART_spi_mosi_i2c_scl_uart_rx_wake_SetDriveMode((uint8)
                                                               pinsDm[XBEE_UART_MOSI_SCL_RX_WAKE_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_mosi_i2c_scl_uart_rx_wake_INP_DIS,
                                     XBEE_UART_spi_mosi_i2c_scl_uart_rx_wake_MASK,
                                     (0u != (pinsInBuf & XBEE_UART_MOSI_SCL_RX_WAKE_PIN_MASK)));

         /* Set interrupt on falling edge */
        XBEE_UART_SET_INCFG_TYPE(XBEE_UART_MOSI_SCL_RX_WAKE_INTCFG_REG,
                                        XBEE_UART_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK,
                                        XBEE_UART_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS,
                                        XBEE_UART_INTCFG_TYPE_FALLING_EDGE);
    #endif /* (XBEE_UART_MOSI_SCL_RX_WAKE_PIN) */

    #if(XBEE_UART_MISO_SDA_TX_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_MISO_SDA_TX_HSIOM_REG,
                                       XBEE_UART_MISO_SDA_TX_HSIOM_MASK,
                                       XBEE_UART_MISO_SDA_TX_HSIOM_POS,
                                       hsiomSel[XBEE_UART_MISO_SDA_TX_PIN_INDEX]);

        XBEE_UART_spi_miso_i2c_sda_uart_tx_SetDriveMode((uint8) pinsDm[XBEE_UART_MISO_SDA_TX_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_miso_i2c_sda_uart_tx_INP_DIS,
                                     XBEE_UART_spi_miso_i2c_sda_uart_tx_MASK,
                                    (0u != (pinsInBuf & XBEE_UART_MISO_SDA_TX_PIN_MASK)));
    #endif /* (XBEE_UART_MOSI_SCL_RX_PIN) */

    #if(XBEE_UART_SCLK_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_SCLK_HSIOM_REG, XBEE_UART_SCLK_HSIOM_MASK,
                                       XBEE_UART_SCLK_HSIOM_POS, hsiomSel[XBEE_UART_SCLK_PIN_INDEX]);

        XBEE_UART_spi_sclk_SetDriveMode((uint8) pinsDm[XBEE_UART_SCLK_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_sclk_INP_DIS,
                             XBEE_UART_spi_sclk_MASK,
                            (0u != (pinsInBuf & XBEE_UART_SCLK_PIN_MASK)));
    #endif /* (XBEE_UART_SCLK_PIN) */

    #if(XBEE_UART_SS0_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_SS0_HSIOM_REG, XBEE_UART_SS0_HSIOM_MASK,
                                       XBEE_UART_SS0_HSIOM_POS, hsiomSel[XBEE_UART_SS0_PIN_INDEX]);

        XBEE_UART_spi_ss0_SetDriveMode((uint8) pinsDm[XBEE_UART_SS0_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_ss0_INP_DIS,
                                     XBEE_UART_spi_ss0_MASK,
                                     (0u != (pinsInBuf & XBEE_UART_SS0_PIN_MASK)));
    #endif /* (XBEE_UART_SS1_PIN) */

    #if(XBEE_UART_SS1_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_SS1_HSIOM_REG, XBEE_UART_SS1_HSIOM_MASK,
                                       XBEE_UART_SS1_HSIOM_POS, hsiomSel[XBEE_UART_SS1_PIN_INDEX]);

        XBEE_UART_spi_ss1_SetDriveMode((uint8) pinsDm[XBEE_UART_SS1_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_ss1_INP_DIS,
                                     XBEE_UART_spi_ss1_MASK,
                                     (0u != (pinsInBuf & XBEE_UART_SS1_PIN_MASK)));
    #endif /* (XBEE_UART_SS1_PIN) */

    #if(XBEE_UART_SS2_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_SS2_HSIOM_REG, XBEE_UART_SS2_HSIOM_MASK,
                                       XBEE_UART_SS2_HSIOM_POS, hsiomSel[XBEE_UART_SS2_PIN_INDEX]);

        XBEE_UART_spi_ss2_SetDriveMode((uint8) pinsDm[XBEE_UART_SS2_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_ss2_INP_DIS,
                                     XBEE_UART_spi_ss2_MASK,
                                     (0u != (pinsInBuf & XBEE_UART_SS2_PIN_MASK)));
    #endif /* (XBEE_UART_SS2_PIN) */

    #if(XBEE_UART_SS3_PIN)
        XBEE_UART_SET_HSIOM_SEL(XBEE_UART_SS3_HSIOM_REG,  XBEE_UART_SS3_HSIOM_MASK,
                                       XBEE_UART_SS3_HSIOM_POS, hsiomSel[XBEE_UART_SS3_PIN_INDEX]);

        XBEE_UART_spi_ss3_SetDriveMode((uint8) pinsDm[XBEE_UART_SS3_PIN_INDEX]);

        XBEE_UART_SET_INP_DIS(XBEE_UART_spi_ss3_INP_DIS,
                                     XBEE_UART_spi_ss3_MASK,
                                     (0u != (pinsInBuf & XBEE_UART_SS3_PIN_MASK)));
    #endif /* (XBEE_UART_SS3_PIN) */
    }

#endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */


/* [] END OF FILE */
