/*******************************************************************************
* File Name: XBEE_UART_UART.c
* Version 1.20
*
* Description:
*  This file provides the source code to the API for the SCB Component in
*  UART mode.
*
* Note:
*
*******************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "XBEE_UART_PVT.h"
#include "XBEE_UART_SPI_UART_PVT.h"


#if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)

    /***************************************
    *  Config Structure Initialization
    ***************************************/

    const XBEE_UART_UART_INIT_STRUCT XBEE_UART_configUart =
    {
        XBEE_UART_UART_SUB_MODE,
        XBEE_UART_UART_DIRECTION,
        XBEE_UART_UART_DATA_BITS_NUM,
        XBEE_UART_UART_PARITY_TYPE,
        XBEE_UART_UART_STOP_BITS_NUM,
        XBEE_UART_UART_OVS_FACTOR,
        XBEE_UART_UART_IRDA_LOW_POWER,
        XBEE_UART_UART_MEDIAN_FILTER_ENABLE,
        XBEE_UART_UART_RETRY_ON_NACK,
        XBEE_UART_UART_IRDA_POLARITY,
        XBEE_UART_UART_DROP_ON_PARITY_ERR,
        XBEE_UART_UART_DROP_ON_FRAME_ERR,
        XBEE_UART_UART_WAKE_ENABLE,
        0u,
        NULL,
        0u,
        NULL,
        XBEE_UART_UART_MP_MODE_ENABLE,
        XBEE_UART_UART_MP_ACCEPT_ADDRESS,
        XBEE_UART_UART_MP_RX_ADDRESS,
        XBEE_UART_UART_MP_RX_ADDRESS_MASK,
        (uint32) XBEE_UART_SCB_IRQ_INTERNAL,
        XBEE_UART_UART_INTR_RX_MASK,
        XBEE_UART_UART_RX_TRIGGER_LEVEL,
        XBEE_UART_UART_INTR_TX_MASK,
        XBEE_UART_UART_TX_TRIGGER_LEVEL
    };


    /*******************************************************************************
    * Function Name: XBEE_UART_UartInit
    ********************************************************************************
    *
    * Summary:
    *  Configures the SCB for the UART operation.
    *
    * Parameters:
    *  config:  Pointer to a structure that contains the following ordered list of
    *           fields. These fields match the selections available in the
    *           customizer.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void XBEE_UART_UartInit(const XBEE_UART_UART_INIT_STRUCT *config)
    {
        if(NULL == config)
        {
            CYASSERT(0u != 0u); /* Halt execution due bad function parameter */
        }
        else
        {
            /* Configure pins */
            XBEE_UART_SetPins(XBEE_UART_SCB_MODE_UART, config->mode, config->direction);

            /* Store internal configuration */
            XBEE_UART_scbMode       = (uint8) XBEE_UART_SCB_MODE_UART;
            XBEE_UART_scbEnableWake = (uint8) config->enableWake;
            XBEE_UART_scbEnableIntr = (uint8) config->enableInterrupt;

            /* Set RX direction internal variables */
            XBEE_UART_rxBuffer      =         config->rxBuffer;
            XBEE_UART_rxDataBits    = (uint8) config->dataBits;
            XBEE_UART_rxBufferSize  = (uint8) config->rxBufferSize;

            /* Set TX direction internal variables */
            XBEE_UART_txBuffer      =         config->txBuffer;
            XBEE_UART_txDataBits    = (uint8) config->dataBits;
            XBEE_UART_txBufferSize  = (uint8) config->txBufferSize;

            /* Configure UART interface */
            if(XBEE_UART_UART_MODE_IRDA == config->mode)
            {
                /* OVS settings: IrDA */
                XBEE_UART_CTRL_REG  = ((0u != config->enableIrdaLowPower) ?
                                                (XBEE_UART_UART_GET_CTRL_OVS_IRDA_LP(config->oversample)) :
                                                (XBEE_UART_CTRL_OVS_IRDA_OVS16));
            }
            else
            {
                /* OVS settings: UART and SmartCard */
                XBEE_UART_CTRL_REG  = XBEE_UART_GET_CTRL_OVS(config->oversample);
            }

            XBEE_UART_CTRL_REG     |= XBEE_UART_GET_CTRL_ADDR_ACCEPT(config->multiprocAcceptAddr) |
                                             XBEE_UART_CTRL_UART;

            /* Configure sub-mode: UART, SmartCard or IrDA */
            XBEE_UART_UART_CTRL_REG = XBEE_UART_GET_UART_CTRL_MODE(config->mode);

            /* Configure RX direction */
            XBEE_UART_UART_RX_CTRL_REG = XBEE_UART_GET_UART_RX_CTRL_MODE(config->stopBits)              |
                                        XBEE_UART_GET_UART_RX_CTRL_POLARITY(config->enableInvertedRx)          |
                                        XBEE_UART_GET_UART_RX_CTRL_MP_MODE(config->enableMultiproc)            |
                                        XBEE_UART_GET_UART_RX_CTRL_DROP_ON_PARITY_ERR(config->dropOnParityErr) |
                                        XBEE_UART_GET_UART_RX_CTRL_DROP_ON_FRAME_ERR(config->dropOnFrameErr);

            if(XBEE_UART_UART_PARITY_NONE != config->parity)
            {
               XBEE_UART_UART_RX_CTRL_REG |= XBEE_UART_GET_UART_RX_CTRL_PARITY(config->parity) |
                                                    XBEE_UART_UART_RX_CTRL_PARITY_ENABLED;
            }

            XBEE_UART_RX_CTRL_REG      = XBEE_UART_GET_RX_CTRL_DATA_WIDTH(config->dataBits)       |
                                                XBEE_UART_GET_RX_CTRL_MEDIAN(config->enableMedianFilter) |
                                                XBEE_UART_GET_UART_RX_CTRL_ENABLED(config->direction);

            XBEE_UART_RX_FIFO_CTRL_REG = XBEE_UART_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(config->rxTriggerLevel);

            /* Configure MP address */
            XBEE_UART_RX_MATCH_REG     = XBEE_UART_GET_RX_MATCH_ADDR(config->multiprocAddr) |
                                                XBEE_UART_GET_RX_MATCH_MASK(config->multiprocAddrMask);

            /* Configure RX direction */
            XBEE_UART_UART_TX_CTRL_REG = XBEE_UART_GET_UART_TX_CTRL_MODE(config->stopBits) |
                                                XBEE_UART_GET_UART_TX_CTRL_RETRY_NACK(config->enableRetryNack);

            if(XBEE_UART_UART_PARITY_NONE != config->parity)
            {
               XBEE_UART_UART_TX_CTRL_REG |= XBEE_UART_GET_UART_TX_CTRL_PARITY(config->parity) |
                                                    XBEE_UART_UART_TX_CTRL_PARITY_ENABLED;
            }

            XBEE_UART_TX_CTRL_REG      = XBEE_UART_GET_TX_CTRL_DATA_WIDTH(config->dataBits)    |
                                                XBEE_UART_GET_UART_TX_CTRL_ENABLED(config->direction);

            XBEE_UART_TX_FIFO_CTRL_REG = XBEE_UART_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(config->txTriggerLevel);



            /* Configure interrupt with UART handler but do not enable it */
            CyIntDisable    (XBEE_UART_ISR_NUMBER);
            CyIntSetPriority(XBEE_UART_ISR_NUMBER, XBEE_UART_ISR_PRIORITY);
            (void) CyIntSetVector(XBEE_UART_ISR_NUMBER, &XBEE_UART_SPI_UART_ISR);

            /* Configure WAKE interrupt */
        #if(XBEE_UART_UART_RX_WAKEUP_IRQ)
            CyIntDisable    (XBEE_UART_RX_WAKE_ISR_NUMBER);
            CyIntSetPriority(XBEE_UART_RX_WAKE_ISR_NUMBER, XBEE_UART_RX_WAKE_ISR_PRIORITY);
            (void) CyIntSetVector(XBEE_UART_RX_WAKE_ISR_NUMBER, &XBEE_UART_UART_WAKEUP_ISR);
        #endif /* (XBEE_UART_UART_RX_WAKEUP_IRQ) */

            /* Configure interrupt sources */
            XBEE_UART_INTR_I2C_EC_MASK_REG = XBEE_UART_NO_INTR_SOURCES;
            XBEE_UART_INTR_SPI_EC_MASK_REG = XBEE_UART_NO_INTR_SOURCES;
            XBEE_UART_INTR_SLAVE_MASK_REG  = XBEE_UART_NO_INTR_SOURCES;
            XBEE_UART_INTR_MASTER_MASK_REG = XBEE_UART_NO_INTR_SOURCES;
            XBEE_UART_INTR_RX_MASK_REG     = config->rxInterruptMask;
            XBEE_UART_INTR_TX_MASK_REG     = config->txInterruptMask;

            /* Clear RX buffer indexes */
            XBEE_UART_rxBufferHead     = 0u;
            XBEE_UART_rxBufferTail     = 0u;
            XBEE_UART_rxBufferOverflow = 0u;

            /* Clrea TX buffer indexes */
            XBEE_UART_txBufferHead = 0u;
            XBEE_UART_txBufferTail = 0u;
        }
    }

#else

    /*******************************************************************************
    * Function Name: XBEE_UART_UartInit
    ********************************************************************************
    *
    * Summary:
    *  Configures the SCB for the UART operation.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void XBEE_UART_UartInit(void)
    {
        /* Configure UART interface */
        XBEE_UART_CTRL_REG = XBEE_UART_UART_DEFAULT_CTRL;

        /* Configure sub-mode: UART, SmartCard or IrDA */
        XBEE_UART_UART_CTRL_REG = XBEE_UART_UART_DEFAULT_UART_CTRL;

        /* Configure RX direction */
        XBEE_UART_UART_RX_CTRL_REG = XBEE_UART_UART_DEFAULT_UART_RX_CTRL;
        XBEE_UART_RX_CTRL_REG      = XBEE_UART_UART_DEFAULT_RX_CTRL;
        XBEE_UART_RX_FIFO_CTRL_REG = XBEE_UART_UART_DEFAULT_RX_FIFO_CTRL;
        XBEE_UART_RX_MATCH_REG     = XBEE_UART_UART_DEFAULT_RX_MATCH_REG;

        /* Configure TX direction */
        XBEE_UART_UART_TX_CTRL_REG = XBEE_UART_UART_DEFAULT_UART_TX_CTRL;
        XBEE_UART_TX_CTRL_REG      = XBEE_UART_UART_DEFAULT_TX_CTRL;
        XBEE_UART_TX_FIFO_CTRL_REG = XBEE_UART_UART_DEFAULT_TX_FIFO_CTRL;

        /* Configure interrupt with UART handler but do not enable it */
    #if(XBEE_UART_SCB_IRQ_INTERNAL)
        CyIntDisable    (XBEE_UART_ISR_NUMBER);
        CyIntSetPriority(XBEE_UART_ISR_NUMBER, XBEE_UART_ISR_PRIORITY);
        (void) CyIntSetVector(XBEE_UART_ISR_NUMBER, &XBEE_UART_SPI_UART_ISR);
    #endif /* (XBEE_UART_SCB_IRQ_INTERNAL) */

        /* Configure WAKE interrupt */
    #if(XBEE_UART_UART_RX_WAKEUP_IRQ)
        CyIntDisable    (XBEE_UART_RX_WAKE_ISR_NUMBER);
        CyIntSetPriority(XBEE_UART_RX_WAKE_ISR_NUMBER, XBEE_UART_RX_WAKE_ISR_PRIORITY);
        (void) CyIntSetVector(XBEE_UART_RX_WAKE_ISR_NUMBER, &XBEE_UART_UART_WAKEUP_ISR);
    #endif /* (XBEE_UART_UART_RX_WAKEUP_IRQ) */

        /* Configure interrupt sources */
        XBEE_UART_INTR_I2C_EC_MASK_REG = XBEE_UART_UART_DEFAULT_INTR_I2C_EC_MASK;
        XBEE_UART_INTR_SPI_EC_MASK_REG = XBEE_UART_UART_DEFAULT_INTR_SPI_EC_MASK;
        XBEE_UART_INTR_SLAVE_MASK_REG  = XBEE_UART_UART_DEFAULT_INTR_SLAVE_MASK;
        XBEE_UART_INTR_MASTER_MASK_REG = XBEE_UART_UART_DEFAULT_INTR_MASTER_MASK;
        XBEE_UART_INTR_RX_MASK_REG     = XBEE_UART_UART_DEFAULT_INTR_RX_MASK;
        XBEE_UART_INTR_TX_MASK_REG     = XBEE_UART_UART_DEFAULT_INTR_TX_MASK;

    #if(XBEE_UART_INTERNAL_RX_SW_BUFFER_CONST)
        XBEE_UART_rxBufferHead     = 0u;
        XBEE_UART_rxBufferTail     = 0u;
        XBEE_UART_rxBufferOverflow = 0u;
    #endif /* (XBEE_UART_INTERNAL_RX_SW_BUFFER_CONST) */

    #if(XBEE_UART_INTERNAL_TX_SW_BUFFER_CONST)
        XBEE_UART_txBufferHead = 0u;
        XBEE_UART_txBufferTail = 0u;
    #endif /* (XBEE_UART_INTERNAL_TX_SW_BUFFER_CONST) */
    }
#endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */


/*******************************************************************************
* Function Name: XBEE_UART_UartSetRxAddress
********************************************************************************
*
* Summary:
*  Sets the hardware detectable receiver address for the UART in the Multiprocessor
*  mode.
*
* Parameters:
*  address: Address for hardware address detection.
*
* Return:
*  None
*
*******************************************************************************/
void XBEE_UART_UartSetRxAddress(uint32 address)
{
     uint32 matchReg;

    matchReg = XBEE_UART_RX_MATCH_REG;

    matchReg &= ((uint32) ~XBEE_UART_RX_MATCH_ADDR_MASK); /* Clear address bits */
    matchReg |= ((uint32)  (address & XBEE_UART_RX_MATCH_ADDR_MASK)); /* Set address  */

    XBEE_UART_RX_MATCH_REG = matchReg;
}


/*******************************************************************************
* Function Name: XBEE_UART_UartSetRxAddressMask
********************************************************************************
*
* Summary:
*  Sets the hardware address mask for the UART in the Multiprocessor mode.
*
* Parameters:
*  addressMask: Address mask.
*   0 - address bit does not care while comparison.
*   1 - address bit is significant while comparison.
*
* Return:
*  None
*
*******************************************************************************/
void XBEE_UART_UartSetRxAddressMask(uint32 addressMask)
{
    uint32 matchReg;

    matchReg = XBEE_UART_RX_MATCH_REG;

    matchReg &= ((uint32) ~XBEE_UART_RX_MATCH_MASK_MASK); /* Clear address mask bits */
    matchReg |= ((uint32) (addressMask << XBEE_UART_RX_MATCH_MASK_POS));

    XBEE_UART_RX_MATCH_REG = matchReg;
}


#if(XBEE_UART_UART_RX_DIRECTION)
    /*******************************************************************************
    * Function Name: XBEE_UART_UartGetChar
    ********************************************************************************
    *
    * Summary:
    *  Retrieves the next data element from the receive buffer.
    *  This function is designed for ASCII characters and returns a char
    *  where 1 to 255 are valid characters and 0 indicates an error occurred or
    *  no data present.
    *  - The RX software buffer is disabled: returns the data element retrieved from the RX FIFO.
    *    Undefined data will be returned if the RX FIFO is empty.
    *  - The RX software buffer is enabled: returns the data element from the software receive
    *    buffer.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  The next data element from the receive buffer.
    *  ASCII character values from 1 to 255 are valid.
    *  A returned zero signifies an error condition or no data available.
    *
    *******************************************************************************/
    uint32 XBEE_UART_UartGetChar(void)
    {
        uint32 rxData = 0u;

        /* Read data only if there is data to read */
        if(0u != XBEE_UART_SpiUartGetRxBufferSize())
        {
            rxData = XBEE_UART_SpiUartReadRxData();
        }

        if(XBEE_UART_CHECK_INTR_RX(XBEE_UART_INTR_RX_ERR))
        {
            rxData = 0u; /* Error occurred: return zero */
            XBEE_UART_ClearRxInterruptSource(XBEE_UART_INTR_RX_ERR);
        }

        return(rxData);
    }


    /*******************************************************************************
    * Function Name: XBEE_UART_UartGetByte
    ********************************************************************************
    *
    * Summary:
    *  Retrieves the next data element from the receive buffer, returns the received byte
    *  and error condition.
    *   - The RX software buffer is disabled: returns the data element retrieved from the RX FIFO.
    *     Undefined data will be returned if the RX FIFO is empty.
    *   - The RX software buffer is enabled: returns data element from the software receive
    *     buffer.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  Bits 15-8 contains status and bits 7-0 contains the next data element from
    *  receive buffer. If the bits 15-8 are non-zero, an error has occurred.
    *
    *******************************************************************************/
    uint32 XBEE_UART_UartGetByte(void)
    {
        uint32 rxData;
        uint32 tmpStatus;
        uint32 intSourceMask;

        intSourceMask = XBEE_UART_SpiUartDisableIntRx();

        if(0u != XBEE_UART_SpiUartGetRxBufferSize())
        {
             /*
             * Enable interrupt to receive more bytes: at least one byte is in
             * buffer.
             */
            XBEE_UART_SpiUartEnableIntRx(intSourceMask);

            /* Get received byte */
            rxData = XBEE_UART_SpiUartReadRxData();
        }
        else
        {
            /*
            * Read byte directly from RX FIFO: the underflow is raised in case
            * of empty. In other case the first received byte will be read.
            */
            rxData = XBEE_UART_RX_FIFO_RD_REG;

            /*
            * Enable interrupt to receive more bytes.
            * The RX_NOT_EMPTY interrupt is cleared by the interrupt routine in case
            * the byte was received and read above.
            */
            XBEE_UART_SpiUartEnableIntRx(intSourceMask);
        }

        /* Get and clear RX error mask */
        tmpStatus = (XBEE_UART_GetRxInterruptSource() & XBEE_UART_INTR_RX_ERR);
        XBEE_UART_ClearRxInterruptSource(XBEE_UART_INTR_RX_ERR);

        /*
        * Put together data and error status:
        * MP mode and accept address: the 9th bit is set to notify mark.
        */
        rxData |= ((uint32) (tmpStatus << 8u));

        return(rxData);
    }

#endif /* (XBEE_UART_UART_RX_DIRECTION) */


#if(XBEE_UART_UART_TX_DIRECTION)
    /*******************************************************************************
    * Function Name: XBEE_UART_UartPutString
    ********************************************************************************
    *
    * Summary:
    *  Places a NULL terminated string in the transmit buffer to be sent at the
    *  next available bus time.
    *  This function is blocking and waits until there is space available to put
    *  all the requested data into the  transmit buffer.
    *
    * Parameters:
    *  string: pointer to the null terminated string array to be placed in the
    *          transmit buffer.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void XBEE_UART_UartPutString(const char8 string[])
    {
        uint32 bufIndex;

        bufIndex = 0u;

        /* Block the control flow until all data has been sent */
        while(string[bufIndex] != ((char8) 0))
        {
            XBEE_UART_UartPutChar((uint32) string[bufIndex]);
            bufIndex++;
        }
    }


    /*******************************************************************************
    * Function Name: XBEE_UART_UartPutCRLF
    ********************************************************************************
    *
    * Summary:
    *  Places a byte of data followed by a carriage return (0x0D) and line feed (0x0A)
    *  into the transmit buffer.
    *  This function is blocking and waits until there is space available to put
    *  all the requested data into the  transmit buffer.
    *
    * Parameters:
    *  txDataByte : the data to be transmitted.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void XBEE_UART_UartPutCRLF(uint32 txDataByte)
    {
        XBEE_UART_UartPutChar(txDataByte);  /* Blocks control flow until all data has been sent */
        XBEE_UART_UartPutChar(0x0Du);       /* Blocks control flow until all data has been sent */
        XBEE_UART_UartPutChar(0x0Au);       /* Blocks control flow until all data has been sent */
    }
#endif /* (XBEE_UART_UART_TX_DIRECTION) */


#if(XBEE_UART_UART_WAKE_ENABLE_CONST)
    /*******************************************************************************
    * Function Name: XBEE_UART_UartSaveConfig
    ********************************************************************************
    *
    * Summary:
    *  Clears and enables interrupt on a falling edge of the Rx input. The GPIO
    *  event wakes up the device and SKIP_START feature allows the UART continue
    *  receiving data bytes properly. The GPIO interrupt does not track in the active
    *  mode therefore requires to be cleared by this API.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void XBEE_UART_UartSaveConfig(void)
    {
        /* Clear interrupt activity:
        *  - set skip start and disable RX. On GPIO wakeup RX will be enabled.
        *  - clear rx_wake interrupt source as it triggers during normal operation.
        *  - clear wake interrupt pending state as it becomes pending in active mode.
        */

        XBEE_UART_UART_RX_CTRL_REG |= XBEE_UART_UART_RX_CTRL_SKIP_START;

    #if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
        #if(XBEE_UART_MOSI_SCL_RX_WAKE_PIN)
            (void) XBEE_UART_spi_mosi_i2c_scl_uart_rx_wake_ClearInterrupt();
        #endif /* (XBEE_UART_MOSI_SCL_RX_WAKE_PIN) */
    #else
        #if(XBEE_UART_UART_RX_WAKE_PIN)
            (void) XBEE_UART_rx_wake_ClearInterrupt();
        #endif /* (XBEE_UART_UART_RX_WAKE_PIN) */
    #endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */

    #if(XBEE_UART_UART_RX_WAKEUP_IRQ)
        XBEE_UART_RxWakeClearPendingInt();
        XBEE_UART_RxWakeEnableInt();
    #endif /* (XBEE_UART_UART_RX_WAKEUP_IRQ) */
    }


    /*******************************************************************************
    * Function Name: XBEE_UART_UartRestoreConfig
    ********************************************************************************
    *
    * Summary:
    *  Disables the RX GPIO interrupt. Until this function is called the interrupt remains
    *  active and triggers on every falling edge of the UART RX line.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void XBEE_UART_UartRestoreConfig(void)
    {
    /* Disable RX GPIO interrupt: no more triggers in active mode */
    #if(XBEE_UART_UART_RX_WAKEUP_IRQ)
        XBEE_UART_RxWakeDisableInt();
    #endif /* (XBEE_UART_UART_RX_WAKEUP_IRQ) */
    }
#endif /* (XBEE_UART_UART_WAKE_ENABLE_CONST) */


#if(XBEE_UART_UART_RX_WAKEUP_IRQ)
    /*******************************************************************************
    * Function Name: XBEE_UART_UART_WAKEUP_ISR
    ********************************************************************************
    *
    * Summary:
    *  Handles the Interrupt Service Routine for the SCB UART mode GPIO wakeup event. This
    *  event is configured to trigger on a falling edge of the RX line.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    CY_ISR(XBEE_UART_UART_WAKEUP_ISR)
    {
        /* Clear interrupt source: the event becomes multi triggered and is only disabled
        * by XBEE_UART_UartRestoreConfig() call.
        */
    #if(XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG)
        #if(XBEE_UART_MOSI_SCL_RX_WAKE_PIN)
            (void) XBEE_UART_spi_mosi_i2c_scl_uart_rx_wake_ClearInterrupt();
        #endif /* (XBEE_UART_MOSI_SCL_RX_WAKE_PIN) */
    #else
        #if(XBEE_UART_UART_RX_WAKE_PIN)
            (void) XBEE_UART_rx_wake_ClearInterrupt();
        #endif /* (XBEE_UART_UART_RX_WAKE_PIN) */
    #endif /* (XBEE_UART_SCB_MODE_UNCONFIG_CONST_CFG) */
    }
#endif /* (XBEE_UART_UART_RX_WAKEUP_IRQ) */


/* [] END OF FILE */
