/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <cytypes.h>

//Caracteres de escape, dados por el API utilizado//
#define ESCAPE1     0x7E
#define ESCAPE2     0x7D
#define ESCAPE3     0x11
#define ESCAPE4     0x13
#define PLCHEADER   0x02
#define PLCTAIL     0x03

// { FRAME HEAD, API ID, FRAME ID, OPTIONS }
static uint8 xbee_settings[5] = {0x7E, 0x00, 0x01, 0x04, '\0'}; // 
// BROAD CAST ADDRESS
static uint8 broadcast[9] = {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, '\0'}; // 
// frame de enviado
static uint8 xbee_status [7] = {0x00, 0x03, 0x89, 0x01, 0x00, 0x75, '\0'}; 

char XBeeRXbuffer[100];
char XBeeTXbuffer[100];
char PLCRXbuffer[100];
char PLCTXbuffer[100];

uint8 XBEERXOK;
uint8 XBEETXOK;
uint8 PLCRXOK;
uint8 PLCTXOK;

void sys_init(void);
void PLCPacketHandler(void);
void XBeePacketHandler(void);
int send_data();
uint8* scape_frame(uint8 *frame, uint8 *length);
void check_akw();

static uint8 tmp[14] = {'l','i','n','o',' ','e','s',' ','p','u','t','o','\r','\n'};

int main()
{
    XBEERXOK = 0;
    XBEETXOK = 0;
    PLCRXOK = 0;
    PLCTXOK = 0;
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
    sys_init();

    for(;;)
    {
        if(XBEERXOK)
        {
            XBEE_UART_DisableInt();
            CyDelayUs(500);
            PLC_UART_EnableInt();
            CyDelayUs(500);
            PLC_UART_UartPutChar('\n');
            CyDelay(1);
            PLC_UART_UartPutChar('\n');
            CyDelay(1);
            PLC_UART_UartPutString(XBeeRXbuffer);
            XBEERXOK = 0;
        }
        if(PLCRXOK)
        {
            PLC_UART_DisableInt();
            strcpy(XBeeTXbuffer, PLCRXbuffer);
            CyDelayUs(500);
            CyDelayUs(20);
            send_data(); //Envia frame al XB
            XBEE_UART_EnableInt();
            PLCRXOK = 0;
        }
    }
}

void sys_init(void)
{
    CyDelay(2000);
	XBEE_UART_Start();
    PLC_UART_Start();
    
    CyDelay(100);
    PLC_UART_UartPutString("Configurando");
    CyDelayUs(500);
    
    PLC_UART_SetCustomInterruptHandler(&PLCPacketHandler);
    PLC_UART_DisableInt();
    XBEE_UART_SetCustomInterruptHandler(&XBeePacketHandler);
    
	CyGlobalIntEnable;
}

void PLCPacketHandler(void)
{
    uint8 tempchar;
    int i=0, start=0;
    if(PLC_UART_INTR_CAUSE_RX & PLC_UART_GetInterruptCause())
	{
        for(;;)
        {
            while(PLC_UART_SpiUartGetRxBufferSize() == 0)
                CyDelayUs(100);
            tempchar = PLC_UART_UartGetChar(); // toma el dato del PLC
            
            if(start)
            {
                PLCRXbuffer[i] = tempchar;
                if(tempchar == 0x03)
                {
                    PLCRXbuffer[i+1] = '\0';
                    PLCRXOK = 1;
                    PLC_UART_ClearRxInterruptSource(PLC_UART_INTR_RX_NOT_EMPTY);
                    return;
                }
                i++;
            }
            else
            {
                if(tempchar == 0x02)
                {
                    start = 1;
                    PLCRXbuffer[i] = tempchar;
                    i++;
                }
            }
        }
          
    }
}

void XBeePacketHandler(void)
{
    uint8 tempchar, escaped=0, rssi=0, broadcast=0, checksum=0, rfchecksum=0, api_id=0, xbee_checksum=0;
    int i=0, j=0, k=0;
    uint16 length=0;
	/* Check interrupt source*/
	if(XBEE_UART_INTR_CAUSE_RX & XBEE_UART_GetInterruptCause())
	{	
        //HEADER
        while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
            CyDelayUs(100);
        tempchar = XBEE_UART_UartGetChar(); // toma el dato del xbee
        if( tempchar == 0x7E ) // compara el dato empieza con la cabecera del xbee 7E
        {
            CyDelayUs(100);
            while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                CyDelayUs(100);
            tempchar = XBEE_UART_UartGetChar();
            
            //LENGTH
            length = (length | tempchar) << 8; //hace una or con tempchar y lenght y lo recorre 8 lugares
            while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                CyDelayUs(100);
            tempchar = XBEE_UART_UartGetChar();
            length = length | tempchar;
            
            //API ID
            while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                CyDelayUs(100);
            tempchar = XBEE_UART_UartGetChar();
            api_id = tempchar;
            checksum = checksum+tempchar;
            if(api_id == 0x80)
            {
                //MSB ADDRESS (Most Significant Byte)
                for(i=3; i >= 0; i--, j++)
                {       
                    while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                        CyDelayUs(100);
                    tempchar = XBEE_UART_UartGetChar();
                    if( tempchar == 0x7D )
                    {
                        while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                            CyDelayUs(100);
                        tempchar = XBEE_UART_UartGetChar();
                        tempchar = tempchar^0x20;
                        checksum = checksum+tempchar;
                        ++escaped;
                    }
                    else
                        checksum = checksum+tempchar;
                }
                
                //LSB ADDRESS (Least Significant Byte)
                for(i=3; i >= 0; i--, j++)
                {    
                    while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                        CyDelayUs(100);
                    tempchar = XBEE_UART_UartGetChar();
                    if( tempchar == 0x7D )
                    {
                        
                        while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                            CyDelayUs(100);
                        tempchar = XBEE_UART_UartGetChar();
                        tempchar = tempchar^0x20;
                        checksum = checksum+tempchar;
                        ++escaped;
                    }
                    else
                        checksum = checksum+tempchar;
                }
                
                //RSSI
                while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                    CyDelayUs(100);
                tempchar = XBEE_UART_UartGetChar();
                if( tempchar == 0x7D )
                {
                    
                    while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                        CyDelayUs(100);
                    tempchar = XBEE_UART_UartGetChar();
                    tempchar = tempchar^0x20;
                    checksum = checksum+tempchar;
                    ++escaped;
                }
                else
                    checksum = checksum+tempchar;
                rssi = tempchar;
                ++j;
                
                //BROADCAST
                while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                    CyDelayUs(100);
                tempchar = XBEE_UART_UartGetChar();
                if( tempchar == 0x7D )
                {
                    while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                    CyDelayUs(100);
                    tempchar = XBEE_UART_UartGetChar();
                    tempchar = tempchar^0x20;
                    checksum = checksum+tempchar;
                }
                else
                    checksum = checksum+tempchar;
                broadcast = 0x0F & tempchar;
                ++j;                
                
                //*************
                // DATA
                //*************
                k = length - 11;
                for(i=0; i < k; i++)
                {
                    while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                    CyDelayUs(100);
                    tempchar = XBEE_UART_UartGetChar();
                    if( tempchar == 0x7D )
                    {
                        
                        while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                            CyDelayUs(100);
                        tempchar = XBEE_UART_UartGetChar();
                        tempchar = tempchar^0x20;
                        checksum = checksum+tempchar;
                        ++escaped;
                    }
                    else
                        checksum = checksum+tempchar;
                    XBeeRXbuffer[i] = tempchar;
                }
                if(XBeeRXbuffer[0] == PLCHEADER && XBeeRXbuffer[k-1] == PLCTAIL )
                    XBEERXOK = 1;
                XBeeRXbuffer[k] = '\0';
                //++++++++++++++++++++++++++++++++++++++++++++++++++
                
                while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
                    CyDelayUs(100);
                tempchar = XBEE_UART_UartGetChar();
                
                rfchecksum = tempchar;
                checksum = 0xFF - checksum;            
                
                if( rfchecksum != checksum)
                {
                    RedLed_Write(1);
                    CyDelay(200);
                    RedLed_Write(0);
                    XBEERXOK = 0;
                }
                else
                {
                    if(XBEERXOK)
                        GreenLed_Write(1);
                    else
                        RedLed_Write(1);
                        
                    CyDelay(200);
                    GreenLed_Write(0);
                    RedLed_Write(0);
                }
            }
        }
        CyDelay(1);
        XBEE_UART_ClearRxInterruptSource(XBEE_UART_INTR_RX_NOT_EMPTY);
    }
}

int send_data()
{  
   uint8 *frame, *scaped_frame;
   int i, k; //variables enteras 
   uint8 checksumxbee, length_data, frame_size; //se declan mas variables para formar la trama del xbee
   
   length_data = checksumxbee = 0;
   
   length_data = strlen(XBeeTXbuffer); //strlen mide la cantidad de caracteres de DATA que sera igual a 5
   frame_size = 15 + length_data; //se le suma el lenght_data para calcular el tamaño del frame , 15 deconfiguracion +´5 de datos
   frame = (uint8*) malloc(sizeof(uint8)*frame_size);// RESERVAR LA MEMORIA DINAMICA
   
   //Frame init, Bite 1//
   frame[0] = xbee_settings[0];
   
   //Frame length Byte 2-3//
   frame[1] = 0x00;
   frame[2] = frame_size - 4; // MENOS CABECERA , 2 DE TAMAÑO DE PAQUETE Y CHEKSUN
   
   //ApiFrame,Byte 4//
   frame[3] = xbee_settings[1];
   checksumxbee += xbee_settings[1];
   
   //Frame ID for Response//
   frame[4] = xbee_settings[2]; 
   checksumxbee += xbee_settings[2];
   
   //Destination MAC Address//
   for(i = 5; i < 13; i++) //i igual a 5, el for se complira hata que llegue a 13
   {
      frame[i] = broadcast[i-5];
      checksumxbee += broadcast[i-5];
   }
   
   //Setting options
   frame[13] = xbee_settings[3];
   checksumxbee += xbee_settings[3];
   
   
   //**Data**//
   for(i=14; i < 14+length_data; i++)
   {
      frame[i] = XBeeTXbuffer[i-14];
      checksumxbee += XBeeTXbuffer[i-14];
   }
   
   //****//x
   
   checksumxbee = 0xFF - checksumxbee;
   
   frame[14 + length_data] = checksumxbee;
   
   scaped_frame = scape_frame(frame, &frame_size);
   
   if (scaped_frame != 0 )
   {
      free(frame);
      frame = scaped_frame;
   }
   for(k = 0; k < frame_size; k++)
   {
      XBEE_UART_UartPutChar(frame[k]);
      CyDelay(50);
   }
   
   return 0;
}

uint8* scape_frame(uint8 *frame, uint8 *length)
{
   int count = 0, i , j;
   uint8 *escaped_frame;
   
   for (i=3; i < *length-1; i++)
   {
      if (frame[i] == ESCAPE1 || frame[i] == ESCAPE2 || frame[i] == ESCAPE3 || frame[i] == ESCAPE4) // se le hace una or a cada escape del frame
         ++count;
   }
   
   if (count > 0)
   {
      escaped_frame = (uint8*)malloc (sizeof(char)*(*length + count));
      escaped_frame[0] = frame[0];
      escaped_frame[1] = frame[1];
      escaped_frame[2] = frame[2];
      
      for(i=3, j=3; i < *length-1; i++, j++)
      {
         if( frame[i] == ESCAPE1 || frame[i] == ESCAPE2 || frame[i] == ESCAPE3 || frame[i] == ESCAPE4 )
         {
            escaped_frame[j] = 0x7D;
            ++j;
            escaped_frame[j] = frame[i]^0x20;
         }
         else
            escaped_frame[j] = frame[i];
      }
       escaped_frame[j] = frame[i];
      *length = *length+count;
      }
      if( !count )
         return 0;
      else
         return escaped_frame;

}

// recivir el frame de status del xbee
void check_akw()
{
   uint8 mybyte, i, cont=0; // constasntes y contador a cero
   
   do //espera a que llegue la cabecera 
   {
        if(cont > 20) //si el contador es mayor a cero
        return; //regresa
      
        while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
            CyDelayUs(100);
        mybyte = XBEE_UART_UartGetChar(); //lee el caracter y lo asigna a mybyte
        XBEE_UART_SpiUartClearRxBuffer();
    
        ++cont;
  
    } while(mybyte != 0x7E); //si el caracter no es 0x7E que es la cabecera, hace el Do
   XBeeTXbuffer[0] = mybyte;
   for(i=0; i < 7; i++)
   {
      
        while(XBEE_UART_SpiUartGetRxBufferSize() == 0)
            CyDelayUs(100);
        mybyte = XBEE_UART_UartGetChar();
        XBeeTXbuffer[i+1] = mybyte;
        if(mybyte != xbee_status[i])
        {
            XBeeTXbuffer[i+2] = '\0';
            PLC_UART_UartPutString(XBeeTXbuffer);
            return;
        }
   }
   
}