/*******************************************************************************
* File Name: IntLed.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "IntLed.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        IntLed_PC =   (IntLed_PC & \
                                (uint32)(~(uint32)(IntLed_DRIVE_MODE_IND_MASK << (IntLed_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (IntLed_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: IntLed_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void IntLed_Write(uint8 value) 
{
    uint8 drVal = (uint8)(IntLed_DR & (uint8)(~IntLed_MASK));
    drVal = (drVal | ((uint8)(value << IntLed_SHIFT) & IntLed_MASK));
    IntLed_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: IntLed_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  IntLed_DM_STRONG     Strong Drive 
*  IntLed_DM_OD_HI      Open Drain, Drives High 
*  IntLed_DM_OD_LO      Open Drain, Drives Low 
*  IntLed_DM_RES_UP     Resistive Pull Up 
*  IntLed_DM_RES_DWN    Resistive Pull Down 
*  IntLed_DM_RES_UPDWN  Resistive Pull Up/Down 
*  IntLed_DM_DIG_HIZ    High Impedance Digital 
*  IntLed_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void IntLed_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(IntLed__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: IntLed_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro IntLed_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 IntLed_Read(void) 
{
    return (uint8)((IntLed_PS & IntLed_MASK) >> IntLed_SHIFT);
}


/*******************************************************************************
* Function Name: IntLed_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 IntLed_ReadDataReg(void) 
{
    return (uint8)((IntLed_DR & IntLed_MASK) >> IntLed_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(IntLed_INTSTAT) 

    /*******************************************************************************
    * Function Name: IntLed_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 IntLed_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(IntLed_INTSTAT & IntLed_MASK);
		IntLed_INTSTAT = maskedStatus;
        return maskedStatus >> IntLed_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
