/*******************************************************************************
* File Name: PLCTimer.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the PLCTimer
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_PLCTimer_H)
#define CY_TCPWM_PLCTimer_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} PLCTimer_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  PLCTimer_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define PLCTimer_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define PLCTimer_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define PLCTimer_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define PLCTimer_QUAD_ENCODING_MODES            (0lu)

/* Signal modes */
#define PLCTimer_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define PLCTimer_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define PLCTimer_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define PLCTimer_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define PLCTimer_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define PLCTimer_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define PLCTimer_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define PLCTimer_TC_RUN_MODE                    (1lu)
#define PLCTimer_TC_COUNTER_MODE                (1lu)
#define PLCTimer_TC_COMP_CAP_MODE               (2lu)
#define PLCTimer_TC_PRESCALER                   (5lu)

/* Signal modes */
#define PLCTimer_TC_RELOAD_SIGNAL_MODE          (0lu)
#define PLCTimer_TC_COUNT_SIGNAL_MODE           (3lu)
#define PLCTimer_TC_START_SIGNAL_MODE           (0lu)
#define PLCTimer_TC_STOP_SIGNAL_MODE            (0lu)
#define PLCTimer_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define PLCTimer_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define PLCTimer_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define PLCTimer_TC_START_SIGNAL_PRESENT        (0lu)
#define PLCTimer_TC_STOP_SIGNAL_PRESENT         (0lu)
#define PLCTimer_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PLCTimer_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define PLCTimer_PWM_KILL_EVENT                 (0lu)
#define PLCTimer_PWM_STOP_EVENT                 (0lu)
#define PLCTimer_PWM_MODE                       (4lu)
#define PLCTimer_PWM_OUT_N_INVERT               (0lu)
#define PLCTimer_PWM_OUT_INVERT                 (0lu)
#define PLCTimer_PWM_ALIGN                      (0lu)
#define PLCTimer_PWM_RUN_MODE                   (0lu)
#define PLCTimer_PWM_DEAD_TIME_CYCLE            (0lu)
#define PLCTimer_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define PLCTimer_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define PLCTimer_PWM_COUNT_SIGNAL_MODE          (3lu)
#define PLCTimer_PWM_START_SIGNAL_MODE          (0lu)
#define PLCTimer_PWM_STOP_SIGNAL_MODE           (0lu)
#define PLCTimer_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define PLCTimer_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define PLCTimer_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define PLCTimer_PWM_START_SIGNAL_PRESENT       (0lu)
#define PLCTimer_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define PLCTimer_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PLCTimer_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define PLCTimer_TC_PERIOD_VALUE                (65535lu)
#define PLCTimer_TC_COMPARE_VALUE               (65535lu)
#define PLCTimer_TC_COMPARE_BUF_VALUE           (65535lu)
#define PLCTimer_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define PLCTimer_PWM_PERIOD_VALUE               (65535lu)
#define PLCTimer_PWM_PERIOD_BUF_VALUE           (65535lu)
#define PLCTimer_PWM_PERIOD_SWAP                (0lu)
#define PLCTimer_PWM_COMPARE_VALUE              (65535lu)
#define PLCTimer_PWM_COMPARE_BUF_VALUE          (65535lu)
#define PLCTimer_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define PLCTimer__LEFT 0
#define PLCTimer__RIGHT 1
#define PLCTimer__CENTER 2
#define PLCTimer__ASYMMETRIC 3

#define PLCTimer__X1 0
#define PLCTimer__X2 1
#define PLCTimer__X4 2

#define PLCTimer__PWM 4
#define PLCTimer__PWM_DT 5
#define PLCTimer__PWM_PR 6

#define PLCTimer__INVERSE 1
#define PLCTimer__DIRECT 0

#define PLCTimer__CAPTURE 2
#define PLCTimer__COMPARE 0

#define PLCTimer__TRIG_LEVEL 3
#define PLCTimer__TRIG_RISING 0
#define PLCTimer__TRIG_FALLING 1
#define PLCTimer__TRIG_BOTH 2

#define PLCTimer__INTR_MASK_TC 1
#define PLCTimer__INTR_MASK_CC_MATCH 2
#define PLCTimer__INTR_MASK_NONE 0
#define PLCTimer__INTR_MASK_TC_CC 3

#define PLCTimer__UNCONFIG 8
#define PLCTimer__TIMER 1
#define PLCTimer__QUAD 3
#define PLCTimer__PWM_SEL 7

#define PLCTimer__COUNT_UP 0
#define PLCTimer__COUNT_DOWN 1
#define PLCTimer__COUNT_UPDOWN0 2
#define PLCTimer__COUNT_UPDOWN1 3


/* Prescaler */
#define PLCTimer_PRESCALE_DIVBY1                ((uint32)(0u << PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_PRESCALE_DIVBY2                ((uint32)(1u << PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_PRESCALE_DIVBY4                ((uint32)(2u << PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_PRESCALE_DIVBY8                ((uint32)(3u << PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_PRESCALE_DIVBY16               ((uint32)(4u << PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_PRESCALE_DIVBY32               ((uint32)(5u << PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_PRESCALE_DIVBY64               ((uint32)(6u << PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_PRESCALE_DIVBY128              ((uint32)(7u << PLCTimer_PRESCALER_SHIFT))

/* TCPWM set modes */
#define PLCTimer_MODE_TIMER_COMPARE             ((uint32)(PLCTimer__COMPARE         <<  \
                                                                  PLCTimer_MODE_SHIFT))
#define PLCTimer_MODE_TIMER_CAPTURE             ((uint32)(PLCTimer__CAPTURE         <<  \
                                                                  PLCTimer_MODE_SHIFT))
#define PLCTimer_MODE_QUAD                      ((uint32)(PLCTimer__QUAD            <<  \
                                                                  PLCTimer_MODE_SHIFT))
#define PLCTimer_MODE_PWM                       ((uint32)(PLCTimer__PWM             <<  \
                                                                  PLCTimer_MODE_SHIFT))
#define PLCTimer_MODE_PWM_DT                    ((uint32)(PLCTimer__PWM_DT          <<  \
                                                                  PLCTimer_MODE_SHIFT))
#define PLCTimer_MODE_PWM_PR                    ((uint32)(PLCTimer__PWM_PR          <<  \
                                                                  PLCTimer_MODE_SHIFT))

/* Quad Modes */
#define PLCTimer_MODE_X1                        ((uint32)(PLCTimer__X1              <<  \
                                                                  PLCTimer_QUAD_MODE_SHIFT))
#define PLCTimer_MODE_X2                        ((uint32)(PLCTimer__X2              <<  \
                                                                  PLCTimer_QUAD_MODE_SHIFT))
#define PLCTimer_MODE_X4                        ((uint32)(PLCTimer__X4              <<  \
                                                                  PLCTimer_QUAD_MODE_SHIFT))

/* Counter modes */
#define PLCTimer_COUNT_UP                       ((uint32)(PLCTimer__COUNT_UP        <<  \
                                                                  PLCTimer_UPDOWN_SHIFT))
#define PLCTimer_COUNT_DOWN                     ((uint32)(PLCTimer__COUNT_DOWN      <<  \
                                                                  PLCTimer_UPDOWN_SHIFT))
#define PLCTimer_COUNT_UPDOWN0                  ((uint32)(PLCTimer__COUNT_UPDOWN0   <<  \
                                                                  PLCTimer_UPDOWN_SHIFT))
#define PLCTimer_COUNT_UPDOWN1                  ((uint32)(PLCTimer__COUNT_UPDOWN1   <<  \
                                                                  PLCTimer_UPDOWN_SHIFT))

/* PWM output invert */
#define PLCTimer_INVERT_LINE                    ((uint32)(PLCTimer__INVERSE         <<  \
                                                                  PLCTimer_INV_OUT_SHIFT))
#define PLCTimer_INVERT_LINE_N                  ((uint32)(PLCTimer__INVERSE         <<  \
                                                                  PLCTimer_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define PLCTimer_TRIG_RISING                    ((uint32)PLCTimer__TRIG_RISING)
#define PLCTimer_TRIG_FALLING                   ((uint32)PLCTimer__TRIG_FALLING)
#define PLCTimer_TRIG_BOTH                      ((uint32)PLCTimer__TRIG_BOTH)
#define PLCTimer_TRIG_LEVEL                     ((uint32)PLCTimer__TRIG_LEVEL)

/* Interrupt mask */
#define PLCTimer_INTR_MASK_TC                   ((uint32)PLCTimer__INTR_MASK_TC)
#define PLCTimer_INTR_MASK_CC_MATCH             ((uint32)PLCTimer__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define PLCTimer_CC_MATCH_SET                   (0x00u)
#define PLCTimer_CC_MATCH_CLEAR                 (0x01u)
#define PLCTimer_CC_MATCH_INVERT                (0x02u)
#define PLCTimer_CC_MATCH_NO_CHANGE             (0x03u)
#define PLCTimer_OVERLOW_SET                    (0x00u)
#define PLCTimer_OVERLOW_CLEAR                  (0x04u)
#define PLCTimer_OVERLOW_INVERT                 (0x08u)
#define PLCTimer_OVERLOW_NO_CHANGE              (0x0Cu)
#define PLCTimer_UNDERFLOW_SET                  (0x00u)
#define PLCTimer_UNDERFLOW_CLEAR                (0x10u)
#define PLCTimer_UNDERFLOW_INVERT               (0x20u)
#define PLCTimer_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define PLCTimer_PWM_MODE_LEFT                  (PLCTimer_CC_MATCH_CLEAR        |   \
                                                         PLCTimer_OVERLOW_SET           |   \
                                                         PLCTimer_UNDERFLOW_NO_CHANGE)
#define PLCTimer_PWM_MODE_RIGHT                 (PLCTimer_CC_MATCH_SET          |   \
                                                         PLCTimer_OVERLOW_NO_CHANGE     |   \
                                                         PLCTimer_UNDERFLOW_CLEAR)
#define PLCTimer_PWM_MODE_ASYM                  (PLCTimer_CC_MATCH_INVERT       |   \
                                                         PLCTimer_OVERLOW_SET           |   \
                                                         PLCTimer_UNDERFLOW_CLEAR)

#if (PLCTimer_CY_TCPWM_V2)
    #if(PLCTimer_CY_TCPWM_4000)
        #define PLCTimer_PWM_MODE_CENTER                (PLCTimer_CC_MATCH_INVERT       |   \
                                                                 PLCTimer_OVERLOW_NO_CHANGE     |   \
                                                                 PLCTimer_UNDERFLOW_CLEAR)
    #else
        #define PLCTimer_PWM_MODE_CENTER                (PLCTimer_CC_MATCH_INVERT       |   \
                                                                 PLCTimer_OVERLOW_SET           |   \
                                                                 PLCTimer_UNDERFLOW_CLEAR)
    #endif /* (PLCTimer_CY_TCPWM_4000) */
#else
    #define PLCTimer_PWM_MODE_CENTER                (PLCTimer_CC_MATCH_INVERT       |   \
                                                             PLCTimer_OVERLOW_NO_CHANGE     |   \
                                                             PLCTimer_UNDERFLOW_CLEAR)
#endif /* (PLCTimer_CY_TCPWM_NEW) */

/* Command operations without condition */
#define PLCTimer_CMD_CAPTURE                    (0u)
#define PLCTimer_CMD_RELOAD                     (8u)
#define PLCTimer_CMD_STOP                       (16u)
#define PLCTimer_CMD_START                      (24u)

/* Status */
#define PLCTimer_STATUS_DOWN                    (1u)
#define PLCTimer_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   PLCTimer_Init(void);
void   PLCTimer_Enable(void);
void   PLCTimer_Start(void);
void   PLCTimer_Stop(void);

void   PLCTimer_SetMode(uint32 mode);
void   PLCTimer_SetCounterMode(uint32 counterMode);
void   PLCTimer_SetPWMMode(uint32 modeMask);
void   PLCTimer_SetQDMode(uint32 qdMode);

void   PLCTimer_SetPrescaler(uint32 prescaler);
void   PLCTimer_TriggerCommand(uint32 mask, uint32 command);
void   PLCTimer_SetOneShot(uint32 oneShotEnable);
uint32 PLCTimer_ReadStatus(void);

void   PLCTimer_SetPWMSyncKill(uint32 syncKillEnable);
void   PLCTimer_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   PLCTimer_SetPWMDeadTime(uint32 deadTime);
void   PLCTimer_SetPWMInvert(uint32 mask);

void   PLCTimer_SetInterruptMode(uint32 interruptMask);
uint32 PLCTimer_GetInterruptSourceMasked(void);
uint32 PLCTimer_GetInterruptSource(void);
void   PLCTimer_ClearInterrupt(uint32 interruptMask);
void   PLCTimer_SetInterrupt(uint32 interruptMask);

void   PLCTimer_WriteCounter(uint32 count);
uint32 PLCTimer_ReadCounter(void);

uint32 PLCTimer_ReadCapture(void);
uint32 PLCTimer_ReadCaptureBuf(void);

void   PLCTimer_WritePeriod(uint32 period);
uint32 PLCTimer_ReadPeriod(void);
void   PLCTimer_WritePeriodBuf(uint32 periodBuf);
uint32 PLCTimer_ReadPeriodBuf(void);

void   PLCTimer_WriteCompare(uint32 compare);
uint32 PLCTimer_ReadCompare(void);
void   PLCTimer_WriteCompareBuf(uint32 compareBuf);
uint32 PLCTimer_ReadCompareBuf(void);

void   PLCTimer_SetPeriodSwap(uint32 swapEnable);
void   PLCTimer_SetCompareSwap(uint32 swapEnable);

void   PLCTimer_SetCaptureMode(uint32 triggerMode);
void   PLCTimer_SetReloadMode(uint32 triggerMode);
void   PLCTimer_SetStartMode(uint32 triggerMode);
void   PLCTimer_SetStopMode(uint32 triggerMode);
void   PLCTimer_SetCountMode(uint32 triggerMode);

void   PLCTimer_SaveConfig(void);
void   PLCTimer_RestoreConfig(void);
void   PLCTimer_Sleep(void);
void   PLCTimer_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define PLCTimer_BLOCK_CONTROL_REG              (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PLCTimer_BLOCK_CONTROL_PTR              ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PLCTimer_COMMAND_REG                    (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PLCTimer_COMMAND_PTR                    ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PLCTimer_INTRRUPT_CAUSE_REG             (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PLCTimer_INTRRUPT_CAUSE_PTR             ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PLCTimer_CONTROL_REG                    (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__CTRL )
#define PLCTimer_CONTROL_PTR                    ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__CTRL )
#define PLCTimer_STATUS_REG                     (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__STATUS )
#define PLCTimer_STATUS_PTR                     ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__STATUS )
#define PLCTimer_COUNTER_REG                    (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__COUNTER )
#define PLCTimer_COUNTER_PTR                    ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__COUNTER )
#define PLCTimer_COMP_CAP_REG                   (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__CC )
#define PLCTimer_COMP_CAP_PTR                   ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__CC )
#define PLCTimer_COMP_CAP_BUF_REG               (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define PLCTimer_COMP_CAP_BUF_PTR               ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define PLCTimer_PERIOD_REG                     (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__PERIOD )
#define PLCTimer_PERIOD_PTR                     ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__PERIOD )
#define PLCTimer_PERIOD_BUF_REG                 (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PLCTimer_PERIOD_BUF_PTR                 ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PLCTimer_TRIG_CONTROL0_REG              (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PLCTimer_TRIG_CONTROL0_PTR              ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PLCTimer_TRIG_CONTROL1_REG              (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PLCTimer_TRIG_CONTROL1_PTR              ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PLCTimer_TRIG_CONTROL2_REG              (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PLCTimer_TRIG_CONTROL2_PTR              ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PLCTimer_INTERRUPT_REQ_REG              (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR )
#define PLCTimer_INTERRUPT_REQ_PTR              ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR )
#define PLCTimer_INTERRUPT_SET_REG              (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define PLCTimer_INTERRUPT_SET_PTR              ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define PLCTimer_INTERRUPT_MASK_REG             (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define PLCTimer_INTERRUPT_MASK_PTR             ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define PLCTimer_INTERRUPT_MASKED_REG           (*(reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR_MASKED )
#define PLCTimer_INTERRUPT_MASKED_PTR           ( (reg32 *) PLCTimer_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define PLCTimer_MASK                           ((uint32)PLCTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define PLCTimer_RELOAD_CC_SHIFT                (0u)
#define PLCTimer_RELOAD_PERIOD_SHIFT            (1u)
#define PLCTimer_PWM_SYNC_KILL_SHIFT            (2u)
#define PLCTimer_PWM_STOP_KILL_SHIFT            (3u)
#define PLCTimer_PRESCALER_SHIFT                (8u)
#define PLCTimer_UPDOWN_SHIFT                   (16u)
#define PLCTimer_ONESHOT_SHIFT                  (18u)
#define PLCTimer_QUAD_MODE_SHIFT                (20u)
#define PLCTimer_INV_OUT_SHIFT                  (20u)
#define PLCTimer_INV_COMPL_OUT_SHIFT            (21u)
#define PLCTimer_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define PLCTimer_RELOAD_CC_MASK                 ((uint32)(PLCTimer_1BIT_MASK        <<  \
                                                                            PLCTimer_RELOAD_CC_SHIFT))
#define PLCTimer_RELOAD_PERIOD_MASK             ((uint32)(PLCTimer_1BIT_MASK        <<  \
                                                                            PLCTimer_RELOAD_PERIOD_SHIFT))
#define PLCTimer_PWM_SYNC_KILL_MASK             ((uint32)(PLCTimer_1BIT_MASK        <<  \
                                                                            PLCTimer_PWM_SYNC_KILL_SHIFT))
#define PLCTimer_PWM_STOP_KILL_MASK             ((uint32)(PLCTimer_1BIT_MASK        <<  \
                                                                            PLCTimer_PWM_STOP_KILL_SHIFT))
#define PLCTimer_PRESCALER_MASK                 ((uint32)(PLCTimer_8BIT_MASK        <<  \
                                                                            PLCTimer_PRESCALER_SHIFT))
#define PLCTimer_UPDOWN_MASK                    ((uint32)(PLCTimer_2BIT_MASK        <<  \
                                                                            PLCTimer_UPDOWN_SHIFT))
#define PLCTimer_ONESHOT_MASK                   ((uint32)(PLCTimer_1BIT_MASK        <<  \
                                                                            PLCTimer_ONESHOT_SHIFT))
#define PLCTimer_QUAD_MODE_MASK                 ((uint32)(PLCTimer_3BIT_MASK        <<  \
                                                                            PLCTimer_QUAD_MODE_SHIFT))
#define PLCTimer_INV_OUT_MASK                   ((uint32)(PLCTimer_2BIT_MASK        <<  \
                                                                            PLCTimer_INV_OUT_SHIFT))
#define PLCTimer_MODE_MASK                      ((uint32)(PLCTimer_3BIT_MASK        <<  \
                                                                            PLCTimer_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define PLCTimer_CAPTURE_SHIFT                  (0u)
#define PLCTimer_COUNT_SHIFT                    (2u)
#define PLCTimer_RELOAD_SHIFT                   (4u)
#define PLCTimer_STOP_SHIFT                     (6u)
#define PLCTimer_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define PLCTimer_CAPTURE_MASK                   ((uint32)(PLCTimer_2BIT_MASK        <<  \
                                                                  PLCTimer_CAPTURE_SHIFT))
#define PLCTimer_COUNT_MASK                     ((uint32)(PLCTimer_2BIT_MASK        <<  \
                                                                  PLCTimer_COUNT_SHIFT))
#define PLCTimer_RELOAD_MASK                    ((uint32)(PLCTimer_2BIT_MASK        <<  \
                                                                  PLCTimer_RELOAD_SHIFT))
#define PLCTimer_STOP_MASK                      ((uint32)(PLCTimer_2BIT_MASK        <<  \
                                                                  PLCTimer_STOP_SHIFT))
#define PLCTimer_START_MASK                     ((uint32)(PLCTimer_2BIT_MASK        <<  \
                                                                  PLCTimer_START_SHIFT))

/* MASK */
#define PLCTimer_1BIT_MASK                      ((uint32)0x01u)
#define PLCTimer_2BIT_MASK                      ((uint32)0x03u)
#define PLCTimer_3BIT_MASK                      ((uint32)0x07u)
#define PLCTimer_6BIT_MASK                      ((uint32)0x3Fu)
#define PLCTimer_8BIT_MASK                      ((uint32)0xFFu)
#define PLCTimer_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define PLCTimer_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define PLCTimer_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(PLCTimer_QUAD_ENCODING_MODES     << PLCTimer_QUAD_MODE_SHIFT))       |\
         ((uint32)(PLCTimer_CONFIG                  << PLCTimer_MODE_SHIFT)))

#define PLCTimer_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(PLCTimer_PWM_STOP_EVENT          << PLCTimer_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(PLCTimer_PWM_OUT_INVERT          << PLCTimer_INV_OUT_SHIFT))         |\
         ((uint32)(PLCTimer_PWM_OUT_N_INVERT        << PLCTimer_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(PLCTimer_PWM_MODE                << PLCTimer_MODE_SHIFT)))

#define PLCTimer_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(PLCTimer_PWM_RUN_MODE         << PLCTimer_ONESHOT_SHIFT))
            
#define PLCTimer_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(PLCTimer_PWM_ALIGN            << PLCTimer_UPDOWN_SHIFT))

#define PLCTimer_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(PLCTimer_PWM_KILL_EVENT      << PLCTimer_PWM_SYNC_KILL_SHIFT))

#define PLCTimer_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(PLCTimer_PWM_DEAD_TIME_CYCLE  << PLCTimer_PRESCALER_SHIFT))

#define PLCTimer_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(PLCTimer_PWM_PRESCALER        << PLCTimer_PRESCALER_SHIFT))

#define PLCTimer_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(PLCTimer_TC_PRESCALER            << PLCTimer_PRESCALER_SHIFT))       |\
         ((uint32)(PLCTimer_TC_COUNTER_MODE         << PLCTimer_UPDOWN_SHIFT))          |\
         ((uint32)(PLCTimer_TC_RUN_MODE             << PLCTimer_ONESHOT_SHIFT))         |\
         ((uint32)(PLCTimer_TC_COMP_CAP_MODE        << PLCTimer_MODE_SHIFT)))
        
#define PLCTimer_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(PLCTimer_QUAD_PHIA_SIGNAL_MODE   << PLCTimer_COUNT_SHIFT))           |\
         ((uint32)(PLCTimer_QUAD_INDEX_SIGNAL_MODE  << PLCTimer_RELOAD_SHIFT))          |\
         ((uint32)(PLCTimer_QUAD_STOP_SIGNAL_MODE   << PLCTimer_STOP_SHIFT))            |\
         ((uint32)(PLCTimer_QUAD_PHIB_SIGNAL_MODE   << PLCTimer_START_SHIFT)))

#define PLCTimer_PWM_SIGNALS_MODES                                                              \
        (((uint32)(PLCTimer_PWM_SWITCH_SIGNAL_MODE  << PLCTimer_CAPTURE_SHIFT))         |\
         ((uint32)(PLCTimer_PWM_COUNT_SIGNAL_MODE   << PLCTimer_COUNT_SHIFT))           |\
         ((uint32)(PLCTimer_PWM_RELOAD_SIGNAL_MODE  << PLCTimer_RELOAD_SHIFT))          |\
         ((uint32)(PLCTimer_PWM_STOP_SIGNAL_MODE    << PLCTimer_STOP_SHIFT))            |\
         ((uint32)(PLCTimer_PWM_START_SIGNAL_MODE   << PLCTimer_START_SHIFT)))

#define PLCTimer_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(PLCTimer_TC_CAPTURE_SIGNAL_MODE  << PLCTimer_CAPTURE_SHIFT))         |\
         ((uint32)(PLCTimer_TC_COUNT_SIGNAL_MODE    << PLCTimer_COUNT_SHIFT))           |\
         ((uint32)(PLCTimer_TC_RELOAD_SIGNAL_MODE   << PLCTimer_RELOAD_SHIFT))          |\
         ((uint32)(PLCTimer_TC_STOP_SIGNAL_MODE     << PLCTimer_STOP_SHIFT))            |\
         ((uint32)(PLCTimer_TC_START_SIGNAL_MODE    << PLCTimer_START_SHIFT)))
        
#define PLCTimer_TIMER_UPDOWN_CNT_USED                                                          \
                ((PLCTimer__COUNT_UPDOWN0 == PLCTimer_TC_COUNTER_MODE)                  ||\
                 (PLCTimer__COUNT_UPDOWN1 == PLCTimer_TC_COUNTER_MODE))

#define PLCTimer_PWM_UPDOWN_CNT_USED                                                            \
                ((PLCTimer__CENTER == PLCTimer_PWM_ALIGN)                               ||\
                 (PLCTimer__ASYMMETRIC == PLCTimer_PWM_ALIGN))               
        
#define PLCTimer_PWM_PR_INIT_VALUE              (1u)
#define PLCTimer_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_PLCTimer_H */

/* [] END OF FILE */
