/*******************************************************************************
* File Name: XBEE_UART_SPI_UART_INT.c
* Version 2.0
*
* Description:
*  This file provides the source code to the Interrupt Service Routine for
*  the SCB Component in SPI and UART modes.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "XBEE_UART_PVT.h"
#include "XBEE_UART_SPI_UART_PVT.h"


/*******************************************************************************
* Function Name: XBEE_UART_SPI_UART_ISR
********************************************************************************
*
* Summary:
*  Handles the Interrupt Service Routine for the SCB SPI or UART modes.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
CY_ISR(XBEE_UART_SPI_UART_ISR)
{
#if(XBEE_UART_INTERNAL_RX_SW_BUFFER_CONST)
    uint32 locHead;
    uint32 dataRx;
#endif /* (XBEE_UART_INTERNAL_RX_SW_BUFFER_CONST) */

#if(XBEE_UART_INTERNAL_TX_SW_BUFFER_CONST)
    uint32 locTail;
#endif /* (XBEE_UART_INTERNAL_TX_SW_BUFFER_CONST) */

    if(NULL != XBEE_UART_customIntrHandler)
    {
        XBEE_UART_customIntrHandler();
    }

    #if(XBEE_UART_CHECK_SPI_WAKE_ENABLE)
    {
        /* Clear SPI wakeup source */
        XBEE_UART_ClearSpiExtClkInterruptSource(XBEE_UART_INTR_SPI_EC_WAKE_UP);
    }
    #endif

    #if(XBEE_UART_CHECK_RX_SW_BUFFER)
    {
        if(XBEE_UART_CHECK_INTR_RX_MASKED(XBEE_UART_INTR_RX_NOT_EMPTY))
        {
            while(0u != XBEE_UART_GET_RX_FIFO_ENTRIES)
            {
                /* Get data from RX FIFO */
                dataRx = XBEE_UART_RX_FIFO_RD_REG;

                /* Move local head index */
                locHead = (XBEE_UART_rxBufferHead + 1u);

                /* Adjust local head index */
                if(XBEE_UART_RX_BUFFER_SIZE == locHead)
                {
                    locHead = 0u;
                }

                if(locHead == XBEE_UART_rxBufferTail)
                {
                    /* Overflow: through away new data */
                    XBEE_UART_rxBufferOverflow = (uint8) XBEE_UART_INTR_RX_OVERFLOW;
                }
                else
                {
                    /* Store received data */
                    XBEE_UART_PutWordInRxBuffer(locHead, dataRx);

                    /* Move head index */
                    XBEE_UART_rxBufferHead = locHead;
                }
            }

            XBEE_UART_ClearRxInterruptSource(XBEE_UART_INTR_RX_NOT_EMPTY);
        }
    }
    #endif


    #if(XBEE_UART_CHECK_TX_SW_BUFFER)
    {
        if(XBEE_UART_CHECK_INTR_TX_MASKED(XBEE_UART_INTR_TX_NOT_FULL))
        {
            /* Put data into TX FIFO */
            while(XBEE_UART_SPI_UART_FIFO_SIZE != XBEE_UART_GET_TX_FIFO_ENTRIES)
            {
                /* Check for room in TX software buffer */
                if(XBEE_UART_txBufferHead != XBEE_UART_txBufferTail)
                {
                    /* Move local tail index */
                    locTail = (XBEE_UART_txBufferTail + 1u);

                    /* Adjust local tail index */
                    if(XBEE_UART_TX_BUFFER_SIZE == locTail)
                    {
                        locTail = 0u;
                    }

                    /* Put data into TX FIFO */
                    XBEE_UART_TX_FIFO_WR_REG = XBEE_UART_GetWordFromTxBuffer(locTail);

                    /* Move tail index */
                    XBEE_UART_txBufferTail = locTail;
                }
                else
                {
                    /* TX software buffer is empty: complete transfer */
                    XBEE_UART_DISABLE_INTR_TX(XBEE_UART_INTR_TX_NOT_FULL);
                    break;
                }
            }

            XBEE_UART_ClearTxInterruptSource(XBEE_UART_INTR_TX_NOT_FULL);
        }
    }
    #endif
}


/* [] END OF FILE */
