/*******************************************************************************
* File Name: ACKTimer.c
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the ACKTimer
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ACKTimer.h"

uint8 ACKTimer_initVar = 0u;


/*******************************************************************************
* Function Name: ACKTimer_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default ACKTimer configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (ACKTimer__QUAD == ACKTimer_CONFIG)
        ACKTimer_CONTROL_REG = ACKTimer_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        ACKTimer_TRIG_CONTROL1_REG  = ACKTimer_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        ACKTimer_SetInterruptMode(ACKTimer_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        ACKTimer_SetCounterMode(ACKTimer_COUNT_DOWN);
        ACKTimer_WritePeriod(ACKTimer_QUAD_PERIOD_INIT_VALUE);
        ACKTimer_WriteCounter(ACKTimer_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (ACKTimer__QUAD == ACKTimer_CONFIG) */

    #if (ACKTimer__TIMER == ACKTimer_CONFIG)
        ACKTimer_CONTROL_REG = ACKTimer_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        ACKTimer_TRIG_CONTROL1_REG  = ACKTimer_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        ACKTimer_SetInterruptMode(ACKTimer_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        ACKTimer_WritePeriod(ACKTimer_TC_PERIOD_VALUE );

        #if (ACKTimer__COMPARE == ACKTimer_TC_COMP_CAP_MODE)
            ACKTimer_WriteCompare(ACKTimer_TC_COMPARE_VALUE);

            #if (1u == ACKTimer_TC_COMPARE_SWAP)
                ACKTimer_SetCompareSwap(1u);
                ACKTimer_WriteCompareBuf(ACKTimer_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == ACKTimer_TC_COMPARE_SWAP) */
        #endif  /* (ACKTimer__COMPARE == ACKTimer_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (ACKTimer_CY_TCPWM_V2 && ACKTimer_TIMER_UPDOWN_CNT_USED && !ACKTimer_CY_TCPWM_4000)
            ACKTimer_WriteCounter(1u);
        #elif(ACKTimer__COUNT_DOWN == ACKTimer_TC_COUNTER_MODE)
            ACKTimer_WriteCounter(ACKTimer_TC_PERIOD_VALUE);
        #else
            ACKTimer_WriteCounter(0u);
        #endif /* (ACKTimer_CY_TCPWM_V2 && ACKTimer_TIMER_UPDOWN_CNT_USED && !ACKTimer_CY_TCPWM_4000) */
    #endif  /* (ACKTimer__TIMER == ACKTimer_CONFIG) */

    #if (ACKTimer__PWM_SEL == ACKTimer_CONFIG)
        ACKTimer_CONTROL_REG = ACKTimer_CTRL_PWM_BASE_CONFIG;

        #if (ACKTimer__PWM_PR == ACKTimer_PWM_MODE)
            ACKTimer_CONTROL_REG |= ACKTimer_CTRL_PWM_RUN_MODE;
            ACKTimer_WriteCounter(ACKTimer_PWM_PR_INIT_VALUE);
        #else
            ACKTimer_CONTROL_REG |= ACKTimer_CTRL_PWM_ALIGN | ACKTimer_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (ACKTimer_CY_TCPWM_V2 && ACKTimer_PWM_UPDOWN_CNT_USED && !ACKTimer_CY_TCPWM_4000)
                ACKTimer_WriteCounter(1u);
            #elif (ACKTimer__RIGHT == ACKTimer_PWM_ALIGN)
                ACKTimer_WriteCounter(ACKTimer_PWM_PERIOD_VALUE);
            #else 
                ACKTimer_WriteCounter(0u);
            #endif  /* (ACKTimer_CY_TCPWM_V2 && ACKTimer_PWM_UPDOWN_CNT_USED && !ACKTimer_CY_TCPWM_4000) */
        #endif  /* (ACKTimer__PWM_PR == ACKTimer_PWM_MODE) */

        #if (ACKTimer__PWM_DT == ACKTimer_PWM_MODE)
            ACKTimer_CONTROL_REG |= ACKTimer_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (ACKTimer__PWM_DT == ACKTimer_PWM_MODE) */

        #if (ACKTimer__PWM == ACKTimer_PWM_MODE)
            ACKTimer_CONTROL_REG |= ACKTimer_CTRL_PWM_PRESCALER;
        #endif  /* (ACKTimer__PWM == ACKTimer_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        ACKTimer_TRIG_CONTROL1_REG  = ACKTimer_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        ACKTimer_SetInterruptMode(ACKTimer_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (ACKTimer__PWM_PR == ACKTimer_PWM_MODE)
            ACKTimer_TRIG_CONTROL2_REG =
                    (ACKTimer_CC_MATCH_NO_CHANGE    |
                    ACKTimer_OVERLOW_NO_CHANGE      |
                    ACKTimer_UNDERFLOW_NO_CHANGE);
        #else
            #if (ACKTimer__LEFT == ACKTimer_PWM_ALIGN)
                ACKTimer_TRIG_CONTROL2_REG = ACKTimer_PWM_MODE_LEFT;
            #endif  /* ( ACKTimer_PWM_LEFT == ACKTimer_PWM_ALIGN) */

            #if (ACKTimer__RIGHT == ACKTimer_PWM_ALIGN)
                ACKTimer_TRIG_CONTROL2_REG = ACKTimer_PWM_MODE_RIGHT;
            #endif  /* ( ACKTimer_PWM_RIGHT == ACKTimer_PWM_ALIGN) */

            #if (ACKTimer__CENTER == ACKTimer_PWM_ALIGN)
                ACKTimer_TRIG_CONTROL2_REG = ACKTimer_PWM_MODE_CENTER;
            #endif  /* ( ACKTimer_PWM_CENTER == ACKTimer_PWM_ALIGN) */

            #if (ACKTimer__ASYMMETRIC == ACKTimer_PWM_ALIGN)
                ACKTimer_TRIG_CONTROL2_REG = ACKTimer_PWM_MODE_ASYM;
            #endif  /* (ACKTimer__ASYMMETRIC == ACKTimer_PWM_ALIGN) */
        #endif  /* (ACKTimer__PWM_PR == ACKTimer_PWM_MODE) */

        /* Set other values from customizer */
        ACKTimer_WritePeriod(ACKTimer_PWM_PERIOD_VALUE );
        ACKTimer_WriteCompare(ACKTimer_PWM_COMPARE_VALUE);

        #if (1u == ACKTimer_PWM_COMPARE_SWAP)
            ACKTimer_SetCompareSwap(1u);
            ACKTimer_WriteCompareBuf(ACKTimer_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == ACKTimer_PWM_COMPARE_SWAP) */

        #if (1u == ACKTimer_PWM_PERIOD_SWAP)
            ACKTimer_SetPeriodSwap(1u);
            ACKTimer_WritePeriodBuf(ACKTimer_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == ACKTimer_PWM_PERIOD_SWAP) */
    #endif  /* (ACKTimer__PWM_SEL == ACKTimer_CONFIG) */
    
}


/*******************************************************************************
* Function Name: ACKTimer_Enable
********************************************************************************
*
* Summary:
*  Enables the ACKTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    ACKTimer_BLOCK_CONTROL_REG |= ACKTimer_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (ACKTimer__PWM_SEL == ACKTimer_CONFIG)
        #if (0u == ACKTimer_PWM_START_SIGNAL_PRESENT)
            ACKTimer_TriggerCommand(ACKTimer_MASK, ACKTimer_CMD_START);
        #endif /* (0u == ACKTimer_PWM_START_SIGNAL_PRESENT) */
    #endif /* (ACKTimer__PWM_SEL == ACKTimer_CONFIG) */

    #if (ACKTimer__TIMER == ACKTimer_CONFIG)
        #if (0u == ACKTimer_TC_START_SIGNAL_PRESENT)
            ACKTimer_TriggerCommand(ACKTimer_MASK, ACKTimer_CMD_START);
        #endif /* (0u == ACKTimer_TC_START_SIGNAL_PRESENT) */
    #endif /* (ACKTimer__TIMER == ACKTimer_CONFIG) */
}


/*******************************************************************************
* Function Name: ACKTimer_Start
********************************************************************************
*
* Summary:
*  Initializes the ACKTimer with default customizer
*  values when called the first time and enables the ACKTimer.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  ACKTimer_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time ACKTimer_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the ACKTimer_Start() routine.
*
*******************************************************************************/
void ACKTimer_Start(void)
{
    if (0u == ACKTimer_initVar)
    {
        ACKTimer_Init();
        ACKTimer_initVar = 1u;
    }

    ACKTimer_Enable();
}


/*******************************************************************************
* Function Name: ACKTimer_Stop
********************************************************************************
*
* Summary:
*  Disables the ACKTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_BLOCK_CONTROL_REG &= (uint32)~ACKTimer_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the ACKTimer. This function is used when
*  configured as a generic ACKTimer and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the ACKTimer to operate in
*   Values:
*   - ACKTimer_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - ACKTimer_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - ACKTimer_MODE_QUAD - Quadrature decoder
*         - ACKTimer_MODE_PWM - PWM
*         - ACKTimer_MODE_PWM_DT - PWM with dead time
*         - ACKTimer_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_MODE_MASK;
    ACKTimer_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - ACKTimer_MODE_X1 - Counts on phi 1 rising
*         - ACKTimer_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - ACKTimer_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_QUAD_MODE_MASK;
    ACKTimer_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - ACKTimer_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - ACKTimer_PRESCALE_DIVBY2    - Divide by 2
*         - ACKTimer_PRESCALE_DIVBY4    - Divide by 4
*         - ACKTimer_PRESCALE_DIVBY8    - Divide by 8
*         - ACKTimer_PRESCALE_DIVBY16   - Divide by 16
*         - ACKTimer_PRESCALE_DIVBY32   - Divide by 32
*         - ACKTimer_PRESCALE_DIVBY64   - Divide by 64
*         - ACKTimer_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_PRESCALER_MASK;
    ACKTimer_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the ACKTimer runs
*  continuously or stops when terminal count is reached.  By default the
*  ACKTimer operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_ONESHOT_MASK;
    ACKTimer_CONTROL_REG |= ((uint32)((oneShotEnable & ACKTimer_1BIT_MASK) <<
                                                               ACKTimer_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetPWMMode(uint32 modeMask)
{
    ACKTimer_TRIG_CONTROL2_REG = (modeMask & ACKTimer_6BIT_MASK);
}



/*******************************************************************************
* Function Name: ACKTimer_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_PWM_SYNC_KILL_MASK;
    ACKTimer_CONTROL_REG |= ((uint32)((syncKillEnable & ACKTimer_1BIT_MASK)  <<
                                               ACKTimer_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_PWM_STOP_KILL_MASK;
    ACKTimer_CONTROL_REG |= ((uint32)((stopOnKillEnable & ACKTimer_1BIT_MASK)  <<
                                                         ACKTimer_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_PRESCALER_MASK;
    ACKTimer_CONTROL_REG |= ((uint32)((deadTime & ACKTimer_8BIT_MASK) <<
                                                          ACKTimer_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - ACKTimer_INVERT_LINE   - Inverts the line output
*         - ACKTimer_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_INV_OUT_MASK;
    ACKTimer_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: ACKTimer_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_WriteCounter(uint32 count)
{
    ACKTimer_COUNTER_REG = (count & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 ACKTimer_ReadCounter(void)
{
    return (ACKTimer_COUNTER_REG & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - ACKTimer_COUNT_UP       - Counts up
*     - ACKTimer_COUNT_DOWN     - Counts down
*     - ACKTimer_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - ACKTimer_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_UPDOWN_MASK;
    ACKTimer_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_WritePeriod(uint32 period)
{
    ACKTimer_PERIOD_REG = (period & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 ACKTimer_ReadPeriod(void)
{
    return (ACKTimer_PERIOD_REG & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_RELOAD_CC_MASK;
    ACKTimer_CONTROL_REG |= (swapEnable & ACKTimer_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_WritePeriodBuf(uint32 periodBuf)
{
    ACKTimer_PERIOD_BUF_REG = (periodBuf & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 ACKTimer_ReadPeriodBuf(void)
{
    return (ACKTimer_PERIOD_BUF_REG & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_CONTROL_REG &= (uint32)~ACKTimer_RELOAD_PERIOD_MASK;
    ACKTimer_CONTROL_REG |= ((uint32)((swapEnable & ACKTimer_1BIT_MASK) <<
                                                            ACKTimer_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_WriteCompare(uint32 compare)
{
    #if (ACKTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (ACKTimer_CY_TCPWM_4000) */

    #if (ACKTimer_CY_TCPWM_4000)
        currentMode = ((ACKTimer_CONTROL_REG & ACKTimer_UPDOWN_MASK) >> ACKTimer_UPDOWN_SHIFT);

        if (((uint32)ACKTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)ACKTimer__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (ACKTimer_CY_TCPWM_4000) */
    
    ACKTimer_COMP_CAP_REG = (compare & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 ACKTimer_ReadCompare(void)
{
    #if (ACKTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (ACKTimer_CY_TCPWM_4000) */

    #if (ACKTimer_CY_TCPWM_4000)
        currentMode = ((ACKTimer_CONTROL_REG & ACKTimer_UPDOWN_MASK) >> ACKTimer_UPDOWN_SHIFT);
        
        regVal = ACKTimer_COMP_CAP_REG;
        
        if (((uint32)ACKTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)ACKTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & ACKTimer_16BIT_MASK);
    #else
        return (ACKTimer_COMP_CAP_REG & ACKTimer_16BIT_MASK);
    #endif /* (ACKTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: ACKTimer_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_WriteCompareBuf(uint32 compareBuf)
{
    #if (ACKTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (ACKTimer_CY_TCPWM_4000) */

    #if (ACKTimer_CY_TCPWM_4000)
        currentMode = ((ACKTimer_CONTROL_REG & ACKTimer_UPDOWN_MASK) >> ACKTimer_UPDOWN_SHIFT);

        if (((uint32)ACKTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)ACKTimer__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (ACKTimer_CY_TCPWM_4000) */
    
    ACKTimer_COMP_CAP_BUF_REG = (compareBuf & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 ACKTimer_ReadCompareBuf(void)
{
    #if (ACKTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (ACKTimer_CY_TCPWM_4000) */

    #if (ACKTimer_CY_TCPWM_4000)
        currentMode = ((ACKTimer_CONTROL_REG & ACKTimer_UPDOWN_MASK) >> ACKTimer_UPDOWN_SHIFT);

        regVal = ACKTimer_COMP_CAP_BUF_REG;
        
        if (((uint32)ACKTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)ACKTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & ACKTimer_16BIT_MASK);
    #else
        return (ACKTimer_COMP_CAP_BUF_REG & ACKTimer_16BIT_MASK);
    #endif /* (ACKTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: ACKTimer_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 ACKTimer_ReadCapture(void)
{
    return (ACKTimer_COMP_CAP_REG & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 ACKTimer_ReadCaptureBuf(void)
{
    return (ACKTimer_COMP_CAP_BUF_REG & ACKTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: ACKTimer_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - ACKTimer_TRIG_LEVEL     - Level
*     - ACKTimer_TRIG_RISING    - Rising edge
*     - ACKTimer_TRIG_FALLING   - Falling edge
*     - ACKTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_TRIG_CONTROL1_REG &= (uint32)~ACKTimer_CAPTURE_MASK;
    ACKTimer_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - ACKTimer_TRIG_LEVEL     - Level
*     - ACKTimer_TRIG_RISING    - Rising edge
*     - ACKTimer_TRIG_FALLING   - Falling edge
*     - ACKTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_TRIG_CONTROL1_REG &= (uint32)~ACKTimer_RELOAD_MASK;
    ACKTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << ACKTimer_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - ACKTimer_TRIG_LEVEL     - Level
*     - ACKTimer_TRIG_RISING    - Rising edge
*     - ACKTimer_TRIG_FALLING   - Falling edge
*     - ACKTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_TRIG_CONTROL1_REG &= (uint32)~ACKTimer_START_MASK;
    ACKTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << ACKTimer_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - ACKTimer_TRIG_LEVEL     - Level
*     - ACKTimer_TRIG_RISING    - Rising edge
*     - ACKTimer_TRIG_FALLING   - Falling edge
*     - ACKTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_TRIG_CONTROL1_REG &= (uint32)~ACKTimer_STOP_MASK;
    ACKTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << ACKTimer_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - ACKTimer_TRIG_LEVEL     - Level
*     - ACKTimer_TRIG_RISING    - Rising edge
*     - ACKTimer_TRIG_FALLING   - Falling edge
*     - ACKTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_TRIG_CONTROL1_REG &= (uint32)~ACKTimer_COUNT_MASK;
    ACKTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << ACKTimer_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - ACKTimer_CMD_CAPTURE    - Trigger Capture command
*     - ACKTimer_CMD_RELOAD     - Trigger Reload command
*     - ACKTimer_CMD_STOP       - Trigger Stop command
*     - ACKTimer_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    ACKTimer_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: ACKTimer_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the ACKTimer.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - ACKTimer_STATUS_DOWN    - Set if counting down
*     - ACKTimer_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 ACKTimer_ReadStatus(void)
{
    return ((ACKTimer_STATUS_REG >> ACKTimer_RUNNING_STATUS_SHIFT) |
            (ACKTimer_STATUS_REG & ACKTimer_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: ACKTimer_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - ACKTimer_INTR_MASK_TC       - Terminal count mask
*     - ACKTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetInterruptMode(uint32 interruptMask)
{
    ACKTimer_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: ACKTimer_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - ACKTimer_INTR_MASK_TC       - Terminal count mask
*     - ACKTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 ACKTimer_GetInterruptSourceMasked(void)
{
    return (ACKTimer_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: ACKTimer_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - ACKTimer_INTR_MASK_TC       - Terminal count mask
*     - ACKTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 ACKTimer_GetInterruptSource(void)
{
    return (ACKTimer_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: ACKTimer_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - ACKTimer_INTR_MASK_TC       - Terminal count mask
*     - ACKTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_ClearInterrupt(uint32 interruptMask)
{
    ACKTimer_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: ACKTimer_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - ACKTimer_INTR_MASK_TC       - Terminal count mask
*     - ACKTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SetInterrupt(uint32 interruptMask)
{
    ACKTimer_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
