/*******************************************************************************
* File Name: ACKTimer.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the ACKTimer
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_ACKTimer_H)
#define CY_TCPWM_ACKTimer_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} ACKTimer_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  ACKTimer_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define ACKTimer_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define ACKTimer_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define ACKTimer_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define ACKTimer_QUAD_ENCODING_MODES            (0lu)

/* Signal modes */
#define ACKTimer_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define ACKTimer_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define ACKTimer_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define ACKTimer_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define ACKTimer_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define ACKTimer_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define ACKTimer_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define ACKTimer_TC_RUN_MODE                    (1lu)
#define ACKTimer_TC_COUNTER_MODE                (1lu)
#define ACKTimer_TC_COMP_CAP_MODE               (2lu)
#define ACKTimer_TC_PRESCALER                   (6lu)

/* Signal modes */
#define ACKTimer_TC_RELOAD_SIGNAL_MODE          (0lu)
#define ACKTimer_TC_COUNT_SIGNAL_MODE           (3lu)
#define ACKTimer_TC_START_SIGNAL_MODE           (0lu)
#define ACKTimer_TC_STOP_SIGNAL_MODE            (0lu)
#define ACKTimer_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define ACKTimer_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define ACKTimer_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define ACKTimer_TC_START_SIGNAL_PRESENT        (0lu)
#define ACKTimer_TC_STOP_SIGNAL_PRESENT         (0lu)
#define ACKTimer_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define ACKTimer_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define ACKTimer_PWM_KILL_EVENT                 (0lu)
#define ACKTimer_PWM_STOP_EVENT                 (0lu)
#define ACKTimer_PWM_MODE                       (4lu)
#define ACKTimer_PWM_OUT_N_INVERT               (0lu)
#define ACKTimer_PWM_OUT_INVERT                 (0lu)
#define ACKTimer_PWM_ALIGN                      (0lu)
#define ACKTimer_PWM_RUN_MODE                   (0lu)
#define ACKTimer_PWM_DEAD_TIME_CYCLE            (0lu)
#define ACKTimer_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define ACKTimer_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define ACKTimer_PWM_COUNT_SIGNAL_MODE          (3lu)
#define ACKTimer_PWM_START_SIGNAL_MODE          (0lu)
#define ACKTimer_PWM_STOP_SIGNAL_MODE           (0lu)
#define ACKTimer_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define ACKTimer_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define ACKTimer_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define ACKTimer_PWM_START_SIGNAL_PRESENT       (0lu)
#define ACKTimer_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define ACKTimer_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define ACKTimer_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define ACKTimer_TC_PERIOD_VALUE                (65535lu)
#define ACKTimer_TC_COMPARE_VALUE               (65535lu)
#define ACKTimer_TC_COMPARE_BUF_VALUE           (65535lu)
#define ACKTimer_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define ACKTimer_PWM_PERIOD_VALUE               (65535lu)
#define ACKTimer_PWM_PERIOD_BUF_VALUE           (65535lu)
#define ACKTimer_PWM_PERIOD_SWAP                (0lu)
#define ACKTimer_PWM_COMPARE_VALUE              (65535lu)
#define ACKTimer_PWM_COMPARE_BUF_VALUE          (65535lu)
#define ACKTimer_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define ACKTimer__LEFT 0
#define ACKTimer__RIGHT 1
#define ACKTimer__CENTER 2
#define ACKTimer__ASYMMETRIC 3

#define ACKTimer__X1 0
#define ACKTimer__X2 1
#define ACKTimer__X4 2

#define ACKTimer__PWM 4
#define ACKTimer__PWM_DT 5
#define ACKTimer__PWM_PR 6

#define ACKTimer__INVERSE 1
#define ACKTimer__DIRECT 0

#define ACKTimer__CAPTURE 2
#define ACKTimer__COMPARE 0

#define ACKTimer__TRIG_LEVEL 3
#define ACKTimer__TRIG_RISING 0
#define ACKTimer__TRIG_FALLING 1
#define ACKTimer__TRIG_BOTH 2

#define ACKTimer__INTR_MASK_TC 1
#define ACKTimer__INTR_MASK_CC_MATCH 2
#define ACKTimer__INTR_MASK_NONE 0
#define ACKTimer__INTR_MASK_TC_CC 3

#define ACKTimer__UNCONFIG 8
#define ACKTimer__TIMER 1
#define ACKTimer__QUAD 3
#define ACKTimer__PWM_SEL 7

#define ACKTimer__COUNT_UP 0
#define ACKTimer__COUNT_DOWN 1
#define ACKTimer__COUNT_UPDOWN0 2
#define ACKTimer__COUNT_UPDOWN1 3


/* Prescaler */
#define ACKTimer_PRESCALE_DIVBY1                ((uint32)(0u << ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_PRESCALE_DIVBY2                ((uint32)(1u << ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_PRESCALE_DIVBY4                ((uint32)(2u << ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_PRESCALE_DIVBY8                ((uint32)(3u << ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_PRESCALE_DIVBY16               ((uint32)(4u << ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_PRESCALE_DIVBY32               ((uint32)(5u << ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_PRESCALE_DIVBY64               ((uint32)(6u << ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_PRESCALE_DIVBY128              ((uint32)(7u << ACKTimer_PRESCALER_SHIFT))

/* TCPWM set modes */
#define ACKTimer_MODE_TIMER_COMPARE             ((uint32)(ACKTimer__COMPARE         <<  \
                                                                  ACKTimer_MODE_SHIFT))
#define ACKTimer_MODE_TIMER_CAPTURE             ((uint32)(ACKTimer__CAPTURE         <<  \
                                                                  ACKTimer_MODE_SHIFT))
#define ACKTimer_MODE_QUAD                      ((uint32)(ACKTimer__QUAD            <<  \
                                                                  ACKTimer_MODE_SHIFT))
#define ACKTimer_MODE_PWM                       ((uint32)(ACKTimer__PWM             <<  \
                                                                  ACKTimer_MODE_SHIFT))
#define ACKTimer_MODE_PWM_DT                    ((uint32)(ACKTimer__PWM_DT          <<  \
                                                                  ACKTimer_MODE_SHIFT))
#define ACKTimer_MODE_PWM_PR                    ((uint32)(ACKTimer__PWM_PR          <<  \
                                                                  ACKTimer_MODE_SHIFT))

/* Quad Modes */
#define ACKTimer_MODE_X1                        ((uint32)(ACKTimer__X1              <<  \
                                                                  ACKTimer_QUAD_MODE_SHIFT))
#define ACKTimer_MODE_X2                        ((uint32)(ACKTimer__X2              <<  \
                                                                  ACKTimer_QUAD_MODE_SHIFT))
#define ACKTimer_MODE_X4                        ((uint32)(ACKTimer__X4              <<  \
                                                                  ACKTimer_QUAD_MODE_SHIFT))

/* Counter modes */
#define ACKTimer_COUNT_UP                       ((uint32)(ACKTimer__COUNT_UP        <<  \
                                                                  ACKTimer_UPDOWN_SHIFT))
#define ACKTimer_COUNT_DOWN                     ((uint32)(ACKTimer__COUNT_DOWN      <<  \
                                                                  ACKTimer_UPDOWN_SHIFT))
#define ACKTimer_COUNT_UPDOWN0                  ((uint32)(ACKTimer__COUNT_UPDOWN0   <<  \
                                                                  ACKTimer_UPDOWN_SHIFT))
#define ACKTimer_COUNT_UPDOWN1                  ((uint32)(ACKTimer__COUNT_UPDOWN1   <<  \
                                                                  ACKTimer_UPDOWN_SHIFT))

/* PWM output invert */
#define ACKTimer_INVERT_LINE                    ((uint32)(ACKTimer__INVERSE         <<  \
                                                                  ACKTimer_INV_OUT_SHIFT))
#define ACKTimer_INVERT_LINE_N                  ((uint32)(ACKTimer__INVERSE         <<  \
                                                                  ACKTimer_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define ACKTimer_TRIG_RISING                    ((uint32)ACKTimer__TRIG_RISING)
#define ACKTimer_TRIG_FALLING                   ((uint32)ACKTimer__TRIG_FALLING)
#define ACKTimer_TRIG_BOTH                      ((uint32)ACKTimer__TRIG_BOTH)
#define ACKTimer_TRIG_LEVEL                     ((uint32)ACKTimer__TRIG_LEVEL)

/* Interrupt mask */
#define ACKTimer_INTR_MASK_TC                   ((uint32)ACKTimer__INTR_MASK_TC)
#define ACKTimer_INTR_MASK_CC_MATCH             ((uint32)ACKTimer__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define ACKTimer_CC_MATCH_SET                   (0x00u)
#define ACKTimer_CC_MATCH_CLEAR                 (0x01u)
#define ACKTimer_CC_MATCH_INVERT                (0x02u)
#define ACKTimer_CC_MATCH_NO_CHANGE             (0x03u)
#define ACKTimer_OVERLOW_SET                    (0x00u)
#define ACKTimer_OVERLOW_CLEAR                  (0x04u)
#define ACKTimer_OVERLOW_INVERT                 (0x08u)
#define ACKTimer_OVERLOW_NO_CHANGE              (0x0Cu)
#define ACKTimer_UNDERFLOW_SET                  (0x00u)
#define ACKTimer_UNDERFLOW_CLEAR                (0x10u)
#define ACKTimer_UNDERFLOW_INVERT               (0x20u)
#define ACKTimer_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define ACKTimer_PWM_MODE_LEFT                  (ACKTimer_CC_MATCH_CLEAR        |   \
                                                         ACKTimer_OVERLOW_SET           |   \
                                                         ACKTimer_UNDERFLOW_NO_CHANGE)
#define ACKTimer_PWM_MODE_RIGHT                 (ACKTimer_CC_MATCH_SET          |   \
                                                         ACKTimer_OVERLOW_NO_CHANGE     |   \
                                                         ACKTimer_UNDERFLOW_CLEAR)
#define ACKTimer_PWM_MODE_ASYM                  (ACKTimer_CC_MATCH_INVERT       |   \
                                                         ACKTimer_OVERLOW_SET           |   \
                                                         ACKTimer_UNDERFLOW_CLEAR)

#if (ACKTimer_CY_TCPWM_V2)
    #if(ACKTimer_CY_TCPWM_4000)
        #define ACKTimer_PWM_MODE_CENTER                (ACKTimer_CC_MATCH_INVERT       |   \
                                                                 ACKTimer_OVERLOW_NO_CHANGE     |   \
                                                                 ACKTimer_UNDERFLOW_CLEAR)
    #else
        #define ACKTimer_PWM_MODE_CENTER                (ACKTimer_CC_MATCH_INVERT       |   \
                                                                 ACKTimer_OVERLOW_SET           |   \
                                                                 ACKTimer_UNDERFLOW_CLEAR)
    #endif /* (ACKTimer_CY_TCPWM_4000) */
#else
    #define ACKTimer_PWM_MODE_CENTER                (ACKTimer_CC_MATCH_INVERT       |   \
                                                             ACKTimer_OVERLOW_NO_CHANGE     |   \
                                                             ACKTimer_UNDERFLOW_CLEAR)
#endif /* (ACKTimer_CY_TCPWM_NEW) */

/* Command operations without condition */
#define ACKTimer_CMD_CAPTURE                    (0u)
#define ACKTimer_CMD_RELOAD                     (8u)
#define ACKTimer_CMD_STOP                       (16u)
#define ACKTimer_CMD_START                      (24u)

/* Status */
#define ACKTimer_STATUS_DOWN                    (1u)
#define ACKTimer_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   ACKTimer_Init(void);
void   ACKTimer_Enable(void);
void   ACKTimer_Start(void);
void   ACKTimer_Stop(void);

void   ACKTimer_SetMode(uint32 mode);
void   ACKTimer_SetCounterMode(uint32 counterMode);
void   ACKTimer_SetPWMMode(uint32 modeMask);
void   ACKTimer_SetQDMode(uint32 qdMode);

void   ACKTimer_SetPrescaler(uint32 prescaler);
void   ACKTimer_TriggerCommand(uint32 mask, uint32 command);
void   ACKTimer_SetOneShot(uint32 oneShotEnable);
uint32 ACKTimer_ReadStatus(void);

void   ACKTimer_SetPWMSyncKill(uint32 syncKillEnable);
void   ACKTimer_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   ACKTimer_SetPWMDeadTime(uint32 deadTime);
void   ACKTimer_SetPWMInvert(uint32 mask);

void   ACKTimer_SetInterruptMode(uint32 interruptMask);
uint32 ACKTimer_GetInterruptSourceMasked(void);
uint32 ACKTimer_GetInterruptSource(void);
void   ACKTimer_ClearInterrupt(uint32 interruptMask);
void   ACKTimer_SetInterrupt(uint32 interruptMask);

void   ACKTimer_WriteCounter(uint32 count);
uint32 ACKTimer_ReadCounter(void);

uint32 ACKTimer_ReadCapture(void);
uint32 ACKTimer_ReadCaptureBuf(void);

void   ACKTimer_WritePeriod(uint32 period);
uint32 ACKTimer_ReadPeriod(void);
void   ACKTimer_WritePeriodBuf(uint32 periodBuf);
uint32 ACKTimer_ReadPeriodBuf(void);

void   ACKTimer_WriteCompare(uint32 compare);
uint32 ACKTimer_ReadCompare(void);
void   ACKTimer_WriteCompareBuf(uint32 compareBuf);
uint32 ACKTimer_ReadCompareBuf(void);

void   ACKTimer_SetPeriodSwap(uint32 swapEnable);
void   ACKTimer_SetCompareSwap(uint32 swapEnable);

void   ACKTimer_SetCaptureMode(uint32 triggerMode);
void   ACKTimer_SetReloadMode(uint32 triggerMode);
void   ACKTimer_SetStartMode(uint32 triggerMode);
void   ACKTimer_SetStopMode(uint32 triggerMode);
void   ACKTimer_SetCountMode(uint32 triggerMode);

void   ACKTimer_SaveConfig(void);
void   ACKTimer_RestoreConfig(void);
void   ACKTimer_Sleep(void);
void   ACKTimer_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define ACKTimer_BLOCK_CONTROL_REG              (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define ACKTimer_BLOCK_CONTROL_PTR              ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define ACKTimer_COMMAND_REG                    (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define ACKTimer_COMMAND_PTR                    ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define ACKTimer_INTRRUPT_CAUSE_REG             (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define ACKTimer_INTRRUPT_CAUSE_PTR             ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define ACKTimer_CONTROL_REG                    (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__CTRL )
#define ACKTimer_CONTROL_PTR                    ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__CTRL )
#define ACKTimer_STATUS_REG                     (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__STATUS )
#define ACKTimer_STATUS_PTR                     ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__STATUS )
#define ACKTimer_COUNTER_REG                    (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__COUNTER )
#define ACKTimer_COUNTER_PTR                    ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__COUNTER )
#define ACKTimer_COMP_CAP_REG                   (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__CC )
#define ACKTimer_COMP_CAP_PTR                   ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__CC )
#define ACKTimer_COMP_CAP_BUF_REG               (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define ACKTimer_COMP_CAP_BUF_PTR               ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define ACKTimer_PERIOD_REG                     (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__PERIOD )
#define ACKTimer_PERIOD_PTR                     ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__PERIOD )
#define ACKTimer_PERIOD_BUF_REG                 (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define ACKTimer_PERIOD_BUF_PTR                 ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define ACKTimer_TRIG_CONTROL0_REG              (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define ACKTimer_TRIG_CONTROL0_PTR              ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define ACKTimer_TRIG_CONTROL1_REG              (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define ACKTimer_TRIG_CONTROL1_PTR              ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define ACKTimer_TRIG_CONTROL2_REG              (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define ACKTimer_TRIG_CONTROL2_PTR              ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define ACKTimer_INTERRUPT_REQ_REG              (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR )
#define ACKTimer_INTERRUPT_REQ_PTR              ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR )
#define ACKTimer_INTERRUPT_SET_REG              (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define ACKTimer_INTERRUPT_SET_PTR              ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define ACKTimer_INTERRUPT_MASK_REG             (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define ACKTimer_INTERRUPT_MASK_PTR             ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define ACKTimer_INTERRUPT_MASKED_REG           (*(reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR_MASKED )
#define ACKTimer_INTERRUPT_MASKED_PTR           ( (reg32 *) ACKTimer_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define ACKTimer_MASK                           ((uint32)ACKTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define ACKTimer_RELOAD_CC_SHIFT                (0u)
#define ACKTimer_RELOAD_PERIOD_SHIFT            (1u)
#define ACKTimer_PWM_SYNC_KILL_SHIFT            (2u)
#define ACKTimer_PWM_STOP_KILL_SHIFT            (3u)
#define ACKTimer_PRESCALER_SHIFT                (8u)
#define ACKTimer_UPDOWN_SHIFT                   (16u)
#define ACKTimer_ONESHOT_SHIFT                  (18u)
#define ACKTimer_QUAD_MODE_SHIFT                (20u)
#define ACKTimer_INV_OUT_SHIFT                  (20u)
#define ACKTimer_INV_COMPL_OUT_SHIFT            (21u)
#define ACKTimer_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define ACKTimer_RELOAD_CC_MASK                 ((uint32)(ACKTimer_1BIT_MASK        <<  \
                                                                            ACKTimer_RELOAD_CC_SHIFT))
#define ACKTimer_RELOAD_PERIOD_MASK             ((uint32)(ACKTimer_1BIT_MASK        <<  \
                                                                            ACKTimer_RELOAD_PERIOD_SHIFT))
#define ACKTimer_PWM_SYNC_KILL_MASK             ((uint32)(ACKTimer_1BIT_MASK        <<  \
                                                                            ACKTimer_PWM_SYNC_KILL_SHIFT))
#define ACKTimer_PWM_STOP_KILL_MASK             ((uint32)(ACKTimer_1BIT_MASK        <<  \
                                                                            ACKTimer_PWM_STOP_KILL_SHIFT))
#define ACKTimer_PRESCALER_MASK                 ((uint32)(ACKTimer_8BIT_MASK        <<  \
                                                                            ACKTimer_PRESCALER_SHIFT))
#define ACKTimer_UPDOWN_MASK                    ((uint32)(ACKTimer_2BIT_MASK        <<  \
                                                                            ACKTimer_UPDOWN_SHIFT))
#define ACKTimer_ONESHOT_MASK                   ((uint32)(ACKTimer_1BIT_MASK        <<  \
                                                                            ACKTimer_ONESHOT_SHIFT))
#define ACKTimer_QUAD_MODE_MASK                 ((uint32)(ACKTimer_3BIT_MASK        <<  \
                                                                            ACKTimer_QUAD_MODE_SHIFT))
#define ACKTimer_INV_OUT_MASK                   ((uint32)(ACKTimer_2BIT_MASK        <<  \
                                                                            ACKTimer_INV_OUT_SHIFT))
#define ACKTimer_MODE_MASK                      ((uint32)(ACKTimer_3BIT_MASK        <<  \
                                                                            ACKTimer_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define ACKTimer_CAPTURE_SHIFT                  (0u)
#define ACKTimer_COUNT_SHIFT                    (2u)
#define ACKTimer_RELOAD_SHIFT                   (4u)
#define ACKTimer_STOP_SHIFT                     (6u)
#define ACKTimer_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define ACKTimer_CAPTURE_MASK                   ((uint32)(ACKTimer_2BIT_MASK        <<  \
                                                                  ACKTimer_CAPTURE_SHIFT))
#define ACKTimer_COUNT_MASK                     ((uint32)(ACKTimer_2BIT_MASK        <<  \
                                                                  ACKTimer_COUNT_SHIFT))
#define ACKTimer_RELOAD_MASK                    ((uint32)(ACKTimer_2BIT_MASK        <<  \
                                                                  ACKTimer_RELOAD_SHIFT))
#define ACKTimer_STOP_MASK                      ((uint32)(ACKTimer_2BIT_MASK        <<  \
                                                                  ACKTimer_STOP_SHIFT))
#define ACKTimer_START_MASK                     ((uint32)(ACKTimer_2BIT_MASK        <<  \
                                                                  ACKTimer_START_SHIFT))

/* MASK */
#define ACKTimer_1BIT_MASK                      ((uint32)0x01u)
#define ACKTimer_2BIT_MASK                      ((uint32)0x03u)
#define ACKTimer_3BIT_MASK                      ((uint32)0x07u)
#define ACKTimer_6BIT_MASK                      ((uint32)0x3Fu)
#define ACKTimer_8BIT_MASK                      ((uint32)0xFFu)
#define ACKTimer_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define ACKTimer_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define ACKTimer_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(ACKTimer_QUAD_ENCODING_MODES     << ACKTimer_QUAD_MODE_SHIFT))       |\
         ((uint32)(ACKTimer_CONFIG                  << ACKTimer_MODE_SHIFT)))

#define ACKTimer_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(ACKTimer_PWM_STOP_EVENT          << ACKTimer_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(ACKTimer_PWM_OUT_INVERT          << ACKTimer_INV_OUT_SHIFT))         |\
         ((uint32)(ACKTimer_PWM_OUT_N_INVERT        << ACKTimer_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(ACKTimer_PWM_MODE                << ACKTimer_MODE_SHIFT)))

#define ACKTimer_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(ACKTimer_PWM_RUN_MODE         << ACKTimer_ONESHOT_SHIFT))
            
#define ACKTimer_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(ACKTimer_PWM_ALIGN            << ACKTimer_UPDOWN_SHIFT))

#define ACKTimer_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(ACKTimer_PWM_KILL_EVENT      << ACKTimer_PWM_SYNC_KILL_SHIFT))

#define ACKTimer_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(ACKTimer_PWM_DEAD_TIME_CYCLE  << ACKTimer_PRESCALER_SHIFT))

#define ACKTimer_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(ACKTimer_PWM_PRESCALER        << ACKTimer_PRESCALER_SHIFT))

#define ACKTimer_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(ACKTimer_TC_PRESCALER            << ACKTimer_PRESCALER_SHIFT))       |\
         ((uint32)(ACKTimer_TC_COUNTER_MODE         << ACKTimer_UPDOWN_SHIFT))          |\
         ((uint32)(ACKTimer_TC_RUN_MODE             << ACKTimer_ONESHOT_SHIFT))         |\
         ((uint32)(ACKTimer_TC_COMP_CAP_MODE        << ACKTimer_MODE_SHIFT)))
        
#define ACKTimer_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(ACKTimer_QUAD_PHIA_SIGNAL_MODE   << ACKTimer_COUNT_SHIFT))           |\
         ((uint32)(ACKTimer_QUAD_INDEX_SIGNAL_MODE  << ACKTimer_RELOAD_SHIFT))          |\
         ((uint32)(ACKTimer_QUAD_STOP_SIGNAL_MODE   << ACKTimer_STOP_SHIFT))            |\
         ((uint32)(ACKTimer_QUAD_PHIB_SIGNAL_MODE   << ACKTimer_START_SHIFT)))

#define ACKTimer_PWM_SIGNALS_MODES                                                              \
        (((uint32)(ACKTimer_PWM_SWITCH_SIGNAL_MODE  << ACKTimer_CAPTURE_SHIFT))         |\
         ((uint32)(ACKTimer_PWM_COUNT_SIGNAL_MODE   << ACKTimer_COUNT_SHIFT))           |\
         ((uint32)(ACKTimer_PWM_RELOAD_SIGNAL_MODE  << ACKTimer_RELOAD_SHIFT))          |\
         ((uint32)(ACKTimer_PWM_STOP_SIGNAL_MODE    << ACKTimer_STOP_SHIFT))            |\
         ((uint32)(ACKTimer_PWM_START_SIGNAL_MODE   << ACKTimer_START_SHIFT)))

#define ACKTimer_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(ACKTimer_TC_CAPTURE_SIGNAL_MODE  << ACKTimer_CAPTURE_SHIFT))         |\
         ((uint32)(ACKTimer_TC_COUNT_SIGNAL_MODE    << ACKTimer_COUNT_SHIFT))           |\
         ((uint32)(ACKTimer_TC_RELOAD_SIGNAL_MODE   << ACKTimer_RELOAD_SHIFT))          |\
         ((uint32)(ACKTimer_TC_STOP_SIGNAL_MODE     << ACKTimer_STOP_SHIFT))            |\
         ((uint32)(ACKTimer_TC_START_SIGNAL_MODE    << ACKTimer_START_SHIFT)))
        
#define ACKTimer_TIMER_UPDOWN_CNT_USED                                                          \
                ((ACKTimer__COUNT_UPDOWN0 == ACKTimer_TC_COUNTER_MODE)                  ||\
                 (ACKTimer__COUNT_UPDOWN1 == ACKTimer_TC_COUNTER_MODE))

#define ACKTimer_PWM_UPDOWN_CNT_USED                                                            \
                ((ACKTimer__CENTER == ACKTimer_PWM_ALIGN)                               ||\
                 (ACKTimer__ASYMMETRIC == ACKTimer_PWM_ALIGN))               
        
#define ACKTimer_PWM_PR_INIT_VALUE              (1u)
#define ACKTimer_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_ACKTimer_H */

/* [] END OF FILE */
