/*******************************************************************************
* File Name: ACKTimer_PM.c
* Version 2.0
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ACKTimer.h"

static ACKTimer_BACKUP_STRUCT ACKTimer_backup;


/*******************************************************************************
* Function Name: ACKTimer_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: ACKTimer_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_Sleep(void)
{
    if(0u != (ACKTimer_BLOCK_CONTROL_REG & ACKTimer_MASK))
    {
        ACKTimer_backup.enableState = 1u;
    }
    else
    {
        ACKTimer_backup.enableState = 0u;
    }

    ACKTimer_Stop();
    ACKTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: ACKTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: ACKTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ACKTimer_Wakeup(void)
{
    ACKTimer_RestoreConfig();

    if(0u != ACKTimer_backup.enableState)
    {
        ACKTimer_Enable();
    }
}


/* [] END OF FILE */
