/*******************************************************************************
* File Name: ADC_Hanna_PM.c
* Version 2.10
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ADC_Hanna.h"


/***************************************
* Local data allocation
***************************************/

static ADC_Hanna_BACKUP_STRUCT  ADC_Hanna_backup =
{
    ADC_Hanna_DISABLED
};


/*******************************************************************************
* Function Name: ADC_Hanna_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC_Hanna_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC_Hanna_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC_Hanna_RestoreConfig(void)
{
    /* All congiguration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC_Hanna_Sleep
********************************************************************************
*
* Summary:
*  Stops the ADC operation and saves the configuration registers and component
*  enable state. Should be called just prior to entering sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ADC_Hanna_backup - modified.
*
*******************************************************************************/
void ADC_Hanna_Sleep(void)
{
    /* During deepsleep/ hibernate mode keep SARMUX active, i.e. do not open
    *   all switches (disconnect), to be used for ADFT
    */
    ADC_Hanna_SAR_DFT_CTRL_REG |= ADC_Hanna_ADFT_OVERRIDE;
    if((ADC_Hanna_SAR_CTRL_REG  & ADC_Hanna_ENABLE) != 0u)
    {
        if((ADC_Hanna_SAR_SAMPLE_CTRL_REG & ADC_Hanna_CONTINUOUS_EN) != 0u)
        {
            ADC_Hanna_backup.enableState = ADC_Hanna_ENABLED | ADC_Hanna_STARTED;
        }
        else
        {
            ADC_Hanna_backup.enableState = ADC_Hanna_ENABLED;
        }
        ADC_Hanna_StopConvert();
        ADC_Hanna_Stop();
        
        /* Disable the SAR internal pump before entering the chip low power mode */
        if((ADC_Hanna_SAR_CTRL_REG & ADC_Hanna_BOOSTPUMP_EN) != 0u)
        {
            ADC_Hanna_SAR_CTRL_REG &= (uint32)~ADC_Hanna_BOOSTPUMP_EN;
            ADC_Hanna_backup.enableState |= ADC_Hanna_BOOSTPUMP_ENABLED;
        }
    }
    else
    {
        ADC_Hanna_backup.enableState = ADC_Hanna_DISABLED;
    }
}


/*******************************************************************************
* Function Name: ADC_Hanna_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component enable state and configuration registers.
*  This should be called just after awaking from sleep mode.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ADC_Hanna_backup - used.
*
*******************************************************************************/
void ADC_Hanna_Wakeup(void)
{
    ADC_Hanna_SAR_DFT_CTRL_REG &= (uint32)~ADC_Hanna_ADFT_OVERRIDE;
    if(ADC_Hanna_backup.enableState != ADC_Hanna_DISABLED)
    {
        /* Enable the SAR internal pump  */
        if((ADC_Hanna_backup.enableState & ADC_Hanna_BOOSTPUMP_ENABLED) != 0u)
        {
            ADC_Hanna_SAR_CTRL_REG |= ADC_Hanna_BOOSTPUMP_EN;
        }
        ADC_Hanna_Enable();
        if((ADC_Hanna_backup.enableState & ADC_Hanna_STARTED) != 0u)
        {
            ADC_Hanna_StartConvert();
        }
    }
}
/* [] END OF FILE */
