/*******************************************************************************
* File Name: AN_Ce.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "AN_Ce.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        AN_Ce_PC =   (AN_Ce_PC & \
                                (uint32)(~(uint32)(AN_Ce_DRIVE_MODE_IND_MASK << (AN_Ce_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (AN_Ce_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: AN_Ce_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void AN_Ce_Write(uint8 value) 
{
    uint8 drVal = (uint8)(AN_Ce_DR & (uint8)(~AN_Ce_MASK));
    drVal = (drVal | ((uint8)(value << AN_Ce_SHIFT) & AN_Ce_MASK));
    AN_Ce_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: AN_Ce_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  AN_Ce_DM_STRONG     Strong Drive 
*  AN_Ce_DM_OD_HI      Open Drain, Drives High 
*  AN_Ce_DM_OD_LO      Open Drain, Drives Low 
*  AN_Ce_DM_RES_UP     Resistive Pull Up 
*  AN_Ce_DM_RES_DWN    Resistive Pull Down 
*  AN_Ce_DM_RES_UPDWN  Resistive Pull Up/Down 
*  AN_Ce_DM_DIG_HIZ    High Impedance Digital 
*  AN_Ce_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void AN_Ce_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(AN_Ce__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: AN_Ce_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro AN_Ce_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 AN_Ce_Read(void) 
{
    return (uint8)((AN_Ce_PS & AN_Ce_MASK) >> AN_Ce_SHIFT);
}


/*******************************************************************************
* Function Name: AN_Ce_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 AN_Ce_ReadDataReg(void) 
{
    return (uint8)((AN_Ce_DR & AN_Ce_MASK) >> AN_Ce_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(AN_Ce_INTSTAT) 

    /*******************************************************************************
    * Function Name: AN_Ce_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 AN_Ce_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(AN_Ce_INTSTAT & AN_Ce_MASK);
		AN_Ce_INTSTAT = maskedStatus;
        return maskedStatus >> AN_Ce_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
