/*******************************************************************************
* File Name: An6.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "An6.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        An6_PC =   (An6_PC & \
                                (uint32)(~(uint32)(An6_DRIVE_MODE_IND_MASK << (An6_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (An6_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: An6_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void An6_Write(uint8 value) 
{
    uint8 drVal = (uint8)(An6_DR & (uint8)(~An6_MASK));
    drVal = (drVal | ((uint8)(value << An6_SHIFT) & An6_MASK));
    An6_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: An6_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  An6_DM_STRONG     Strong Drive 
*  An6_DM_OD_HI      Open Drain, Drives High 
*  An6_DM_OD_LO      Open Drain, Drives Low 
*  An6_DM_RES_UP     Resistive Pull Up 
*  An6_DM_RES_DWN    Resistive Pull Down 
*  An6_DM_RES_UPDWN  Resistive Pull Up/Down 
*  An6_DM_DIG_HIZ    High Impedance Digital 
*  An6_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void An6_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(An6__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: An6_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro An6_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 An6_Read(void) 
{
    return (uint8)((An6_PS & An6_MASK) >> An6_SHIFT);
}


/*******************************************************************************
* Function Name: An6_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 An6_ReadDataReg(void) 
{
    return (uint8)((An6_DR & An6_MASK) >> An6_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(An6_INTSTAT) 

    /*******************************************************************************
    * Function Name: An6_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 An6_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(An6_INTSTAT & An6_MASK);
		An6_INTSTAT = maskedStatus;
        return maskedStatus >> An6_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
