/*******************************************************************************
* File Name: CounterClockPLC.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_CounterClockPLC_H)
#define CY_CLOCK_CounterClockPLC_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void CounterClockPLC_StartEx(uint32 alignClkDiv);
#define CounterClockPLC_Start() \
    CounterClockPLC_StartEx(CounterClockPLC__PA_DIV_ID)

#else

void CounterClockPLC_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void CounterClockPLC_Stop(void);

void CounterClockPLC_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 CounterClockPLC_GetDividerRegister(void);
uint8  CounterClockPLC_GetFractionalDividerRegister(void);

#define CounterClockPLC_Enable()                         CounterClockPLC_Start()
#define CounterClockPLC_Disable()                        CounterClockPLC_Stop()
#define CounterClockPLC_SetDividerRegister(clkDivider, reset)  \
    CounterClockPLC_SetFractionalDividerRegister((clkDivider), 0u)
#define CounterClockPLC_SetDivider(clkDivider)           CounterClockPLC_SetDividerRegister((clkDivider), 1u)
#define CounterClockPLC_SetDividerValue(clkDivider)      CounterClockPLC_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define CounterClockPLC_DIV_ID     CounterClockPLC__DIV_ID

#define CounterClockPLC_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define CounterClockPLC_CTRL_REG   (*(reg32 *)CounterClockPLC__CTRL_REGISTER)
#define CounterClockPLC_DIV_REG    (*(reg32 *)CounterClockPLC__DIV_REGISTER)

#define CounterClockPLC_CMD_DIV_SHIFT          (0u)
#define CounterClockPLC_CMD_PA_DIV_SHIFT       (8u)
#define CounterClockPLC_CMD_DISABLE_SHIFT      (30u)
#define CounterClockPLC_CMD_ENABLE_SHIFT       (31u)

#define CounterClockPLC_CMD_DISABLE_MASK       ((uint32)((uint32)1u << CounterClockPLC_CMD_DISABLE_SHIFT))
#define CounterClockPLC_CMD_ENABLE_MASK        ((uint32)((uint32)1u << CounterClockPLC_CMD_ENABLE_SHIFT))

#define CounterClockPLC_DIV_FRAC_MASK  (0x000000F8u)
#define CounterClockPLC_DIV_FRAC_SHIFT (3u)
#define CounterClockPLC_DIV_INT_MASK   (0xFFFFFF00u)
#define CounterClockPLC_DIV_INT_SHIFT  (8u)

#else 

#define CounterClockPLC_DIV_REG        (*(reg32 *)CounterClockPLC__REGISTER)
#define CounterClockPLC_ENABLE_REG     CounterClockPLC_DIV_REG
#define CounterClockPLC_DIV_FRAC_MASK  CounterClockPLC__FRAC_MASK
#define CounterClockPLC_DIV_FRAC_SHIFT (16u)
#define CounterClockPLC_DIV_INT_MASK   CounterClockPLC__DIVIDER_MASK
#define CounterClockPLC_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_CounterClockPLC_H) */

/* [] END OF FILE */
