/*******************************************************************************
* File Name: .h
* Version 1.20
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_PC_COM_UART_H)
#define CY_SCB_PVT_PC_COM_UART_H

#include "PC_COM_UART.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define PC_COM_UART_SetI2CExtClkInterruptMode(interruptMask) PC_COM_UART_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define PC_COM_UART_ClearI2CExtClkInterruptSource(interruptMask) PC_COM_UART_CLEAR_INTR_I2C_EC(interruptMask)
#define PC_COM_UART_GetI2CExtClkInterruptSource()                (PC_COM_UART_INTR_I2C_EC_REG)
#define PC_COM_UART_GetI2CExtClkInterruptMode()                  (PC_COM_UART_INTR_I2C_EC_MASK_REG)
#define PC_COM_UART_GetI2CExtClkInterruptSourceMasked()          (PC_COM_UART_INTR_I2C_EC_MASKED_REG)

#if(!PC_COM_UART_CY_SCBIP_V1_I2C_ONLY)
/* APIs to service INTR_SPI_EC register */
#define PC_COM_UART_SetSpiExtClkInterruptMode(interruptMask) PC_COM_UART_WRITE_INTR_SPI_EC_MASK(interruptMask)
#define PC_COM_UART_ClearSpiExtClkInterruptSource(interruptMask) PC_COM_UART_CLEAR_INTR_SPI_EC(interruptMask)
#define PC_COM_UART_GetExtSpiClkInterruptSource()                 (PC_COM_UART_INTR_SPI_EC_REG)
#define PC_COM_UART_GetExtSpiClkInterruptMode()                   (PC_COM_UART_INTR_SPI_EC_MASK_REG)
#define PC_COM_UART_GetExtSpiClkInterruptSourceMasked()           (PC_COM_UART_INTR_SPI_EC_MASKED_REG)
#endif /* (!PC_COM_UART_CY_SCBIP_V1_I2C_ONLY) */

#if(PC_COM_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void PC_COM_UART_SetPins(uint32 mode, uint32 subMode, uint32 uartTxRx);
#endif /* (PC_COM_UART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if !defined (CY_REMOVE_PC_COM_UART_CUSTOM_INTR_HANDLER)
    extern cyisraddress PC_COM_UART_customIntrHandler;
#endif /* !defined (CY_REMOVE_PC_COM_UART_CUSTOM_INTR_HANDLER) */

extern PC_COM_UART_BACKUP_STRUCT PC_COM_UART_backup;

#if(PC_COM_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common config vars */
    extern uint8 PC_COM_UART_scbMode;
    extern uint8 PC_COM_UART_scbEnableWake;
    extern uint8 PC_COM_UART_scbEnableIntr;

    /* I2C config vars */
    extern uint8 PC_COM_UART_mode;
    extern uint8 PC_COM_UART_acceptAddr;

    /* SPI/UART config vars */
    extern volatile uint8 * PC_COM_UART_rxBuffer;
    extern uint8   PC_COM_UART_rxDataBits;
    extern uint32  PC_COM_UART_rxBufferSize;

    extern volatile uint8 * PC_COM_UART_txBuffer;
    extern uint8   PC_COM_UART_txDataBits;
    extern uint32  PC_COM_UART_txBufferSize;

    /* EZI2C config vars */
    extern uint8 PC_COM_UART_numberOfAddr;
    extern uint8 PC_COM_UART_subAddrSize;
#endif /* (PC_COM_UART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*  Conditional Macro
****************************************/

#if(PC_COM_UART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Define run time operation mode */
    #define PC_COM_UART_SCB_MODE_I2C_RUNTM_CFG     (PC_COM_UART_SCB_MODE_I2C      == PC_COM_UART_scbMode)
    #define PC_COM_UART_SCB_MODE_SPI_RUNTM_CFG     (PC_COM_UART_SCB_MODE_SPI      == PC_COM_UART_scbMode)
    #define PC_COM_UART_SCB_MODE_UART_RUNTM_CFG    (PC_COM_UART_SCB_MODE_UART     == PC_COM_UART_scbMode)
    #define PC_COM_UART_SCB_MODE_EZI2C_RUNTM_CFG   (PC_COM_UART_SCB_MODE_EZI2C    == PC_COM_UART_scbMode)
    #define PC_COM_UART_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (PC_COM_UART_SCB_MODE_UNCONFIG == PC_COM_UART_scbMode)

    /* Define wakeup enable */
    #define PC_COM_UART_SCB_WAKE_ENABLE_CHECK        (0u != PC_COM_UART_scbEnableWake)
#endif /* (PC_COM_UART_SCB_MODE_UNCONFIG_CONST_CFG) */

#endif /* (CY_SCB_PVT_PC_COM_UART_H) */


/* [] END OF FILE */
