/*******************************************************************************
* File Name: PC_COM_UART_SPI_UART_INT.c
* Version 1.20
*
* Description:
*  This file provides the source code to the Interrupt Service Routine for
*  the SCB Component in SPI and UART modes.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PC_COM_UART_PVT.h"
#include "PC_COM_UART_SPI_UART_PVT.h"


/*******************************************************************************
* Function Name: PC_COM_UART_SPI_UART_ISR
********************************************************************************
*
* Summary:
*  Handles the Interrupt Service Routine for the SCB SPI or UART modes.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
CY_ISR(PC_COM_UART_SPI_UART_ISR)
{
#if(PC_COM_UART_INTERNAL_RX_SW_BUFFER_CONST)
    uint32 locHead;
    uint32 dataRx;
#endif /* (PC_COM_UART_INTERNAL_RX_SW_BUFFER_CONST) */

#if(PC_COM_UART_INTERNAL_TX_SW_BUFFER_CONST)
    uint32 locTail;
#endif /* (PC_COM_UART_INTERNAL_TX_SW_BUFFER_CONST) */

    if(NULL != PC_COM_UART_customIntrHandler)
    {
        PC_COM_UART_customIntrHandler();
    }

    #if(PC_COM_UART_CHECK_SPI_WAKE_ENABLE)
    {
        /* Clear SPI wakeup source */
        PC_COM_UART_ClearSpiExtClkInterruptSource(PC_COM_UART_INTR_SPI_EC_WAKE_UP);
    }
    #endif

    #if(PC_COM_UART_CHECK_RX_SW_BUFFER)
    {
        if(PC_COM_UART_CHECK_INTR_RX_MASKED(PC_COM_UART_INTR_RX_NOT_EMPTY))
        {
            while(0u != PC_COM_UART_GET_RX_FIFO_ENTRIES)
            {
                /* Get data from RX FIFO */
                dataRx = PC_COM_UART_RX_FIFO_RD_REG;

                /* Move local head index */
                locHead = (PC_COM_UART_rxBufferHead + 1u);

                /* Adjust local head index */
                if(PC_COM_UART_RX_BUFFER_SIZE == locHead)
                {
                    locHead = 0u;
                }

                if(locHead == PC_COM_UART_rxBufferTail)
                {
                    /* Overflow: through away new data */
                    PC_COM_UART_rxBufferOverflow = (uint8) PC_COM_UART_INTR_RX_OVERFLOW;
                }
                else
                {
                    /* Store received data */
                    PC_COM_UART_PutWordInRxBuffer(locHead, dataRx);

                    /* Move head index */
                    PC_COM_UART_rxBufferHead = locHead;
                }
            }

            PC_COM_UART_ClearRxInterruptSource(PC_COM_UART_INTR_RX_NOT_EMPTY);
        }
    }
    #endif


    #if(PC_COM_UART_CHECK_TX_SW_BUFFER)
    {
        if(PC_COM_UART_CHECK_INTR_TX_MASKED(PC_COM_UART_INTR_TX_NOT_FULL))
        {
            /* Put data into TX FIFO */
            while(PC_COM_UART_FIFO_SIZE != PC_COM_UART_GET_TX_FIFO_ENTRIES)
            {
                /* Check for a room in TX software buffer */
                if(PC_COM_UART_txBufferHead != PC_COM_UART_txBufferTail)
                {
                    /* Move local tail index */
                    locTail = (PC_COM_UART_txBufferTail + 1u);

                    /* Adjust local tail index */
                    if(PC_COM_UART_TX_BUFFER_SIZE == locTail)
                    {
                        locTail = 0u;
                    }

                    /* Put data into TX FIFO */
                    PC_COM_UART_TX_FIFO_WR_REG = PC_COM_UART_GetWordFromTxBuffer(locTail);

                    /* Move tail index */
                    PC_COM_UART_txBufferTail = locTail;
                }
                else
                {
                    /* TX software buffer is empty: complete transmition */
                    PC_COM_UART_DISABLE_INTR_TX(PC_COM_UART_INTR_TX_NOT_FULL);
                    break;
                }
            }

            PC_COM_UART_ClearTxInterruptSource(PC_COM_UART_INTR_TX_NOT_FULL);
        }
    }
    #endif
}


/* [] END OF FILE */
