/*******************************************************************************
* File Name: PLCTimer.c
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the PLCTimer
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PLCTimer.h"

uint8 PLCTimer_initVar = 0u;


/*******************************************************************************
* Function Name: PLCTimer_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default PLCTimer configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (PLCTimer__QUAD == PLCTimer_CONFIG)
        PLCTimer_CONTROL_REG = PLCTimer_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        PLCTimer_TRIG_CONTROL1_REG  = PLCTimer_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        PLCTimer_SetInterruptMode(PLCTimer_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        PLCTimer_SetCounterMode(PLCTimer_COUNT_DOWN);
        PLCTimer_WritePeriod(PLCTimer_QUAD_PERIOD_INIT_VALUE);
        PLCTimer_WriteCounter(PLCTimer_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (PLCTimer__QUAD == PLCTimer_CONFIG) */

    #if (PLCTimer__TIMER == PLCTimer_CONFIG)
        PLCTimer_CONTROL_REG = PLCTimer_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        PLCTimer_TRIG_CONTROL1_REG  = PLCTimer_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        PLCTimer_SetInterruptMode(PLCTimer_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        PLCTimer_WritePeriod(PLCTimer_TC_PERIOD_VALUE );

        #if (PLCTimer__COMPARE == PLCTimer_TC_COMP_CAP_MODE)
            PLCTimer_WriteCompare(PLCTimer_TC_COMPARE_VALUE);

            #if (1u == PLCTimer_TC_COMPARE_SWAP)
                PLCTimer_SetCompareSwap(1u);
                PLCTimer_WriteCompareBuf(PLCTimer_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == PLCTimer_TC_COMPARE_SWAP) */
        #endif  /* (PLCTimer__COMPARE == PLCTimer_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (PLCTimer_CY_TCPWM_V2 && PLCTimer_TIMER_UPDOWN_CNT_USED && !PLCTimer_CY_TCPWM_4000)
            PLCTimer_WriteCounter(1u);
        #elif(PLCTimer__COUNT_DOWN == PLCTimer_TC_COUNTER_MODE)
            PLCTimer_WriteCounter(PLCTimer_TC_PERIOD_VALUE);
        #else
            PLCTimer_WriteCounter(0u);
        #endif /* (PLCTimer_CY_TCPWM_V2 && PLCTimer_TIMER_UPDOWN_CNT_USED && !PLCTimer_CY_TCPWM_4000) */
    #endif  /* (PLCTimer__TIMER == PLCTimer_CONFIG) */

    #if (PLCTimer__PWM_SEL == PLCTimer_CONFIG)
        PLCTimer_CONTROL_REG = PLCTimer_CTRL_PWM_BASE_CONFIG;

        #if (PLCTimer__PWM_PR == PLCTimer_PWM_MODE)
            PLCTimer_CONTROL_REG |= PLCTimer_CTRL_PWM_RUN_MODE;
            PLCTimer_WriteCounter(PLCTimer_PWM_PR_INIT_VALUE);
        #else
            PLCTimer_CONTROL_REG |= PLCTimer_CTRL_PWM_ALIGN | PLCTimer_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (PLCTimer_CY_TCPWM_V2 && PLCTimer_PWM_UPDOWN_CNT_USED && !PLCTimer_CY_TCPWM_4000)
                PLCTimer_WriteCounter(1u);
            #elif (PLCTimer__RIGHT == PLCTimer_PWM_ALIGN)
                PLCTimer_WriteCounter(PLCTimer_PWM_PERIOD_VALUE);
            #else 
                PLCTimer_WriteCounter(0u);
            #endif  /* (PLCTimer_CY_TCPWM_V2 && PLCTimer_PWM_UPDOWN_CNT_USED && !PLCTimer_CY_TCPWM_4000) */
        #endif  /* (PLCTimer__PWM_PR == PLCTimer_PWM_MODE) */

        #if (PLCTimer__PWM_DT == PLCTimer_PWM_MODE)
            PLCTimer_CONTROL_REG |= PLCTimer_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (PLCTimer__PWM_DT == PLCTimer_PWM_MODE) */

        #if (PLCTimer__PWM == PLCTimer_PWM_MODE)
            PLCTimer_CONTROL_REG |= PLCTimer_CTRL_PWM_PRESCALER;
        #endif  /* (PLCTimer__PWM == PLCTimer_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        PLCTimer_TRIG_CONTROL1_REG  = PLCTimer_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        PLCTimer_SetInterruptMode(PLCTimer_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (PLCTimer__PWM_PR == PLCTimer_PWM_MODE)
            PLCTimer_TRIG_CONTROL2_REG =
                    (PLCTimer_CC_MATCH_NO_CHANGE    |
                    PLCTimer_OVERLOW_NO_CHANGE      |
                    PLCTimer_UNDERFLOW_NO_CHANGE);
        #else
            #if (PLCTimer__LEFT == PLCTimer_PWM_ALIGN)
                PLCTimer_TRIG_CONTROL2_REG = PLCTimer_PWM_MODE_LEFT;
            #endif  /* ( PLCTimer_PWM_LEFT == PLCTimer_PWM_ALIGN) */

            #if (PLCTimer__RIGHT == PLCTimer_PWM_ALIGN)
                PLCTimer_TRIG_CONTROL2_REG = PLCTimer_PWM_MODE_RIGHT;
            #endif  /* ( PLCTimer_PWM_RIGHT == PLCTimer_PWM_ALIGN) */

            #if (PLCTimer__CENTER == PLCTimer_PWM_ALIGN)
                PLCTimer_TRIG_CONTROL2_REG = PLCTimer_PWM_MODE_CENTER;
            #endif  /* ( PLCTimer_PWM_CENTER == PLCTimer_PWM_ALIGN) */

            #if (PLCTimer__ASYMMETRIC == PLCTimer_PWM_ALIGN)
                PLCTimer_TRIG_CONTROL2_REG = PLCTimer_PWM_MODE_ASYM;
            #endif  /* (PLCTimer__ASYMMETRIC == PLCTimer_PWM_ALIGN) */
        #endif  /* (PLCTimer__PWM_PR == PLCTimer_PWM_MODE) */

        /* Set other values from customizer */
        PLCTimer_WritePeriod(PLCTimer_PWM_PERIOD_VALUE );
        PLCTimer_WriteCompare(PLCTimer_PWM_COMPARE_VALUE);

        #if (1u == PLCTimer_PWM_COMPARE_SWAP)
            PLCTimer_SetCompareSwap(1u);
            PLCTimer_WriteCompareBuf(PLCTimer_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == PLCTimer_PWM_COMPARE_SWAP) */

        #if (1u == PLCTimer_PWM_PERIOD_SWAP)
            PLCTimer_SetPeriodSwap(1u);
            PLCTimer_WritePeriodBuf(PLCTimer_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == PLCTimer_PWM_PERIOD_SWAP) */
    #endif  /* (PLCTimer__PWM_SEL == PLCTimer_CONFIG) */
    
}


/*******************************************************************************
* Function Name: PLCTimer_Enable
********************************************************************************
*
* Summary:
*  Enables the PLCTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    PLCTimer_BLOCK_CONTROL_REG |= PLCTimer_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (PLCTimer__PWM_SEL == PLCTimer_CONFIG)
        #if (0u == PLCTimer_PWM_START_SIGNAL_PRESENT)
            PLCTimer_TriggerCommand(PLCTimer_MASK, PLCTimer_CMD_START);
        #endif /* (0u == PLCTimer_PWM_START_SIGNAL_PRESENT) */
    #endif /* (PLCTimer__PWM_SEL == PLCTimer_CONFIG) */

    #if (PLCTimer__TIMER == PLCTimer_CONFIG)
        #if (0u == PLCTimer_TC_START_SIGNAL_PRESENT)
            PLCTimer_TriggerCommand(PLCTimer_MASK, PLCTimer_CMD_START);
        #endif /* (0u == PLCTimer_TC_START_SIGNAL_PRESENT) */
    #endif /* (PLCTimer__TIMER == PLCTimer_CONFIG) */
}


/*******************************************************************************
* Function Name: PLCTimer_Start
********************************************************************************
*
* Summary:
*  Initializes the PLCTimer with default customizer
*  values when called the first time and enables the PLCTimer.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PLCTimer_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time PLCTimer_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the PLCTimer_Start() routine.
*
*******************************************************************************/
void PLCTimer_Start(void)
{
    if (0u == PLCTimer_initVar)
    {
        PLCTimer_Init();
        PLCTimer_initVar = 1u;
    }

    PLCTimer_Enable();
}


/*******************************************************************************
* Function Name: PLCTimer_Stop
********************************************************************************
*
* Summary:
*  Disables the PLCTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_BLOCK_CONTROL_REG &= (uint32)~PLCTimer_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the PLCTimer. This function is used when
*  configured as a generic PLCTimer and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the PLCTimer to operate in
*   Values:
*   - PLCTimer_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - PLCTimer_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - PLCTimer_MODE_QUAD - Quadrature decoder
*         - PLCTimer_MODE_PWM - PWM
*         - PLCTimer_MODE_PWM_DT - PWM with dead time
*         - PLCTimer_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_MODE_MASK;
    PLCTimer_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - PLCTimer_MODE_X1 - Counts on phi 1 rising
*         - PLCTimer_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - PLCTimer_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_QUAD_MODE_MASK;
    PLCTimer_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - PLCTimer_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - PLCTimer_PRESCALE_DIVBY2    - Divide by 2
*         - PLCTimer_PRESCALE_DIVBY4    - Divide by 4
*         - PLCTimer_PRESCALE_DIVBY8    - Divide by 8
*         - PLCTimer_PRESCALE_DIVBY16   - Divide by 16
*         - PLCTimer_PRESCALE_DIVBY32   - Divide by 32
*         - PLCTimer_PRESCALE_DIVBY64   - Divide by 64
*         - PLCTimer_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_PRESCALER_MASK;
    PLCTimer_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PLCTimer runs
*  continuously or stops when terminal count is reached.  By default the
*  PLCTimer operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_ONESHOT_MASK;
    PLCTimer_CONTROL_REG |= ((uint32)((oneShotEnable & PLCTimer_1BIT_MASK) <<
                                                               PLCTimer_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetPWMMode(uint32 modeMask)
{
    PLCTimer_TRIG_CONTROL2_REG = (modeMask & PLCTimer_6BIT_MASK);
}



/*******************************************************************************
* Function Name: PLCTimer_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_PWM_SYNC_KILL_MASK;
    PLCTimer_CONTROL_REG |= ((uint32)((syncKillEnable & PLCTimer_1BIT_MASK)  <<
                                               PLCTimer_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_PWM_STOP_KILL_MASK;
    PLCTimer_CONTROL_REG |= ((uint32)((stopOnKillEnable & PLCTimer_1BIT_MASK)  <<
                                                         PLCTimer_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_PRESCALER_MASK;
    PLCTimer_CONTROL_REG |= ((uint32)((deadTime & PLCTimer_8BIT_MASK) <<
                                                          PLCTimer_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - PLCTimer_INVERT_LINE   - Inverts the line output
*         - PLCTimer_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_INV_OUT_MASK;
    PLCTimer_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: PLCTimer_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_WriteCounter(uint32 count)
{
    PLCTimer_COUNTER_REG = (count & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 PLCTimer_ReadCounter(void)
{
    return (PLCTimer_COUNTER_REG & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - PLCTimer_COUNT_UP       - Counts up
*     - PLCTimer_COUNT_DOWN     - Counts down
*     - PLCTimer_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - PLCTimer_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_UPDOWN_MASK;
    PLCTimer_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_WritePeriod(uint32 period)
{
    PLCTimer_PERIOD_REG = (period & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PLCTimer_ReadPeriod(void)
{
    return (PLCTimer_PERIOD_REG & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_RELOAD_CC_MASK;
    PLCTimer_CONTROL_REG |= (swapEnable & PLCTimer_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_WritePeriodBuf(uint32 periodBuf)
{
    PLCTimer_PERIOD_BUF_REG = (periodBuf & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PLCTimer_ReadPeriodBuf(void)
{
    return (PLCTimer_PERIOD_BUF_REG & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_CONTROL_REG &= (uint32)~PLCTimer_RELOAD_PERIOD_MASK;
    PLCTimer_CONTROL_REG |= ((uint32)((swapEnable & PLCTimer_1BIT_MASK) <<
                                                            PLCTimer_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_WriteCompare(uint32 compare)
{
    #if (PLCTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (PLCTimer_CY_TCPWM_4000) */

    #if (PLCTimer_CY_TCPWM_4000)
        currentMode = ((PLCTimer_CONTROL_REG & PLCTimer_UPDOWN_MASK) >> PLCTimer_UPDOWN_SHIFT);

        if (((uint32)PLCTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)PLCTimer__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (PLCTimer_CY_TCPWM_4000) */
    
    PLCTimer_COMP_CAP_REG = (compare & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 PLCTimer_ReadCompare(void)
{
    #if (PLCTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (PLCTimer_CY_TCPWM_4000) */

    #if (PLCTimer_CY_TCPWM_4000)
        currentMode = ((PLCTimer_CONTROL_REG & PLCTimer_UPDOWN_MASK) >> PLCTimer_UPDOWN_SHIFT);
        
        regVal = PLCTimer_COMP_CAP_REG;
        
        if (((uint32)PLCTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)PLCTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & PLCTimer_16BIT_MASK);
    #else
        return (PLCTimer_COMP_CAP_REG & PLCTimer_16BIT_MASK);
    #endif /* (PLCTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: PLCTimer_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_WriteCompareBuf(uint32 compareBuf)
{
    #if (PLCTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (PLCTimer_CY_TCPWM_4000) */

    #if (PLCTimer_CY_TCPWM_4000)
        currentMode = ((PLCTimer_CONTROL_REG & PLCTimer_UPDOWN_MASK) >> PLCTimer_UPDOWN_SHIFT);

        if (((uint32)PLCTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)PLCTimer__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (PLCTimer_CY_TCPWM_4000) */
    
    PLCTimer_COMP_CAP_BUF_REG = (compareBuf & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 PLCTimer_ReadCompareBuf(void)
{
    #if (PLCTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (PLCTimer_CY_TCPWM_4000) */

    #if (PLCTimer_CY_TCPWM_4000)
        currentMode = ((PLCTimer_CONTROL_REG & PLCTimer_UPDOWN_MASK) >> PLCTimer_UPDOWN_SHIFT);

        regVal = PLCTimer_COMP_CAP_BUF_REG;
        
        if (((uint32)PLCTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)PLCTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & PLCTimer_16BIT_MASK);
    #else
        return (PLCTimer_COMP_CAP_BUF_REG & PLCTimer_16BIT_MASK);
    #endif /* (PLCTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: PLCTimer_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 PLCTimer_ReadCapture(void)
{
    return (PLCTimer_COMP_CAP_REG & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 PLCTimer_ReadCaptureBuf(void)
{
    return (PLCTimer_COMP_CAP_BUF_REG & PLCTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PLCTimer_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PLCTimer_TRIG_LEVEL     - Level
*     - PLCTimer_TRIG_RISING    - Rising edge
*     - PLCTimer_TRIG_FALLING   - Falling edge
*     - PLCTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_TRIG_CONTROL1_REG &= (uint32)~PLCTimer_CAPTURE_MASK;
    PLCTimer_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PLCTimer_TRIG_LEVEL     - Level
*     - PLCTimer_TRIG_RISING    - Rising edge
*     - PLCTimer_TRIG_FALLING   - Falling edge
*     - PLCTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_TRIG_CONTROL1_REG &= (uint32)~PLCTimer_RELOAD_MASK;
    PLCTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PLCTimer_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PLCTimer_TRIG_LEVEL     - Level
*     - PLCTimer_TRIG_RISING    - Rising edge
*     - PLCTimer_TRIG_FALLING   - Falling edge
*     - PLCTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_TRIG_CONTROL1_REG &= (uint32)~PLCTimer_START_MASK;
    PLCTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PLCTimer_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PLCTimer_TRIG_LEVEL     - Level
*     - PLCTimer_TRIG_RISING    - Rising edge
*     - PLCTimer_TRIG_FALLING   - Falling edge
*     - PLCTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_TRIG_CONTROL1_REG &= (uint32)~PLCTimer_STOP_MASK;
    PLCTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PLCTimer_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PLCTimer_TRIG_LEVEL     - Level
*     - PLCTimer_TRIG_RISING    - Rising edge
*     - PLCTimer_TRIG_FALLING   - Falling edge
*     - PLCTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_TRIG_CONTROL1_REG &= (uint32)~PLCTimer_COUNT_MASK;
    PLCTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PLCTimer_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - PLCTimer_CMD_CAPTURE    - Trigger Capture command
*     - PLCTimer_CMD_RELOAD     - Trigger Reload command
*     - PLCTimer_CMD_STOP       - Trigger Stop command
*     - PLCTimer_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PLCTimer_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PLCTimer_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the PLCTimer.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - PLCTimer_STATUS_DOWN    - Set if counting down
*     - PLCTimer_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 PLCTimer_ReadStatus(void)
{
    return ((PLCTimer_STATUS_REG >> PLCTimer_RUNNING_STATUS_SHIFT) |
            (PLCTimer_STATUS_REG & PLCTimer_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: PLCTimer_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - PLCTimer_INTR_MASK_TC       - Terminal count mask
*     - PLCTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetInterruptMode(uint32 interruptMask)
{
    PLCTimer_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: PLCTimer_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - PLCTimer_INTR_MASK_TC       - Terminal count mask
*     - PLCTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PLCTimer_GetInterruptSourceMasked(void)
{
    return (PLCTimer_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: PLCTimer_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - PLCTimer_INTR_MASK_TC       - Terminal count mask
*     - PLCTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PLCTimer_GetInterruptSource(void)
{
    return (PLCTimer_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: PLCTimer_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - PLCTimer_INTR_MASK_TC       - Terminal count mask
*     - PLCTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_ClearInterrupt(uint32 interruptMask)
{
    PLCTimer_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: PLCTimer_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - PLCTimer_INTR_MASK_TC       - Terminal count mask
*     - PLCTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SetInterrupt(uint32 interruptMask)
{
    PLCTimer_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
