/*******************************************************************************
* File Name: PLC_UART1_BOOT.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the bootloader
*  communication interface of SCB component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_PLC_UART1_H)
#define CY_SCB_BOOT_PLC_UART1_H

#include "PLC_UART1_PVT.h"

#if (PLC_UART1_SCB_MODE_I2C_INC)
    #include "PLC_UART1_I2C.h"
#endif /* (PLC_UART1_SCB_MODE_I2C_INC) */

#if (PLC_UART1_SCB_MODE_EZI2C_INC)
    #include "PLC_UART1_EZI2C.h"
#endif /* (PLC_UART1_SCB_MODE_EZI2C_INC) */

#if (PLC_UART1_SCB_MODE_SPI_INC || PLC_UART1_SCB_MODE_UART_INC)
    #include "PLC_UART1_SPI_UART.h"
#endif /* (PLC_UART1_SCB_MODE_SPI_INC || PLC_UART1_SCB_MODE_UART_INC) */


/***************************************
*        Function Prototypes
***************************************/

/* Bootloader communication interface enable */
#define PLC_UART1_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PLC_UART1) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

#if (PLC_UART1_SCB_MODE_I2C_INC)

    #define PLC_UART1_I2C_BTLDR_COMM_ENABLED     (PLC_UART1_BTLDR_COMM_ENABLED && \
                                                            (PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             PLC_UART1_I2C_SLAVE_CONST))

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_I2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void PLC_UART1_I2CCyBtldrCommStart(void);
    void PLC_UART1_I2CCyBtldrCommStop (void);
    void PLC_UART1_I2CCyBtldrCommReset(void);
    cystatus PLC_UART1_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus PLC_UART1_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Size of Read/Write buffers for I2C bootloader  */
    #define PLC_UART1_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
    #define PLC_UART1_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)
    #define PLC_UART1_I2C_MIN_UINT16(a, b)           ( ((uint16)(a) < (uint16) (b)) ? \
                                                                    ((uint32) (a)) : ((uint32) (b)) )
    #define PLC_UART1_WAIT_1_MS                      (1u)
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_I2C_BTLDR_COMM_ENABLED) */

#endif /* (PLC_UART1_SCB_MODE_I2C_INC) */


#if (PLC_UART1_SCB_MODE_EZI2C_INC)

    /* Provide EMPTY bootloader communication functions. EZI2C is NOT supported yet */
    #define PLC_UART1_EZI2C_BTLDR_COMM_ENABLED   (PLC_UART1_BTLDR_COMM_ENABLED && \
                                                         PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void PLC_UART1_EzI2CCyBtldrCommStart(void);
    void PLC_UART1_EzI2CCyBtldrCommStop (void);
    void PLC_UART1_EzI2CCyBtldrCommReset(void);
    cystatus PLC_UART1_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus PLC_UART1_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_EZI2C_BTLDR_COMM_ENABLED) */

#endif /* (PLC_UART1_SCB_MODE_EZI2C_INC) */

#if (PLC_UART1_SCB_MODE_SPI_INC || PLC_UART1_SCB_MODE_UART_INC)
    /* Provide EMPTY bootloader communication functions. SPI and UART is NOT supported yet */
    #define PLC_UART1_SPI_BTLDR_COMM_ENABLED     (PLC_UART1_BTLDR_COMM_ENABLED && \
                                                        PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG)

    #define PLC_UART1_UART_BTLDR_COMM_ENABLED    (PLC_UART1_BTLDR_COMM_ENABLED && \
                                                        PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void PLC_UART1_SpiCyBtldrCommStart(void);
    void PLC_UART1_SpiCyBtldrCommStop (void);
    void PLC_UART1_SpiCyBtldrCommReset(void);
    cystatus PLC_UART1_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus PLC_UART1_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void PLC_UART1_UartCyBtldrCommStart(void);
    void PLC_UART1_UartCyBtldrCommStop (void);
    void PLC_UART1_UartCyBtldrCommReset(void);
    cystatus PLC_UART1_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus PLC_UART1_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_UART_BTLDR_COMM_ENABLED) */

#endif /* (PLC_UART1_SCB_MODE_SPI_INC || PLC_UART1_SCB_MODE_UART_INC) */

#if !defined (PLC_UART1_I2C_BTLDR_COMM_ENABLED)
    #define PLC_UART1_I2C_BTLDR_COMM_ENABLED     (0u)
#endif /* (PLC_UART1_I2C_BTLDR_COMM_ENABLED) */

#if !defined (PLC_UART1_EZI2C_BTLDR_COMM_ENABLED)
    #define PLC_UART1_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (PLC_UART1_EZI2C_BTLDR_COMM_ENABLED) */

#if !defined (PLC_UART1_SPI_BTLDR_COMM_ENABLED)
    #define PLC_UART1_SPI_BTLDR_COMM_ENABLED     (0u)
#endif /* (PLC_UART1_SPI_BTLDR_COMM_ENABLED) */

#if !defined (PLC_UART1_UART_BTLDR_COMM_ENABLED)
    #define PLC_UART1_UART_BTLDR_COMM_ENABLED    (0u)
#endif /* (PLC_UART1_UART_BTLDR_COMM_ENABLED) */

/* Bootloader enabled condition for each mode */
#define PLC_UART1_BTLDR_COMM_MODE_ENABLED    (PLC_UART1_I2C_BTLDR_COMM_ENABLED   || \
                                                     PLC_UART1_EZI2C_BTLDR_COMM_ENABLED || \
                                                     PLC_UART1_SPI_BTLDR_COMM_ENABLED   || \
                                                     PLC_UART1_UART_BTLDR_COMM_ENABLED)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_BTLDR_COMM_ENABLED)
    #if (PLC_UART1_BTLDR_COMM_MODE_ENABLED)
        /* Bootloader physical layer functions */
        void PLC_UART1_CyBtldrCommStart(void);
        void PLC_UART1_CyBtldrCommStop (void);
        void PLC_UART1_CyBtldrCommReset(void);
        cystatus PLC_UART1_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus PLC_UART1_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (PLC_UART1_BTLDR_COMM_MODE_ENABLED) */

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PLC_UART1)
        #define CyBtldrCommStart    PLC_UART1_CyBtldrCommStart
        #define CyBtldrCommStop     PLC_UART1_CyBtldrCommStop
        #define CyBtldrCommReset    PLC_UART1_CyBtldrCommReset
        #define CyBtldrCommWrite    PLC_UART1_CyBtldrCommWrite
        #define CyBtldrCommRead     PLC_UART1_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_PLC_UART1) */
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (PLC_UART1_BTLDR_COMM_ENABLED) */

#endif /* (CY_SCB_BOOT_PLC_UART1_H) */

/* [] END OF FILE */
