/*******************************************************************************
* File Name: .h
* Version 2.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_PLC_UART1_H)
#define CY_SCB_PVT_PLC_UART1_H

#include "PLC_UART1.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define PLC_UART1_SetI2CExtClkInterruptMode(interruptMask) PLC_UART1_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define PLC_UART1_ClearI2CExtClkInterruptSource(interruptMask) PLC_UART1_CLEAR_INTR_I2C_EC(interruptMask)
#define PLC_UART1_GetI2CExtClkInterruptSource()                (PLC_UART1_INTR_I2C_EC_REG)
#define PLC_UART1_GetI2CExtClkInterruptMode()                  (PLC_UART1_INTR_I2C_EC_MASK_REG)
#define PLC_UART1_GetI2CExtClkInterruptSourceMasked()          (PLC_UART1_INTR_I2C_EC_MASKED_REG)

#if (!PLC_UART1_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define PLC_UART1_SetSpiExtClkInterruptMode(interruptMask) \
                                                                PLC_UART1_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define PLC_UART1_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                PLC_UART1_CLEAR_INTR_SPI_EC(interruptMask)
    #define PLC_UART1_GetExtSpiClkInterruptSource()                 (PLC_UART1_INTR_SPI_EC_REG)
    #define PLC_UART1_GetExtSpiClkInterruptMode()                   (PLC_UART1_INTR_SPI_EC_MASK_REG)
    #define PLC_UART1_GetExtSpiClkInterruptSourceMasked()           (PLC_UART1_INTR_SPI_EC_MASKED_REG)
#endif /* (!PLC_UART1_CY_SCBIP_V1) */

#if(PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void PLC_UART1_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if !defined (CY_REMOVE_PLC_UART1_CUSTOM_INTR_HANDLER)
    extern cyisraddress PLC_UART1_customIntrHandler;
#endif /* !defined (CY_REMOVE_PLC_UART1_CUSTOM_INTR_HANDLER) */

extern PLC_UART1_BACKUP_STRUCT PLC_UART1_backup;

#if(PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 PLC_UART1_scbMode;
    extern uint8 PLC_UART1_scbEnableWake;
    extern uint8 PLC_UART1_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 PLC_UART1_mode;
    extern uint8 PLC_UART1_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * PLC_UART1_rxBuffer;
    extern uint8   PLC_UART1_rxDataBits;
    extern uint32  PLC_UART1_rxBufferSize;

    extern volatile uint8 * PLC_UART1_txBuffer;
    extern uint8   PLC_UART1_txDataBits;
    extern uint32  PLC_UART1_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 PLC_UART1_numberOfAddr;
    extern uint8 PLC_UART1_subAddrSize;
#endif /* (PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*        Conditional Macro
****************************************/

#if(PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define PLC_UART1_SCB_MODE_I2C_RUNTM_CFG     (PLC_UART1_SCB_MODE_I2C      == PLC_UART1_scbMode)
    #define PLC_UART1_SCB_MODE_SPI_RUNTM_CFG     (PLC_UART1_SCB_MODE_SPI      == PLC_UART1_scbMode)
    #define PLC_UART1_SCB_MODE_UART_RUNTM_CFG    (PLC_UART1_SCB_MODE_UART     == PLC_UART1_scbMode)
    #define PLC_UART1_SCB_MODE_EZI2C_RUNTM_CFG   (PLC_UART1_SCB_MODE_EZI2C    == PLC_UART1_scbMode)
    #define PLC_UART1_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (PLC_UART1_SCB_MODE_UNCONFIG == PLC_UART1_scbMode)

    /* Defines wakeup enable */
    #define PLC_UART1_SCB_WAKE_ENABLE_CHECK       (0u != PLC_UART1_scbEnableWake)
#endif /* (PLC_UART1_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!PLC_UART1_CY_SCBIP_V1)
    #define PLC_UART1_SCB_PINS_NUMBER    (7u)
#else
    #define PLC_UART1_SCB_PINS_NUMBER    (2u)
#endif /* (!PLC_UART1_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_PLC_UART1_H) */


/* [] END OF FILE */
