/*******************************************************************************
* File Name: PSOC_UART_IntClock.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_PSOC_UART_IntClock_H)
#define CY_CLOCK_PSOC_UART_IntClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void PSOC_UART_IntClock_StartEx(uint32 alignClkDiv);
#define PSOC_UART_IntClock_Start() \
    PSOC_UART_IntClock_StartEx(PSOC_UART_IntClock__PA_DIV_ID)

#else

void PSOC_UART_IntClock_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void PSOC_UART_IntClock_Stop(void);

void PSOC_UART_IntClock_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 PSOC_UART_IntClock_GetDividerRegister(void);
uint8  PSOC_UART_IntClock_GetFractionalDividerRegister(void);

#define PSOC_UART_IntClock_Enable()                         PSOC_UART_IntClock_Start()
#define PSOC_UART_IntClock_Disable()                        PSOC_UART_IntClock_Stop()
#define PSOC_UART_IntClock_SetDividerRegister(clkDivider, reset)  \
    PSOC_UART_IntClock_SetFractionalDividerRegister((clkDivider), 0u)
#define PSOC_UART_IntClock_SetDivider(clkDivider)           PSOC_UART_IntClock_SetDividerRegister((clkDivider), 1u)
#define PSOC_UART_IntClock_SetDividerValue(clkDivider)      PSOC_UART_IntClock_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define PSOC_UART_IntClock_DIV_ID     PSOC_UART_IntClock__DIV_ID

#define PSOC_UART_IntClock_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define PSOC_UART_IntClock_CTRL_REG   (*(reg32 *)PSOC_UART_IntClock__CTRL_REGISTER)
#define PSOC_UART_IntClock_DIV_REG    (*(reg32 *)PSOC_UART_IntClock__DIV_REGISTER)

#define PSOC_UART_IntClock_CMD_DIV_SHIFT          (0u)
#define PSOC_UART_IntClock_CMD_PA_DIV_SHIFT       (8u)
#define PSOC_UART_IntClock_CMD_DISABLE_SHIFT      (30u)
#define PSOC_UART_IntClock_CMD_ENABLE_SHIFT       (31u)

#define PSOC_UART_IntClock_CMD_DISABLE_MASK       ((uint32)((uint32)1u << PSOC_UART_IntClock_CMD_DISABLE_SHIFT))
#define PSOC_UART_IntClock_CMD_ENABLE_MASK        ((uint32)((uint32)1u << PSOC_UART_IntClock_CMD_ENABLE_SHIFT))

#define PSOC_UART_IntClock_DIV_FRAC_MASK  (0x000000F8u)
#define PSOC_UART_IntClock_DIV_FRAC_SHIFT (3u)
#define PSOC_UART_IntClock_DIV_INT_MASK   (0xFFFFFF00u)
#define PSOC_UART_IntClock_DIV_INT_SHIFT  (8u)

#else 

#define PSOC_UART_IntClock_DIV_REG        (*(reg32 *)PSOC_UART_IntClock__REGISTER)
#define PSOC_UART_IntClock_ENABLE_REG     PSOC_UART_IntClock_DIV_REG
#define PSOC_UART_IntClock_DIV_FRAC_MASK  PSOC_UART_IntClock__FRAC_MASK
#define PSOC_UART_IntClock_DIV_FRAC_SHIFT (16u)
#define PSOC_UART_IntClock_DIV_INT_MASK   PSOC_UART_IntClock__DIVIDER_MASK
#define PSOC_UART_IntClock_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_PSOC_UART_IntClock_H) */

/* [] END OF FILE */
