/*******************************************************************************
* File Name: SetIntel.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SetIntel.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        SetIntel_PC =   (SetIntel_PC & \
                                (uint32)(~(uint32)(SetIntel_DRIVE_MODE_IND_MASK << (SetIntel_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (SetIntel_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: SetIntel_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void SetIntel_Write(uint8 value) 
{
    uint8 drVal = (uint8)(SetIntel_DR & (uint8)(~SetIntel_MASK));
    drVal = (drVal | ((uint8)(value << SetIntel_SHIFT) & SetIntel_MASK));
    SetIntel_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: SetIntel_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  SetIntel_DM_STRONG     Strong Drive 
*  SetIntel_DM_OD_HI      Open Drain, Drives High 
*  SetIntel_DM_OD_LO      Open Drain, Drives Low 
*  SetIntel_DM_RES_UP     Resistive Pull Up 
*  SetIntel_DM_RES_DWN    Resistive Pull Down 
*  SetIntel_DM_RES_UPDWN  Resistive Pull Up/Down 
*  SetIntel_DM_DIG_HIZ    High Impedance Digital 
*  SetIntel_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void SetIntel_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(SetIntel__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: SetIntel_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SetIntel_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SetIntel_Read(void) 
{
    return (uint8)((SetIntel_PS & SetIntel_MASK) >> SetIntel_SHIFT);
}


/*******************************************************************************
* Function Name: SetIntel_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SetIntel_ReadDataReg(void) 
{
    return (uint8)((SetIntel_DR & SetIntel_MASK) >> SetIntel_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SetIntel_INTSTAT) 

    /*******************************************************************************
    * Function Name: SetIntel_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SetIntel_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(SetIntel_INTSTAT & SetIntel_MASK);
		SetIntel_INTSTAT = maskedStatus;
        return maskedStatus >> SetIntel_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
