/*******************************************************************************
* File Name: StopIrr.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "StopIrr.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        StopIrr_PC =   (StopIrr_PC & \
                                (uint32)(~(uint32)(StopIrr_DRIVE_MODE_IND_MASK << (StopIrr_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (StopIrr_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: StopIrr_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void StopIrr_Write(uint8 value) 
{
    uint8 drVal = (uint8)(StopIrr_DR & (uint8)(~StopIrr_MASK));
    drVal = (drVal | ((uint8)(value << StopIrr_SHIFT) & StopIrr_MASK));
    StopIrr_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: StopIrr_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  StopIrr_DM_STRONG     Strong Drive 
*  StopIrr_DM_OD_HI      Open Drain, Drives High 
*  StopIrr_DM_OD_LO      Open Drain, Drives Low 
*  StopIrr_DM_RES_UP     Resistive Pull Up 
*  StopIrr_DM_RES_DWN    Resistive Pull Down 
*  StopIrr_DM_RES_UPDWN  Resistive Pull Up/Down 
*  StopIrr_DM_DIG_HIZ    High Impedance Digital 
*  StopIrr_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void StopIrr_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(StopIrr__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: StopIrr_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro StopIrr_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 StopIrr_Read(void) 
{
    return (uint8)((StopIrr_PS & StopIrr_MASK) >> StopIrr_SHIFT);
}


/*******************************************************************************
* Function Name: StopIrr_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 StopIrr_ReadDataReg(void) 
{
    return (uint8)((StopIrr_DR & StopIrr_MASK) >> StopIrr_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(StopIrr_INTSTAT) 

    /*******************************************************************************
    * Function Name: StopIrr_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 StopIrr_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(StopIrr_INTSTAT & StopIrr_MASK);
		StopIrr_INTSTAT = maskedStatus;
        return maskedStatus >> StopIrr_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
