/*******************************************************************************
* File Name: PLCPullTimer.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the PLCPullTimer
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_PLCPullTimer_H)
#define CY_TCPWM_PLCPullTimer_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} PLCPullTimer_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  PLCPullTimer_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define PLCPullTimer_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define PLCPullTimer_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define PLCPullTimer_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define PLCPullTimer_QUAD_ENCODING_MODES            (0lu)

/* Signal modes */
#define PLCPullTimer_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define PLCPullTimer_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define PLCPullTimer_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define PLCPullTimer_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define PLCPullTimer_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define PLCPullTimer_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define PLCPullTimer_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define PLCPullTimer_TC_RUN_MODE                    (1lu)
#define PLCPullTimer_TC_COUNTER_MODE                (1lu)
#define PLCPullTimer_TC_COMP_CAP_MODE               (2lu)
#define PLCPullTimer_TC_PRESCALER                   (7lu)

/* Signal modes */
#define PLCPullTimer_TC_RELOAD_SIGNAL_MODE          (0lu)
#define PLCPullTimer_TC_COUNT_SIGNAL_MODE           (3lu)
#define PLCPullTimer_TC_START_SIGNAL_MODE           (0lu)
#define PLCPullTimer_TC_STOP_SIGNAL_MODE            (0lu)
#define PLCPullTimer_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define PLCPullTimer_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define PLCPullTimer_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define PLCPullTimer_TC_START_SIGNAL_PRESENT        (0lu)
#define PLCPullTimer_TC_STOP_SIGNAL_PRESENT         (0lu)
#define PLCPullTimer_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PLCPullTimer_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define PLCPullTimer_PWM_KILL_EVENT                 (0lu)
#define PLCPullTimer_PWM_STOP_EVENT                 (0lu)
#define PLCPullTimer_PWM_MODE                       (4lu)
#define PLCPullTimer_PWM_OUT_N_INVERT               (0lu)
#define PLCPullTimer_PWM_OUT_INVERT                 (0lu)
#define PLCPullTimer_PWM_ALIGN                      (0lu)
#define PLCPullTimer_PWM_RUN_MODE                   (0lu)
#define PLCPullTimer_PWM_DEAD_TIME_CYCLE            (0lu)
#define PLCPullTimer_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define PLCPullTimer_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define PLCPullTimer_PWM_COUNT_SIGNAL_MODE          (3lu)
#define PLCPullTimer_PWM_START_SIGNAL_MODE          (0lu)
#define PLCPullTimer_PWM_STOP_SIGNAL_MODE           (0lu)
#define PLCPullTimer_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define PLCPullTimer_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define PLCPullTimer_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define PLCPullTimer_PWM_START_SIGNAL_PRESENT       (0lu)
#define PLCPullTimer_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define PLCPullTimer_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PLCPullTimer_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define PLCPullTimer_TC_PERIOD_VALUE                (65535lu)
#define PLCPullTimer_TC_COMPARE_VALUE               (65535lu)
#define PLCPullTimer_TC_COMPARE_BUF_VALUE           (65535lu)
#define PLCPullTimer_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define PLCPullTimer_PWM_PERIOD_VALUE               (65535lu)
#define PLCPullTimer_PWM_PERIOD_BUF_VALUE           (65535lu)
#define PLCPullTimer_PWM_PERIOD_SWAP                (0lu)
#define PLCPullTimer_PWM_COMPARE_VALUE              (65535lu)
#define PLCPullTimer_PWM_COMPARE_BUF_VALUE          (65535lu)
#define PLCPullTimer_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define PLCPullTimer__LEFT 0
#define PLCPullTimer__RIGHT 1
#define PLCPullTimer__CENTER 2
#define PLCPullTimer__ASYMMETRIC 3

#define PLCPullTimer__X1 0
#define PLCPullTimer__X2 1
#define PLCPullTimer__X4 2

#define PLCPullTimer__PWM 4
#define PLCPullTimer__PWM_DT 5
#define PLCPullTimer__PWM_PR 6

#define PLCPullTimer__INVERSE 1
#define PLCPullTimer__DIRECT 0

#define PLCPullTimer__CAPTURE 2
#define PLCPullTimer__COMPARE 0

#define PLCPullTimer__TRIG_LEVEL 3
#define PLCPullTimer__TRIG_RISING 0
#define PLCPullTimer__TRIG_FALLING 1
#define PLCPullTimer__TRIG_BOTH 2

#define PLCPullTimer__INTR_MASK_TC 1
#define PLCPullTimer__INTR_MASK_CC_MATCH 2
#define PLCPullTimer__INTR_MASK_NONE 0
#define PLCPullTimer__INTR_MASK_TC_CC 3

#define PLCPullTimer__UNCONFIG 8
#define PLCPullTimer__TIMER 1
#define PLCPullTimer__QUAD 3
#define PLCPullTimer__PWM_SEL 7

#define PLCPullTimer__COUNT_UP 0
#define PLCPullTimer__COUNT_DOWN 1
#define PLCPullTimer__COUNT_UPDOWN0 2
#define PLCPullTimer__COUNT_UPDOWN1 3


/* Prescaler */
#define PLCPullTimer_PRESCALE_DIVBY1                ((uint32)(0u << PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_PRESCALE_DIVBY2                ((uint32)(1u << PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_PRESCALE_DIVBY4                ((uint32)(2u << PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_PRESCALE_DIVBY8                ((uint32)(3u << PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_PRESCALE_DIVBY16               ((uint32)(4u << PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_PRESCALE_DIVBY32               ((uint32)(5u << PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_PRESCALE_DIVBY64               ((uint32)(6u << PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_PRESCALE_DIVBY128              ((uint32)(7u << PLCPullTimer_PRESCALER_SHIFT))

/* TCPWM set modes */
#define PLCPullTimer_MODE_TIMER_COMPARE             ((uint32)(PLCPullTimer__COMPARE         <<  \
                                                                  PLCPullTimer_MODE_SHIFT))
#define PLCPullTimer_MODE_TIMER_CAPTURE             ((uint32)(PLCPullTimer__CAPTURE         <<  \
                                                                  PLCPullTimer_MODE_SHIFT))
#define PLCPullTimer_MODE_QUAD                      ((uint32)(PLCPullTimer__QUAD            <<  \
                                                                  PLCPullTimer_MODE_SHIFT))
#define PLCPullTimer_MODE_PWM                       ((uint32)(PLCPullTimer__PWM             <<  \
                                                                  PLCPullTimer_MODE_SHIFT))
#define PLCPullTimer_MODE_PWM_DT                    ((uint32)(PLCPullTimer__PWM_DT          <<  \
                                                                  PLCPullTimer_MODE_SHIFT))
#define PLCPullTimer_MODE_PWM_PR                    ((uint32)(PLCPullTimer__PWM_PR          <<  \
                                                                  PLCPullTimer_MODE_SHIFT))

/* Quad Modes */
#define PLCPullTimer_MODE_X1                        ((uint32)(PLCPullTimer__X1              <<  \
                                                                  PLCPullTimer_QUAD_MODE_SHIFT))
#define PLCPullTimer_MODE_X2                        ((uint32)(PLCPullTimer__X2              <<  \
                                                                  PLCPullTimer_QUAD_MODE_SHIFT))
#define PLCPullTimer_MODE_X4                        ((uint32)(PLCPullTimer__X4              <<  \
                                                                  PLCPullTimer_QUAD_MODE_SHIFT))

/* Counter modes */
#define PLCPullTimer_COUNT_UP                       ((uint32)(PLCPullTimer__COUNT_UP        <<  \
                                                                  PLCPullTimer_UPDOWN_SHIFT))
#define PLCPullTimer_COUNT_DOWN                     ((uint32)(PLCPullTimer__COUNT_DOWN      <<  \
                                                                  PLCPullTimer_UPDOWN_SHIFT))
#define PLCPullTimer_COUNT_UPDOWN0                  ((uint32)(PLCPullTimer__COUNT_UPDOWN0   <<  \
                                                                  PLCPullTimer_UPDOWN_SHIFT))
#define PLCPullTimer_COUNT_UPDOWN1                  ((uint32)(PLCPullTimer__COUNT_UPDOWN1   <<  \
                                                                  PLCPullTimer_UPDOWN_SHIFT))

/* PWM output invert */
#define PLCPullTimer_INVERT_LINE                    ((uint32)(PLCPullTimer__INVERSE         <<  \
                                                                  PLCPullTimer_INV_OUT_SHIFT))
#define PLCPullTimer_INVERT_LINE_N                  ((uint32)(PLCPullTimer__INVERSE         <<  \
                                                                  PLCPullTimer_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define PLCPullTimer_TRIG_RISING                    ((uint32)PLCPullTimer__TRIG_RISING)
#define PLCPullTimer_TRIG_FALLING                   ((uint32)PLCPullTimer__TRIG_FALLING)
#define PLCPullTimer_TRIG_BOTH                      ((uint32)PLCPullTimer__TRIG_BOTH)
#define PLCPullTimer_TRIG_LEVEL                     ((uint32)PLCPullTimer__TRIG_LEVEL)

/* Interrupt mask */
#define PLCPullTimer_INTR_MASK_TC                   ((uint32)PLCPullTimer__INTR_MASK_TC)
#define PLCPullTimer_INTR_MASK_CC_MATCH             ((uint32)PLCPullTimer__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define PLCPullTimer_CC_MATCH_SET                   (0x00u)
#define PLCPullTimer_CC_MATCH_CLEAR                 (0x01u)
#define PLCPullTimer_CC_MATCH_INVERT                (0x02u)
#define PLCPullTimer_CC_MATCH_NO_CHANGE             (0x03u)
#define PLCPullTimer_OVERLOW_SET                    (0x00u)
#define PLCPullTimer_OVERLOW_CLEAR                  (0x04u)
#define PLCPullTimer_OVERLOW_INVERT                 (0x08u)
#define PLCPullTimer_OVERLOW_NO_CHANGE              (0x0Cu)
#define PLCPullTimer_UNDERFLOW_SET                  (0x00u)
#define PLCPullTimer_UNDERFLOW_CLEAR                (0x10u)
#define PLCPullTimer_UNDERFLOW_INVERT               (0x20u)
#define PLCPullTimer_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define PLCPullTimer_PWM_MODE_LEFT                  (PLCPullTimer_CC_MATCH_CLEAR        |   \
                                                         PLCPullTimer_OVERLOW_SET           |   \
                                                         PLCPullTimer_UNDERFLOW_NO_CHANGE)
#define PLCPullTimer_PWM_MODE_RIGHT                 (PLCPullTimer_CC_MATCH_SET          |   \
                                                         PLCPullTimer_OVERLOW_NO_CHANGE     |   \
                                                         PLCPullTimer_UNDERFLOW_CLEAR)
#define PLCPullTimer_PWM_MODE_ASYM                  (PLCPullTimer_CC_MATCH_INVERT       |   \
                                                         PLCPullTimer_OVERLOW_SET           |   \
                                                         PLCPullTimer_UNDERFLOW_CLEAR)

#if (PLCPullTimer_CY_TCPWM_V2)
    #if(PLCPullTimer_CY_TCPWM_4000)
        #define PLCPullTimer_PWM_MODE_CENTER                (PLCPullTimer_CC_MATCH_INVERT       |   \
                                                                 PLCPullTimer_OVERLOW_NO_CHANGE     |   \
                                                                 PLCPullTimer_UNDERFLOW_CLEAR)
    #else
        #define PLCPullTimer_PWM_MODE_CENTER                (PLCPullTimer_CC_MATCH_INVERT       |   \
                                                                 PLCPullTimer_OVERLOW_SET           |   \
                                                                 PLCPullTimer_UNDERFLOW_CLEAR)
    #endif /* (PLCPullTimer_CY_TCPWM_4000) */
#else
    #define PLCPullTimer_PWM_MODE_CENTER                (PLCPullTimer_CC_MATCH_INVERT       |   \
                                                             PLCPullTimer_OVERLOW_NO_CHANGE     |   \
                                                             PLCPullTimer_UNDERFLOW_CLEAR)
#endif /* (PLCPullTimer_CY_TCPWM_NEW) */

/* Command operations without condition */
#define PLCPullTimer_CMD_CAPTURE                    (0u)
#define PLCPullTimer_CMD_RELOAD                     (8u)
#define PLCPullTimer_CMD_STOP                       (16u)
#define PLCPullTimer_CMD_START                      (24u)

/* Status */
#define PLCPullTimer_STATUS_DOWN                    (1u)
#define PLCPullTimer_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   PLCPullTimer_Init(void);
void   PLCPullTimer_Enable(void);
void   PLCPullTimer_Start(void);
void   PLCPullTimer_Stop(void);

void   PLCPullTimer_SetMode(uint32 mode);
void   PLCPullTimer_SetCounterMode(uint32 counterMode);
void   PLCPullTimer_SetPWMMode(uint32 modeMask);
void   PLCPullTimer_SetQDMode(uint32 qdMode);

void   PLCPullTimer_SetPrescaler(uint32 prescaler);
void   PLCPullTimer_TriggerCommand(uint32 mask, uint32 command);
void   PLCPullTimer_SetOneShot(uint32 oneShotEnable);
uint32 PLCPullTimer_ReadStatus(void);

void   PLCPullTimer_SetPWMSyncKill(uint32 syncKillEnable);
void   PLCPullTimer_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   PLCPullTimer_SetPWMDeadTime(uint32 deadTime);
void   PLCPullTimer_SetPWMInvert(uint32 mask);

void   PLCPullTimer_SetInterruptMode(uint32 interruptMask);
uint32 PLCPullTimer_GetInterruptSourceMasked(void);
uint32 PLCPullTimer_GetInterruptSource(void);
void   PLCPullTimer_ClearInterrupt(uint32 interruptMask);
void   PLCPullTimer_SetInterrupt(uint32 interruptMask);

void   PLCPullTimer_WriteCounter(uint32 count);
uint32 PLCPullTimer_ReadCounter(void);

uint32 PLCPullTimer_ReadCapture(void);
uint32 PLCPullTimer_ReadCaptureBuf(void);

void   PLCPullTimer_WritePeriod(uint32 period);
uint32 PLCPullTimer_ReadPeriod(void);
void   PLCPullTimer_WritePeriodBuf(uint32 periodBuf);
uint32 PLCPullTimer_ReadPeriodBuf(void);

void   PLCPullTimer_WriteCompare(uint32 compare);
uint32 PLCPullTimer_ReadCompare(void);
void   PLCPullTimer_WriteCompareBuf(uint32 compareBuf);
uint32 PLCPullTimer_ReadCompareBuf(void);

void   PLCPullTimer_SetPeriodSwap(uint32 swapEnable);
void   PLCPullTimer_SetCompareSwap(uint32 swapEnable);

void   PLCPullTimer_SetCaptureMode(uint32 triggerMode);
void   PLCPullTimer_SetReloadMode(uint32 triggerMode);
void   PLCPullTimer_SetStartMode(uint32 triggerMode);
void   PLCPullTimer_SetStopMode(uint32 triggerMode);
void   PLCPullTimer_SetCountMode(uint32 triggerMode);

void   PLCPullTimer_SaveConfig(void);
void   PLCPullTimer_RestoreConfig(void);
void   PLCPullTimer_Sleep(void);
void   PLCPullTimer_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define PLCPullTimer_BLOCK_CONTROL_REG              (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PLCPullTimer_BLOCK_CONTROL_PTR              ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PLCPullTimer_COMMAND_REG                    (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PLCPullTimer_COMMAND_PTR                    ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PLCPullTimer_INTRRUPT_CAUSE_REG             (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PLCPullTimer_INTRRUPT_CAUSE_PTR             ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PLCPullTimer_CONTROL_REG                    (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__CTRL )
#define PLCPullTimer_CONTROL_PTR                    ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__CTRL )
#define PLCPullTimer_STATUS_REG                     (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__STATUS )
#define PLCPullTimer_STATUS_PTR                     ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__STATUS )
#define PLCPullTimer_COUNTER_REG                    (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__COUNTER )
#define PLCPullTimer_COUNTER_PTR                    ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__COUNTER )
#define PLCPullTimer_COMP_CAP_REG                   (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__CC )
#define PLCPullTimer_COMP_CAP_PTR                   ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__CC )
#define PLCPullTimer_COMP_CAP_BUF_REG               (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define PLCPullTimer_COMP_CAP_BUF_PTR               ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define PLCPullTimer_PERIOD_REG                     (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__PERIOD )
#define PLCPullTimer_PERIOD_PTR                     ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__PERIOD )
#define PLCPullTimer_PERIOD_BUF_REG                 (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PLCPullTimer_PERIOD_BUF_PTR                 ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PLCPullTimer_TRIG_CONTROL0_REG              (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PLCPullTimer_TRIG_CONTROL0_PTR              ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PLCPullTimer_TRIG_CONTROL1_REG              (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PLCPullTimer_TRIG_CONTROL1_PTR              ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PLCPullTimer_TRIG_CONTROL2_REG              (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PLCPullTimer_TRIG_CONTROL2_PTR              ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PLCPullTimer_INTERRUPT_REQ_REG              (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR )
#define PLCPullTimer_INTERRUPT_REQ_PTR              ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR )
#define PLCPullTimer_INTERRUPT_SET_REG              (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define PLCPullTimer_INTERRUPT_SET_PTR              ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define PLCPullTimer_INTERRUPT_MASK_REG             (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define PLCPullTimer_INTERRUPT_MASK_PTR             ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define PLCPullTimer_INTERRUPT_MASKED_REG           (*(reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR_MASKED )
#define PLCPullTimer_INTERRUPT_MASKED_PTR           ( (reg32 *) PLCPullTimer_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define PLCPullTimer_MASK                           ((uint32)PLCPullTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define PLCPullTimer_RELOAD_CC_SHIFT                (0u)
#define PLCPullTimer_RELOAD_PERIOD_SHIFT            (1u)
#define PLCPullTimer_PWM_SYNC_KILL_SHIFT            (2u)
#define PLCPullTimer_PWM_STOP_KILL_SHIFT            (3u)
#define PLCPullTimer_PRESCALER_SHIFT                (8u)
#define PLCPullTimer_UPDOWN_SHIFT                   (16u)
#define PLCPullTimer_ONESHOT_SHIFT                  (18u)
#define PLCPullTimer_QUAD_MODE_SHIFT                (20u)
#define PLCPullTimer_INV_OUT_SHIFT                  (20u)
#define PLCPullTimer_INV_COMPL_OUT_SHIFT            (21u)
#define PLCPullTimer_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define PLCPullTimer_RELOAD_CC_MASK                 ((uint32)(PLCPullTimer_1BIT_MASK        <<  \
                                                                            PLCPullTimer_RELOAD_CC_SHIFT))
#define PLCPullTimer_RELOAD_PERIOD_MASK             ((uint32)(PLCPullTimer_1BIT_MASK        <<  \
                                                                            PLCPullTimer_RELOAD_PERIOD_SHIFT))
#define PLCPullTimer_PWM_SYNC_KILL_MASK             ((uint32)(PLCPullTimer_1BIT_MASK        <<  \
                                                                            PLCPullTimer_PWM_SYNC_KILL_SHIFT))
#define PLCPullTimer_PWM_STOP_KILL_MASK             ((uint32)(PLCPullTimer_1BIT_MASK        <<  \
                                                                            PLCPullTimer_PWM_STOP_KILL_SHIFT))
#define PLCPullTimer_PRESCALER_MASK                 ((uint32)(PLCPullTimer_8BIT_MASK        <<  \
                                                                            PLCPullTimer_PRESCALER_SHIFT))
#define PLCPullTimer_UPDOWN_MASK                    ((uint32)(PLCPullTimer_2BIT_MASK        <<  \
                                                                            PLCPullTimer_UPDOWN_SHIFT))
#define PLCPullTimer_ONESHOT_MASK                   ((uint32)(PLCPullTimer_1BIT_MASK        <<  \
                                                                            PLCPullTimer_ONESHOT_SHIFT))
#define PLCPullTimer_QUAD_MODE_MASK                 ((uint32)(PLCPullTimer_3BIT_MASK        <<  \
                                                                            PLCPullTimer_QUAD_MODE_SHIFT))
#define PLCPullTimer_INV_OUT_MASK                   ((uint32)(PLCPullTimer_2BIT_MASK        <<  \
                                                                            PLCPullTimer_INV_OUT_SHIFT))
#define PLCPullTimer_MODE_MASK                      ((uint32)(PLCPullTimer_3BIT_MASK        <<  \
                                                                            PLCPullTimer_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define PLCPullTimer_CAPTURE_SHIFT                  (0u)
#define PLCPullTimer_COUNT_SHIFT                    (2u)
#define PLCPullTimer_RELOAD_SHIFT                   (4u)
#define PLCPullTimer_STOP_SHIFT                     (6u)
#define PLCPullTimer_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define PLCPullTimer_CAPTURE_MASK                   ((uint32)(PLCPullTimer_2BIT_MASK        <<  \
                                                                  PLCPullTimer_CAPTURE_SHIFT))
#define PLCPullTimer_COUNT_MASK                     ((uint32)(PLCPullTimer_2BIT_MASK        <<  \
                                                                  PLCPullTimer_COUNT_SHIFT))
#define PLCPullTimer_RELOAD_MASK                    ((uint32)(PLCPullTimer_2BIT_MASK        <<  \
                                                                  PLCPullTimer_RELOAD_SHIFT))
#define PLCPullTimer_STOP_MASK                      ((uint32)(PLCPullTimer_2BIT_MASK        <<  \
                                                                  PLCPullTimer_STOP_SHIFT))
#define PLCPullTimer_START_MASK                     ((uint32)(PLCPullTimer_2BIT_MASK        <<  \
                                                                  PLCPullTimer_START_SHIFT))

/* MASK */
#define PLCPullTimer_1BIT_MASK                      ((uint32)0x01u)
#define PLCPullTimer_2BIT_MASK                      ((uint32)0x03u)
#define PLCPullTimer_3BIT_MASK                      ((uint32)0x07u)
#define PLCPullTimer_6BIT_MASK                      ((uint32)0x3Fu)
#define PLCPullTimer_8BIT_MASK                      ((uint32)0xFFu)
#define PLCPullTimer_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define PLCPullTimer_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define PLCPullTimer_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(PLCPullTimer_QUAD_ENCODING_MODES     << PLCPullTimer_QUAD_MODE_SHIFT))       |\
         ((uint32)(PLCPullTimer_CONFIG                  << PLCPullTimer_MODE_SHIFT)))

#define PLCPullTimer_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(PLCPullTimer_PWM_STOP_EVENT          << PLCPullTimer_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(PLCPullTimer_PWM_OUT_INVERT          << PLCPullTimer_INV_OUT_SHIFT))         |\
         ((uint32)(PLCPullTimer_PWM_OUT_N_INVERT        << PLCPullTimer_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(PLCPullTimer_PWM_MODE                << PLCPullTimer_MODE_SHIFT)))

#define PLCPullTimer_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(PLCPullTimer_PWM_RUN_MODE         << PLCPullTimer_ONESHOT_SHIFT))
            
#define PLCPullTimer_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(PLCPullTimer_PWM_ALIGN            << PLCPullTimer_UPDOWN_SHIFT))

#define PLCPullTimer_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(PLCPullTimer_PWM_KILL_EVENT      << PLCPullTimer_PWM_SYNC_KILL_SHIFT))

#define PLCPullTimer_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(PLCPullTimer_PWM_DEAD_TIME_CYCLE  << PLCPullTimer_PRESCALER_SHIFT))

#define PLCPullTimer_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(PLCPullTimer_PWM_PRESCALER        << PLCPullTimer_PRESCALER_SHIFT))

#define PLCPullTimer_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(PLCPullTimer_TC_PRESCALER            << PLCPullTimer_PRESCALER_SHIFT))       |\
         ((uint32)(PLCPullTimer_TC_COUNTER_MODE         << PLCPullTimer_UPDOWN_SHIFT))          |\
         ((uint32)(PLCPullTimer_TC_RUN_MODE             << PLCPullTimer_ONESHOT_SHIFT))         |\
         ((uint32)(PLCPullTimer_TC_COMP_CAP_MODE        << PLCPullTimer_MODE_SHIFT)))
        
#define PLCPullTimer_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(PLCPullTimer_QUAD_PHIA_SIGNAL_MODE   << PLCPullTimer_COUNT_SHIFT))           |\
         ((uint32)(PLCPullTimer_QUAD_INDEX_SIGNAL_MODE  << PLCPullTimer_RELOAD_SHIFT))          |\
         ((uint32)(PLCPullTimer_QUAD_STOP_SIGNAL_MODE   << PLCPullTimer_STOP_SHIFT))            |\
         ((uint32)(PLCPullTimer_QUAD_PHIB_SIGNAL_MODE   << PLCPullTimer_START_SHIFT)))

#define PLCPullTimer_PWM_SIGNALS_MODES                                                              \
        (((uint32)(PLCPullTimer_PWM_SWITCH_SIGNAL_MODE  << PLCPullTimer_CAPTURE_SHIFT))         |\
         ((uint32)(PLCPullTimer_PWM_COUNT_SIGNAL_MODE   << PLCPullTimer_COUNT_SHIFT))           |\
         ((uint32)(PLCPullTimer_PWM_RELOAD_SIGNAL_MODE  << PLCPullTimer_RELOAD_SHIFT))          |\
         ((uint32)(PLCPullTimer_PWM_STOP_SIGNAL_MODE    << PLCPullTimer_STOP_SHIFT))            |\
         ((uint32)(PLCPullTimer_PWM_START_SIGNAL_MODE   << PLCPullTimer_START_SHIFT)))

#define PLCPullTimer_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(PLCPullTimer_TC_CAPTURE_SIGNAL_MODE  << PLCPullTimer_CAPTURE_SHIFT))         |\
         ((uint32)(PLCPullTimer_TC_COUNT_SIGNAL_MODE    << PLCPullTimer_COUNT_SHIFT))           |\
         ((uint32)(PLCPullTimer_TC_RELOAD_SIGNAL_MODE   << PLCPullTimer_RELOAD_SHIFT))          |\
         ((uint32)(PLCPullTimer_TC_STOP_SIGNAL_MODE     << PLCPullTimer_STOP_SHIFT))            |\
         ((uint32)(PLCPullTimer_TC_START_SIGNAL_MODE    << PLCPullTimer_START_SHIFT)))
        
#define PLCPullTimer_TIMER_UPDOWN_CNT_USED                                                          \
                ((PLCPullTimer__COUNT_UPDOWN0 == PLCPullTimer_TC_COUNTER_MODE)                  ||\
                 (PLCPullTimer__COUNT_UPDOWN1 == PLCPullTimer_TC_COUNTER_MODE))

#define PLCPullTimer_PWM_UPDOWN_CNT_USED                                                            \
                ((PLCPullTimer__CENTER == PLCPullTimer_PWM_ALIGN)                               ||\
                 (PLCPullTimer__ASYMMETRIC == PLCPullTimer_PWM_ALIGN))               
        
#define PLCPullTimer_PWM_PR_INIT_VALUE              (1u)
#define PLCPullTimer_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_PLCPullTimer_H */

/* [] END OF FILE */
