/*******************************************************************************
* File Name: PLCPullTimer_PM.c
* Version 2.0
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PLCPullTimer.h"

static PLCPullTimer_BACKUP_STRUCT PLCPullTimer_backup;


/*******************************************************************************
* Function Name: PLCPullTimer_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCPullTimer_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: PLCPullTimer_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCPullTimer_Sleep(void)
{
    if(0u != (PLCPullTimer_BLOCK_CONTROL_REG & PLCPullTimer_MASK))
    {
        PLCPullTimer_backup.enableState = 1u;
    }
    else
    {
        PLCPullTimer_backup.enableState = 0u;
    }

    PLCPullTimer_Stop();
    PLCPullTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: PLCPullTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCPullTimer_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: PLCPullTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCPullTimer_Wakeup(void)
{
    PLCPullTimer_RestoreConfig();

    if(0u != PLCPullTimer_backup.enableState)
    {
        PLCPullTimer_Enable();
    }
}


/* [] END OF FILE */
