/*******************************************************************************
* File Name: PLCTimer_PM.c
* Version 2.0
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PLCTimer.h"

static PLCTimer_BACKUP_STRUCT PLCTimer_backup;


/*******************************************************************************
* Function Name: PLCTimer_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: PLCTimer_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_Sleep(void)
{
    if(0u != (PLCTimer_BLOCK_CONTROL_REG & PLCTimer_MASK))
    {
        PLCTimer_backup.enableState = 1u;
    }
    else
    {
        PLCTimer_backup.enableState = 0u;
    }

    PLCTimer_Stop();
    PLCTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: PLCTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: PLCTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PLCTimer_Wakeup(void)
{
    PLCTimer_RestoreConfig();

    if(0u != PLCTimer_backup.enableState)
    {
        PLCTimer_Enable();
    }
}


/* [] END OF FILE */
