/*******************************************************************************
* File Name: StartIrr.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "StartIrr.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        StartIrr_PC =   (StartIrr_PC & \
                                (uint32)(~(uint32)(StartIrr_DRIVE_MODE_IND_MASK << (StartIrr_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (StartIrr_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: StartIrr_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void StartIrr_Write(uint8 value) 
{
    uint8 drVal = (uint8)(StartIrr_DR & (uint8)(~StartIrr_MASK));
    drVal = (drVal | ((uint8)(value << StartIrr_SHIFT) & StartIrr_MASK));
    StartIrr_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: StartIrr_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  StartIrr_DM_STRONG     Strong Drive 
*  StartIrr_DM_OD_HI      Open Drain, Drives High 
*  StartIrr_DM_OD_LO      Open Drain, Drives Low 
*  StartIrr_DM_RES_UP     Resistive Pull Up 
*  StartIrr_DM_RES_DWN    Resistive Pull Down 
*  StartIrr_DM_RES_UPDWN  Resistive Pull Up/Down 
*  StartIrr_DM_DIG_HIZ    High Impedance Digital 
*  StartIrr_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void StartIrr_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(StartIrr__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: StartIrr_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro StartIrr_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 StartIrr_Read(void) 
{
    return (uint8)((StartIrr_PS & StartIrr_MASK) >> StartIrr_SHIFT);
}


/*******************************************************************************
* Function Name: StartIrr_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 StartIrr_ReadDataReg(void) 
{
    return (uint8)((StartIrr_DR & StartIrr_MASK) >> StartIrr_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(StartIrr_INTSTAT) 

    /*******************************************************************************
    * Function Name: StartIrr_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 StartIrr_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(StartIrr_INTSTAT & StartIrr_MASK);
		StartIrr_INTSTAT = maskedStatus;
        return maskedStatus >> StartIrr_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
