/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#if !defined(__DEFINITIONS__)
#define __DEFINITIONS__
    
    #include <project.h>
    
    typedef struct progam
    {
        uint8   hour;
        uint8   min;
        uint8   sec;
        uint8   t_irr;        //Control 1
        uint8   pwm1;
        uint8   pwm2;
        uint8   pwm3;
        uint8   pwm4;
        uint8   pwm5;
        uint8   days;
        uint8   driver;
        uint8   q;              //Control 2
        uint8   ph_obj;
        uint8   ph_offset;
        uint8   ce_obj;
        uint8   ce_offset;
        uint8   control_type;   //Per Pulse or Time counting
        uint8   intel;          //Intelligent Irrigation (Alix)
        uint8   program_num;
        uint8   sector;
        uint8   active;
    } program;
    
    typedef struct time
    {
        uint8   sec;
        uint8   min;
        uint8   hour;
        uint8   is12h;
        uint8   ispm;
        uint8   day;
        uint8   date;
        uint8   month;
        uint8   year;
    } time;

    //Caracteres de escape, dados por el API utilizado//
    #define ESCAPE1         0x7E
    #define ESCAPE2         0x7D
    #define ESCAPE3         0x11
    #define ESCAPE4         0x13
    #define ESCAPE5         0x7B
    #define TOKEN           0x7F
    #define MAX_PACK_SIZE   100
    
    /** COMMANDS **/
    #define _PH_            0x01
    #define _CE_            0x02
    #define _Q_             0x03
    #define _RTC_SAVE_      0x04
    #define _RTC_REQ_       0x05
    #define _PROG_SAVE_     0x06
    #define _PROG_REQ_      0x07
    #define _START_ADC_     0x08
    #define _STOP_ADC_      0x09
    #define _START_Q_       0x0A
    #define _STOP_Q_        0x0B
    #define _AN3_           0x0C
    #define _AN4_           0x0D
    #define _START_IRR_     0x0E
    #define _STOP_IRR_      0x0F
    #define _FORMAT_EE_     0x10
    #define _Q_ACUM_        0x11
    #define _NOT_OK_        0x12
    #define _CHECK_IPROG_   0x13
    #define _SET_INTEL_     0x14
    #define _UNSET_INTEL_   0x15
    #define _GET_INTEL_     0x16
    #define _MAN_IRR_       0x17
    #define _INTEL_IRR_     0x18
    #define _COMM_ACK_      0x20
    
    /** I2C ADDRESSES **/
    #define ADDR_EEPROM     0x50
    
    //**************************
    /**   EEPROM ADDRESSES   **/
    //**************************
    #define ADDR_INIT       0x0000
    #define ADDR_END        0x7FFF
    #define ADDR_INTEL      0x0000
    #define ADDR_ALIXPING   0x0002
    #define ADDR_IRR        0x0003
    
    /** MASKS **/
    
    #define masklsb_lsn     0x000F
	#define masklsb_msn     0x00F0
	#define maskmsb_lsn     0x0F00
	#define maskmsb_msn     0xF000
    
    /** ASCII TYPES **/
    
    #define _INT_           0
    #define _CHAR_          1
        
    extern uint8 XBEERXOK;
    uint8 XBEERXOK;
    extern uint8 XBEETXOK;
    uint8 XBEETXOK;
    extern uint8 PLCRXOK;
    uint8 PLCRXOK;
    extern uint8 PLCTXOK;
    uint8 PLCTXOK;
    extern uint8 PLCFLAG;
    uint8 PLCFLAG;
    extern uint8 PSOCRXOK;
    uint8 PSOCRXOK;
    extern uint8 PLCINTCLK;
    uint8 PLCINTCLK;
    extern uint8 XBEETXSTATUS;
    uint8 XBEETXSTATUS;
    extern uint8 TXDataLength;
    uint8 TXDataLength;
    extern uint8 RXDataLength;
    uint8 RXDataLength;
    
    extern uint8 ALIXTIMEPINGCOUNTER;
    uint8 ALIXTIMEPINGCOUNTER;

    //** DEFINED XBEE BYTES **/
    static uint8 xbee_settings[5] = {0x7E, 0x00, 0x01, 0x04, '\0'};
    static uint8 broadcastAddress[9] = {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, '\0'};
    static uint8 xbee_status [7] = {0x00, 0x03, 0x89, 0x01, 0x00, 0x75, '\0'};

    //** DEFINED COMMANDS PSoC2PSoC **/
    static uint8 ph_req[5] = {0x7E, 0x7B, 0x01, 0x7D};
    static uint8 start_adc[5] = {0x7E, 0x7B, 0x08, 0x7D};

    //** GLOBAL BUFFERS 4 XBEE | PLC | PSOC **/
    extern uint8 XBeeRXbuffer[100];
    uint8 XBeeRXbuffer[100];
    extern uint8 XBeeTXbuffer[100];
    uint8 XBeeTXbuffer[100];
    extern uint8 PLCRXbuffer[100];
    uint8 PLCRXbuffer[100];
    extern uint8 PLCTXbuffer[100];
    uint8 PLCTXbuffer[100];
    extern uint8 PSOCRXbuffer[100];
    uint8 PSOCRXbuffer[100];
    extern uint8 PSOCTXbuffer[100];
    uint8 PSOCTXbuffer[100];
    extern uint16 GRALbuffer[100];
    uint16 GRALbuffer[100];
    extern uint16 UARTRXbuffer[100];
    uint16 UARTRXbuffer[100];

    extern uint8 rssi;
    uint8 rssi;
    extern uint8 broadcast;
    uint8 broadcast;
    
    /**  INIT MAP PLC **/
    #define _R_             0x52
    
    // ***********************************************
    //          Automatic Irrigation Registers
    // ***********************************************

    #define SEC1_PROG1      111
    #define SEC1_PROG2      121
    #define SEC1_PROG3      131
    #define SEC1_PROG4      141
    #define SEC1_PROG5      151
    
    #define SEC2_PROG1      112
    #define SEC2_PROG2      122
    #define SEC2_PROG3      132
    #define SEC2_PROG4      142
    #define SEC2_PROG5      152
    
    #define SEC3_PROG1      113
    #define SEC3_PROG2      123
    #define SEC3_PROG3      133
    #define SEC3_PROG4      143
    #define SEC3_PROG5      153
    
    #define SEC4_PROG1      114
    #define SEC4_PROG2      124
    #define SEC4_PROG3      134
    #define SEC4_PROG4      144
    #define SEC4_PROG5      154
    
    #define SEC5_PROG1      115
    #define SEC5_PROG2      125
    #define SEC5_PROG3      135
    #define SEC5_PROG4      145
    #define SEC5_PROG5      155
   
    #define SEC6_PROG1      116
    #define SEC6_PROG2      126
    #define SEC6_PROG3      136
    #define SEC6_PROG4      146
    #define SEC6_PROG5      156
    
    #define SEC7_PROG1      117
    #define SEC7_PROG2      127
    #define SEC7_PROG3      137
    #define SEC7_PROG4      147
    #define SEC7_PROG5      157
    
    #define SEC8_PROG1      118
    #define SEC8_PROG2      128
    #define SEC8_PROG3      138
    #define SEC8_PROG4      148
    #define SEC8_PROG5      158
   
    #define SEC9_PROG1      119
    #define SEC9_PROG2      129
    #define SEC9_PROG3      139
    #define SEC9_PROG4      149
    #define SEC9_PROG5      159
    
    // ***********************************************
    //			Manual Irrigation Registers
    // ***********************************************

    #define SEC1_MAN        1511
    #define SEC2_MAN        1521
    #define SEC3_MAN        1531
    #define SEC4_MAN        1541
    #define SEC5_MAN        1551
    #define SEC6_MAN        1561
    #define SEC7_MAN        1571
    #define SEC8_MAN        1581
    #define SEC9_MAN        1591
    
    // ***********************************************
    //			Intelligent Irrigation Registers
    // ***********************************************

    #define SEC_ALL_INTEL   2000
    
    // ***********************************************
    //			PreIrrigation Time Registers
    // ***********************************************
    
    #define SEC1_PRET_PROG1 2000

    // ***********************************************
    //					PLC Commands
    // ***********************************************

    static uint8 read_plc_status[8]	= {0x02,0x30,0x31,0x34,0x30,0x43,0x37,0x03};
    static uint8 run_plc[9]			= {0x02,0x30,0x31,0x34,0x31,0x31,0x46,0x39,0x03};
    static uint8 stop_plc[9]		= {0x02,0x30,0x31,0x34,0x31,0x30,0x46,0x38,0x03};
    static uint8 write_register[7]  = {0x02,0x30,0x31,0x34,0x37,0x30,0x31};
    static uint8 irrigation_reg[16] = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x52,0x30,0x31,0x34,0x34,0x35,0x37,0x45,0x03};
    static uint8 manual_reg[16]     = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x52,0x30,0x31,0x34,0x34,0x36,0x37,0x46,0x03};
    static uint8 intel_reg[16]      = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x52,0x30,0x31,0x34,0x34,0x37,0x37,0x47,0x03};
    static uint8 ph_reg[16]         = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x44,0x30,0x34,0x30,0x37,0x32,0x36,0x46,0x03};
    static uint8 ce_reg[16]         = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x44,0x30,0x34,0x30,0x37,0x33,0x37,0x30,0x03};
    static uint8 sector_reg[16]     = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x52,0x30,0x31,0x34,0x35,0x32,0x37,0x43,0x03};
    static uint8 prognum_reg[16]    = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x52,0x30,0x31,0x34,0x35,0x33,0x37,0x44,0x03};
    static uint8 Q_reg_low[16]     = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x52,0x30,0x31,0x34,0x34,0x38,0x38,0x31,0x03};
    static uint8 Q_reg_high[16]      = {0x02,0x30,0x31,0x34,0x36,0x30,0x31,0x52,0x30,0x31,0x34,0x34,0x39,0x38,0x32,0x03};
#endif
/* [] END OF FILE */
