/* ========================================
 *
 * Copyright NGN Mobile, 2015
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF NGN Mobile.
 * 
 * @Author: crash
 * ========================================
*/
#include "main.h"

int main()
{
    vars_init();
    init_hw_status();
    sys_init();
    
    for(;;)
    {      
        XBeePacketHandler();
        if(XBEERXOK)
        {
            check_xbee_data();
            if(PSOCRXOK)
            {
                check_command();
                PSOCRXOK = 0;
            }
            XBEERXOK = 0;
        }        
        if(PLCINTCLK)
        {
            check_irr_status();
            get_irr_sens_info();
            //check_alixping_status();
            PLCINTCLK = 0;
        }
        if(ALIXTIMEPINGCOUNTER >= 12)
        {
            unset_intel_no_ping();
        }
    }
}

void vars_init()
{
    XBEERXOK = 0;
    XBEETXOK = 0;
    PLCRXOK = 1;
    PLCTXOK = 0;
    PLCINTCLK = 0;
    ALIXTIMEPINGCOUNTER = 0;
}

void init_hw_status()
{
    uint8 data=0;
    //OPTO
    if( !read_from_eeprom(ADDR_INTEL, &data) )
        SetIntel_Write(data);
    data = 0x00;
    //IRRIGATION STATUS
    if( !read_from_eeprom(ADDR_IRR, &data) )
    {
        if(data)
            write2eeprom(ADDR_IRR, 0x00);
    }
}

void sys_init()
{
    CyDelay(500);
	XBEE_UART_Start();
    XBEE_UART_EnableRxInt();
    PLC_UART_Start();
    PLCPullTimer_Init();
    PLCPullTimer_Start();
    
    PLC_UART_SetCustomInterruptHandler(&PLCPacketHandler);
    
    CyDelayUs(50);
    isr_PLCPullTimer_StartEx(&IntACKTimer);
    
	CyGlobalIntEnable;
}

void IntACKTimer(void)
{
    if( PLCPullTimer_GetInterruptSource() & PLCPullTimer_INTR_MASK_TC)
    {
        //XBeeTXbuffer[0] = 'A';
        //TXDataLength = 1;
        //XBeeSendPacket();
        
        PLCINTCLK = 1;
        blink_bothleds(3);
        PLCPullTimer_ClearInterrupt(PLCPullTimer_INTR_MASK_TC);
        PLCPullTimer_Init();
        PLCPullTimer_Start();
        isr_PLCPullTimer_ClearPending();
    }
}

void check_alixping_status()
{
    uint8 ping;
    if( !read_from_eeprom(ADDR_ALIXPING, &ping) )
    {
        if( ping )
        {
            write2eeprom(ADDR_ALIXPING, 0x00);
            ALIXTIMEPINGCOUNTER = 0;
        }
        else
            ALIXTIMEPINGCOUNTER += 1;
    }
}

void unset_intel_no_ping()
{
    SetIntel_Write(0);
    write2eeprom(ADDR_INTEL, 0x00);
    ALIXTIMEPINGCOUNTER = 0;
}

void check_irr_status()
{
    int16 status = check_plc_data(irrigation_reg);
    
    if(status)
        write2eeprom(ADDR_IRR, 0x01);
    else
    {
        CyDelay(10);
        status = check_plc_data(irrigation_reg);
        if(!status)
            write2eeprom(ADDR_IRR, 0x00);
    }
}

void get_irr_sens_info()
{
    uint16 sector, prognum, qhigh=0, qlow=0;
    uint8 data;
    if( read_from_eeprom(ADDR_IRR, &data) )
        return;
    // ******
    //int16 status = check_plc_data(irrigation_reg);
    // ******
    /*if(!status)
    {
        CyDelay(10);
        status = check_plc_data(irrigation_reg);
    }*/
    
    if( data )
    {
        XBeeTXbuffer[0] = '~';
        XBeeTXbuffer[1] = '{';
        XBeeTXbuffer[2] = 0x01;
        XBeeTXbuffer[3] = _START_IRR_;
        XBeeTXbuffer[4] = 0x00;
        XBeeTXbuffer[5] = 0x03;
        XBeeTXbuffer[6] = TOKEN;
        XBeeTXbuffer[7] = 0x00;
        XBeeTXbuffer[8] = 0x01;
        
        sector = check_plc_data(sector_reg);
        XBeeTXbuffer[9] = TOKEN;
        XBeeTXbuffer[10] = (sector & 0xFF00) >> 8;
        XBeeTXbuffer[11] = sector & 0x00FF;
        
        prognum = check_plc_data(prognum_reg);
        XBeeTXbuffer[12] = TOKEN;
        XBeeTXbuffer[13] = (prognum & 0xFF00) >> 8;
        XBeeTXbuffer[14] = prognum & 0x00FF;
        XBeeTXbuffer[15] = '}';
        TXDataLength = 16;
        XBeeSendPacket();
        if(DipSW2_Read() == 0)
            pull_plc_info();
        else
            get_adc_info();
            
        qhigh = check_plc_data(Q_reg_high);
        qlow = check_plc_data(Q_reg_low);
        XBeeTXbuffer[0] = '~';
        XBeeTXbuffer[1] = '{';
        XBeeTXbuffer[2] = 0x00;
        XBeeTXbuffer[3] = 0x28;
        XBeeTXbuffer[4] = 0x00;
        XBeeTXbuffer[5] = 0x02;
        XBeeTXbuffer[6] = TOKEN;
        XBeeTXbuffer[7] = (qhigh & 0xFF00) >> 8;
        XBeeTXbuffer[8] = qhigh & 0x00FF;
        XBeeTXbuffer[9] = TOKEN;
        XBeeTXbuffer[10] = (qlow & 0xFF00) >> 8;
        XBeeTXbuffer[11] = qlow & 0x00FF;
        XBeeTXbuffer[12] = '}';
                
        TXDataLength = 13;
        XBeeSendPacket();
    }
    else
    {
        XBeeTXbuffer[0]  = '~';
        XBeeTXbuffer[1]  = '{';
        XBeeTXbuffer[2] = 0x01;
        XBeeTXbuffer[3]  = _START_IRR_;
        XBeeTXbuffer[4] = 0x00;
        XBeeTXbuffer[5] = 0x03;
        XBeeTXbuffer[6]  = TOKEN;
        XBeeTXbuffer[7]  = 0x00;
        XBeeTXbuffer[8]  = 0x00;
        XBeeTXbuffer[9]  = TOKEN;
        XBeeTXbuffer[10]  = 0x00;
        XBeeTXbuffer[11]  = 0x00;
        XBeeTXbuffer[12]  = TOKEN;
        XBeeTXbuffer[13] = 0x00;
        XBeeTXbuffer[14] = 0x00;
        XBeeTXbuffer[15] = '}';
        
        TXDataLength = 16;
        XBeeSendPacket();
    }
    blink_redleds(3);
}

void get_adc_info()
{
    int16 ph = 0, ce = 0;
    init_adc();
    ph = get_ph();
    ce = get_ce();
    
    XBeeTXbuffer[0] = '~';
    XBeeTXbuffer[1] = '{';
    XBeeTXbuffer[2] = 0x00;
    XBeeTXbuffer[3] = 0x5A;
    XBeeTXbuffer[4] = 0x00;
    XBeeTXbuffer[5] = 0x01;
    XBeeTXbuffer[6] = TOKEN;
    XBeeTXbuffer[7] = (ce & 0xFF00) >> 8;
    XBeeTXbuffer[8] = ce & 0x00FF;
    XBeeTXbuffer[9] = '}';
    TXDataLength = 10;
    XBeeSendPacket();
    
    XBeeTXbuffer[0] = '~';
    XBeeTXbuffer[1] = '{';
    XBeeTXbuffer[2] = 0x00;
    XBeeTXbuffer[3] = 0x59;
    XBeeTXbuffer[4] = 0x00;
    XBeeTXbuffer[5] = 0x01;
    XBeeTXbuffer[6] = TOKEN;
    XBeeTXbuffer[7] = (ph & 0xFF00) >> 8;
    XBeeTXbuffer[8] = ph & 0x00FF;
    XBeeTXbuffer[9] = '}';
    TXDataLength = 10;
    XBeeSendPacket();

}

void pull_plc_info()
{
    int16 adc_ph=0, v_ph=0, adc_ce=0, v_ce=0;
    stop_adc();
     
    adc_ce = check_plc_data(ce_reg);
    v_ce = ((adc_ce * 10.0) / 16380.0)*1000.0;
    XBeeTXbuffer[0] = '~';
    XBeeTXbuffer[1] = '{';
    XBeeTXbuffer[2] = 0x00;
    XBeeTXbuffer[3] = 0x5A;
    XBeeTXbuffer[4] = 0x00;
    XBeeTXbuffer[5] = 0x01;
    XBeeTXbuffer[6] = TOKEN;
    XBeeTXbuffer[7] = (v_ce & 0xFF00) >> 8;
    XBeeTXbuffer[8] = v_ce & 0x00FF;
    XBeeTXbuffer[9] = '}';
    TXDataLength = 10;
    XBeeSendPacket();
    
    adc_ph = check_plc_data(ph_reg);
    v_ph = ((adc_ph * 10.0) / 16380.0)*1000.0;
    XBeeTXbuffer[0] = '~';
    XBeeTXbuffer[1] = '{';
    XBeeTXbuffer[2] = 0x00;
    XBeeTXbuffer[3] = 0x59;
    XBeeTXbuffer[4] = 0x00;
    XBeeTXbuffer[5] = 0x01;
    XBeeTXbuffer[6] = TOKEN;
    XBeeTXbuffer[7] = (v_ph & 0xFF00) >> 8;
    XBeeTXbuffer[8] = v_ph & 0x00FF;
    XBeeTXbuffer[9] = '}';
    TXDataLength = 10;
    XBeeSendPacket();
}