/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "plc.h"

void PLCPacketHandler()
{
    uint8 tempchar;
    int i=1, j=0;
    
    if(PLC_UART_INTR_CAUSE_RX & PLC_UART_GetInterruptCause())
    {        
        //HEADER
        while(PLC_UART_SpiUartGetRxBufferSize() == 0)
            CyDelayUs(10);
        tempchar = PLC_UART_UartGetChar(); // toma el dato del plc
        if( tempchar == 0x02 ) // busca inicio de transmisión
        {
            PLCRXbuffer[0] = tempchar;
            do
            {
                while(PLC_UART_SpiUartGetRxBufferSize() == 0)
                    CyDelayUs(10);
                tempchar = PLC_UART_UartGetChar();
                PLCRXbuffer[i] = tempchar;
                i++;
            } while (tempchar != 0x03);
            RXDataLength = i-1;
            PLCRXOK = 1;
            blink_ok();
        }
        PLC_UART_ClearRxInterruptSource(PLC_UART_INTR_RX_NOT_EMPTY);
    }
}

uint8 validate_plc_write()
{
    uint8 i, checksum=0, rxchecksum=0, lsn=0, msn=0;
    for(i = 0; i <= RXDataLength-3; i++)
        checksum += PLCRXbuffer[i];
        
    msn = PLCRXbuffer[RXDataLength-2];
    lsn = PLCRXbuffer[RXDataLength-1];
    
    rxchecksum = char2int(msn) << 4;
    rxchecksum = rxchecksum | char2int(lsn);
    
    if( checksum == rxchecksum)
    {
        blink_ok();
        return (uint8)(PLCRXbuffer[RXDataLength-3] - 48);
    }
    else
    {
        blink_error();
        return 0x01;
    }
}

uint8 validate_plc_read()
{
    uint8 i, checksum=0, rxchecksum=0, lsn=0, msn=0;
    for(i = 0; i <= RXDataLength-3; i++)
        checksum += PLCRXbuffer[i];
        
    msn = PLCRXbuffer[RXDataLength-2];
    lsn = PLCRXbuffer[RXDataLength-1];
    
    rxchecksum = char2int(msn) << 4;
    rxchecksum = rxchecksum | char2int(lsn);
    //***********
    //XBeeTXbuffer[0] = checksum;
    //XBeeTXbuffer[1] = rxchecksum;
    //XBeeTXbuffer[2] = PLCRXbuffer[RXDataLength-7];
    //TXDataLength = 3;
    //XBeeSendPacket();
    //***********
    if( checksum == rxchecksum)
    {
        blink_ok();
        return (uint8)(PLCRXbuffer[RXDataLength-7] - 48);
    }
    else
    {
        blink_error();
        return 0x01;
    }
}

uint8 send_program_2_plc(uint16 *pch)
{
    uint8 sector=0, num_prog=0;
    int plc_addr, preirr_addr;
    
    //pch = [length, t_preirr, sec, min, hour, t_irr, pwm1, pwm2, pwm3, pwm4, pwm5, days, drive, q, ph_obj, ph_offset, ce_obj, ce_offset, control_type, intel, program_num, sector]
    //PLC_UART_UartPutChar( pch[0] );
    if(pch[0] == 21)
    {
        num_prog    = pch[20];
        //PLC_UART_UartPutChar( num_prog );
        sector      = pch[21];
        //PLC_UART_UartPutChar( sector );
        if((num_prog > 0 && num_prog < 6) && (sector > 0 && sector < 10))
        {
            switch(sector)
            {
                case    1:  plc_addr = SEC1_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    2:  plc_addr = SEC2_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    3:  plc_addr = SEC3_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    4:  plc_addr = SEC4_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    5:  plc_addr = SEC5_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    6:  plc_addr = SEC6_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    7:  plc_addr = SEC7_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    8:  plc_addr = SEC8_PROG1 + ( (num_prog-1) * 10 );
                            break;
                case    9:  plc_addr = SEC9_PROG1 + ( (num_prog-1) * 10 );
                            break;
                default:    return 1;
            }
            preirr_addr = SEC1_PRET_PROG1 + (num_prog + ((sector-1) * 5));
            return send_programs(pch, plc_addr, preirr_addr, 11);
        }
    }
    
    if(pch[0] == 7)
    {
        num_prog    = pch[7];
        //PLC_UART_UartPutChar( num_prog );
        sector      = pch[6];
        //PLC_UART_UartPutChar( sector );
        if(num_prog == 0)
        {
            switch(sector)
            {
                case    1:  plc_addr = SEC1_MAN;
                            break;
                case    2:  plc_addr = SEC2_MAN;
                            break;
                case    3:  plc_addr = SEC3_MAN;
                            break;
                case    4:  plc_addr = SEC4_MAN;
                            break;
                case    5:  plc_addr = SEC5_MAN;
                            break;
                case    6:  plc_addr = SEC6_MAN;
                            break;
                case    7:  plc_addr = SEC7_MAN;
                            break;
                case    8:  plc_addr = SEC8_MAN;
                            break;
                case    9:  plc_addr = SEC9_MAN;
                            break;
                default:    return 1;
            }
            return send_programs(pch, plc_addr, 0, 5);
        }
    }
    
    if(pch[0] == 9)
    {
        num_prog    = pch[9];
        //PLC_UART_UartPutChar( num_prog );
        sector      = pch[8];
        //PLC_UART_UartPutChar( sector );
        if(num_prog == 6)
        {
            plc_addr = SEC_ALL_INTEL;
            preirr_addr = SEC1_PRET_PROG1 + (1 + ((sector-1) * 5));
            return send_programs(pch, plc_addr, preirr_addr, pch[0]-1);
        }
    }
    return 1;
}

uint8 send_programs(uint16 *pch, int plc_addr, int preirr_addr, uint8 iterator)
{
    uint8 i=0, checksum=0, tryout=0;
    uint cont=0;
    char *address, *data, *checksum_ascii;
    //Validating manual irrigation to avoid to send pre irrigation time
    if( preirr_addr == 0 )
        ++i;
    for(; i < iterator; i++)
    {
        for(tryout=0; tryout<5; tryout++)
        {
            if( i == 0)
                address = plc_addr_int2ascii(preirr_addr);
            else
                address = plc_addr_int2ascii(plc_addr + ((i-1)*100));
            data = int2wordhex(pch[i+1]);
            //Init Tx
            PLC_UART_UartPutChar(0x02);
            checksum += 0x02;
            //Station Number
            PLC_UART_UartPutChar(0x30);
            checksum += 0x30;
            PLC_UART_UartPutChar(0x31);
            checksum += 0x31;
            //Command Code
            PLC_UART_UartPutChar(0x34);
            checksum += 0x34;
            PLC_UART_UartPutChar(0x37);
            checksum += 0x37;
            //N bytes to Write
            PLC_UART_UartPutChar(0x30);
            checksum += 0x30;
            PLC_UART_UartPutChar(0x31);
            checksum += 0x31;
            //Register Address
            PLC_UART_UartPutChar(_R_);
            checksum += _R_;
            
            PLC_UART_UartPutChar(address[0]);
            checksum += address[0];
            PLC_UART_UartPutChar(address[1]);
            checksum += address[1];
            PLC_UART_UartPutChar(address[2]);
            checksum += address[2];
            PLC_UART_UartPutChar(address[3]);
            checksum += address[3];
            PLC_UART_UartPutChar(address[4]);
            checksum += address[4];
            free(address);
            //Data
            PLC_UART_UartPutChar(data[0]);
            checksum += data[0];
            PLC_UART_UartPutChar(data[1]);
            checksum += data[1];
            PLC_UART_UartPutChar(data[2]);
            checksum += data[2];
            PLC_UART_UartPutChar(data[3]);
            checksum += data[3];
            free(data);
            //Checksum
            checksum_ascii = int2wordhex(checksum);
            PLC_UART_UartPutChar(checksum_ascii[2]);
            PLC_UART_UartPutChar(checksum_ascii[3]);
            free(checksum_ascii);
            //End of Transmission
            PLC_UART_UartPutChar(0x03);
            
            while( !PLCRXOK && cont < 400)
            {
                CyDelay(10);
                ++cont;
            }

            if( PLCRXOK )
            {
                //PLC_UART_DisableInt();
                if( !validate_plc_write() )
                    break;
                PLCRXOK = 0;
                //PLC_UART_EnableInt();
            }
            cont = 0;
            checksum = 0;
        }
        if(tryout >= 5)
                return 1;
        tryout = checksum = 0;
    }
    return 0;
}

void IntPLCTimer(void)
{
    if( PLCTimer_GetInterruptSource() & PLCTimer_INTR_MASK_TC)
    {
        PLCINTCLK = 1;
        blink_bothleds(3);
        isr_PLCTimer_ClearPending();
        PLCTimer_ClearInterrupt(PLCTimer_INTR_MASK_TC);
    }
    else
    {
        PLCTimer_ClearInterrupt(PLCTimer_INTR_MASK_CC_MATCH);
    }
}

char* int2wordhex(uint16 data)
{
	char *hex = (char*) malloc ( sizeof(char) * 4 );
    
    sprintf(hex, "%04X", data);
	
	return hex;
}

uint16 check_plc_akw()
{
    uint8 command = ((PLCRXbuffer[3]-0x30) << 4) | (PLCRXbuffer[4]-0x30);
    
    switch(command)
    {
        case    0x46:   return get_read_data();
        
        case    0x47:   return get_read_data();
    }
    return 0;
}

uint16 get_read_data()
{
    uint16 value = 0x0000;
    
    if( PLCRXbuffer[5] == 0x30 )
    {
        value = (PLCRXbuffer[6]-0x30) << 12;
        value |= (PLCRXbuffer[7]-0x30) << 8;
        value |= (PLCRXbuffer[8]-0x30) << 4;
        value |= (PLCRXbuffer[9]-0x30);
    }
    else
        return 0;
    
    return value;
}

char* plc_addr_int2ascii(uint16 data)
{
    char *array=0;
    //PLC_UART_UartPutChar( (data & 0xFF00 >> 8 ) );
    //PLC_UART_UartPutChar( data & 0x00FF );
    array = (char*) malloc ( sizeof(char)*5 );

    sprintf(array, "%05d", data);
    return array;
}

uint16 check_plc_data(uint8 *data)
{
    uint i, cont=0;
    uint16 mydata = 0x0000;
    
    for(i=0; i < 16; i++)
        PLC_UART_UartPutChar(data[i]);
        
    while( !PLCRXOK && cont < 400 )
    {
        CyDelay(10);
        cont++;
    }
    
    
    if(cont  >= 400)
        return 0x0000;
    
    //PLC_UART_DisableInt();
    
    if( !validate_plc_read() )
    {
    
        if( PLCRXbuffer[6] >= 0x30 && PLCRXbuffer[6] <= 0x39)
            mydata = (PLCRXbuffer[6] - 48) << 12;
        else    
            mydata = (PLCRXbuffer[6] - 55) << 12;
            
        if( PLCRXbuffer[7] >= 0x30 && PLCRXbuffer[7] <= 0x39)
            mydata = mydata | ((PLCRXbuffer[7] - 48) << 8);
        else
            mydata = mydata | ((PLCRXbuffer[7] - 55) << 8);
            
        if( PLCRXbuffer[8] >= 0x30 && PLCRXbuffer[8] <= 0x39)
            mydata = mydata | ((PLCRXbuffer[8] - 48) << 4);
        else
            mydata = mydata | ((PLCRXbuffer[8] - 55) << 4);
            
        if( PLCRXbuffer[9] >= 0x30 && PLCRXbuffer[9] <= 0x39)
            mydata = mydata | (PLCRXbuffer[9] - 48);
        else
            mydata = mydata | (PLCRXbuffer[9] - 55);
            
        return mydata;
    }
    
    //PLC_UART_EnableInt();
    
    return 0x0000;
}


/* [] END OF FILE */
